SCHEMA = {
  "typeName" : "AWS::AmplifyUIBuilder::Theme",
  "description" : "Definition of AWS::AmplifyUIBuilder::Theme Resource Type",
  "definitions" : {
    "Tags" : {
      "type" : "object",
      "patternProperties" : {
        "^(?!aws:)[a-zA-Z+-=._:/]+$" : {
          "type" : "string",
          "maxLength" : 256,
          "minLength" : 1
        }
      },
      "additionalProperties" : False
    },
    "ThemeValue" : {
      "type" : "object",
      "properties" : {
        "Value" : {
          "type" : "string"
        },
        "Children" : {
          "type" : "array",
          "items" : {
            "$ref" : "#/definitions/ThemeValues"
          }
        }
      },
      "additionalProperties" : False
    },
    "ThemeValues" : {
      "type" : "object",
      "properties" : {
        "Key" : {
          "type" : "string"
        },
        "Value" : {
          "$ref" : "#/definitions/ThemeValue"
        }
      },
      "additionalProperties" : False
    }
  },
  "properties" : {
    "AppId" : {
      "type" : "string"
    },
    "CreatedAt" : {
      "type" : "string",
      "format" : "date-time"
    },
    "EnvironmentName" : {
      "type" : "string"
    },
    "Id" : {
      "type" : "string"
    },
    "ModifiedAt" : {
      "type" : "string",
      "format" : "date-time"
    },
    "Name" : {
      "type" : "string",
      "maxLength" : 255,
      "minLength" : 1
    },
    "Overrides" : {
      "type" : "array",
      "items" : {
        "$ref" : "#/definitions/ThemeValues"
      }
    },
    "Tags" : {
      "$ref" : "#/definitions/Tags"
    },
    "Values" : {
      "type" : "array",
      "items" : {
        "$ref" : "#/definitions/ThemeValues"
      }
    }
  },
  "createOnlyProperties" : [ "/properties/AppId", "/properties/EnvironmentName" ],
  "readOnlyProperties" : [ "/properties/CreatedAt", "/properties/Id", "/properties/ModifiedAt" ],
  "primaryIdentifier" : [ "/properties/AppId", "/properties/EnvironmentName", "/properties/Id" ],
  "handlers" : {
    "create" : {
      "permissions" : [ "amplify:GetApp", "amplifyuibuilder:CreateTheme", "amplifyuibuilder:GetTheme", "amplifyuibuilder:TagResource" ]
    },
    "read" : {
      "permissions" : [ "amplify:GetApp", "amplifyuibuilder:GetTheme" ]
    },
    "update" : {
      "permissions" : [ "amplify:GetApp", "amplifyuibuilder:GetTheme", "amplifyuibuilder:TagResource", "amplifyuibuilder:UntagResource", "amplifyuibuilder:UpdateTheme" ]
    },
    "delete" : {
      "permissions" : [ "amplify:GetApp", "amplifyuibuilder:DeleteTheme", "amplifyuibuilder:UntagResource" ]
    },
    "list" : {
      "permissions" : [ "amplify:GetApp", "amplifyuibuilder:ListThemes" ],
      "handlerSchema" : {
        "properties" : {
          "AppId" : {
            "$ref" : "resource-schema.json#/properties/AppId"
          },
          "EnvironmentName" : {
            "$ref" : "resource-schema.json#/properties/EnvironmentName"
          }
        },
        "required" : [ "AppId", "EnvironmentName" ]
      }
    }
  },
  "tagging" : {
    "taggable" : True,
    "tagOnCreate" : True,
    "tagUpdatable" : True,
    "cloudFormationSystemTags" : True,
    "tagProperty" : "/properties/Tags",
    "permissions" : [ "amplifyuibuilder:TagResource", "amplifyuibuilder:UntagResource" ]
  },
  "sourceUrl" : "https://github.com/aws-cloudformation/aws-cloudformation-resource-providers-amplifyuibuilder",
  "additionalProperties" : False
}