SCHEMA = {
  "typeName" : "AWS::ApiGateway::DocumentationPart",
  "description" : "The ``AWS::ApiGateway::DocumentationPart`` resource creates a documentation part for an API. For more information, see [Representation of API Documentation in API Gateway](https://docs.aws.amazon.com/apigateway/latest/developerguide/api-gateway-documenting-api-content-representation.html) in the *API Gateway Developer Guide*.",
  "sourceUrl" : "https://github.com/aws-cloudformation/aws-cloudformation-resource-providers-apigateway",
  "additionalProperties" : False,
  "properties" : {
    "DocumentationPartId" : {
      "description" : "",
      "type" : "string"
    },
    "Location" : {
      "description" : "",
      "$ref" : "#/definitions/Location"
    },
    "Properties" : {
      "description" : "",
      "type" : "string"
    },
    "RestApiId" : {
      "description" : "",
      "type" : "string"
    }
  },
  "definitions" : {
    "Location" : {
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "Method" : {
          "description" : "",
          "type" : "string"
        },
        "Name" : {
          "description" : "",
          "type" : "string"
        },
        "Path" : {
          "description" : "",
          "type" : "string"
        },
        "StatusCode" : {
          "description" : "",
          "type" : "string"
        },
        "Type" : {
          "description" : "",
          "type" : "string",
          "enum" : [ "API", "AUTHORIZER", "MODEL", "RESOURCE", "METHOD", "PATH_PARAMETER", "QUERY_PARAMETER", "REQUEST_HEADER", "REQUEST_BODY", "RESPONSE", "RESPONSE_HEADER", "RESPONSE_BODY" ]
        }
      },
      "description" : "The ``Location`` property specifies the location of the Amazon API Gateway API entity that the documentation applies to. ``Location`` is a property of the [AWS::ApiGateway::DocumentationPart](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-documentationpart.html) resource.\n For more information about each property, including constraints and valid values, see [DocumentationPart](https://docs.aws.amazon.com/apigateway/latest/api/API_DocumentationPartLocation.html) in the *Amazon API Gateway REST API Reference*."
    }
  },
  "required" : [ "Location", "Properties", "RestApiId" ],
  "createOnlyProperties" : [ "/properties/Location", "/properties/RestApiId" ],
  "tagging" : {
    "taggable" : False
  },
  "primaryIdentifier" : [ "/properties/DocumentationPartId", "/properties/RestApiId" ],
  "readOnlyProperties" : [ "/properties/DocumentationPartId" ],
  "handlers" : {
    "create" : {
      "permissions" : [ "apigateway:GET", "apigateway:POST" ]
    },
    "read" : {
      "permissions" : [ "apigateway:GET" ]
    },
    "update" : {
      "permissions" : [ "apigateway:GET", "apigateway:PATCH" ]
    },
    "delete" : {
      "permissions" : [ "apigateway:DELETE" ]
    },
    "list" : {
      "handlerSchema" : {
        "properties" : {
          "RestApiId" : {
            "$ref" : "resource-schema.json#/properties/RestApiId"
          }
        },
        "required" : [ "RestApiId" ]
      },
      "permissions" : [ "apigateway:GET" ]
    }
  }
}