SCHEMA = {
  "typeName" : "AWS::ApiGateway::DomainNameAccessAssociation",
  "description" : "Resource Type definition for AWS::ApiGateway::DomainNameAccessAssociation.",
  "sourceUrl" : "https://github.com/aws-cloudformation/aws-cloudformation-resource-providers-apigateway",
  "additionalProperties" : False,
  "properties" : {
    "DomainNameAccessAssociationArn" : {
      "type" : "string",
      "description" : "The amazon resource name (ARN) of the domain name access association resource."
    },
    "DomainNameArn" : {
      "type" : "string",
      "description" : "The amazon resource name (ARN) of the domain name resource."
    },
    "AccessAssociationSource" : {
      "type" : "string",
      "description" : "The source of the domain name access association resource."
    },
    "AccessAssociationSourceType" : {
      "type" : "string",
      "description" : "The source type of the domain name access association resource.",
      "enum" : [ "VPCE" ]
    },
    "Tags" : {
      "description" : "An array of arbitrary tags (key-value pairs) to associate with the domainname access association.",
      "uniqueItems" : False,
      "type" : "array",
      "items" : {
        "$ref" : "#/definitions/Tag"
      }
    }
  },
  "definitions" : {
    "Tag" : {
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "Value" : {
          "type" : "string"
        },
        "Key" : {
          "type" : "string"
        }
      },
      "required" : [ "Value", "Key" ]
    }
  },
  "primaryIdentifier" : [ "/properties/DomainNameAccessAssociationArn" ],
  "required" : [ "DomainNameArn", "AccessAssociationSource", "AccessAssociationSourceType" ],
  "readOnlyProperties" : [ "/properties/DomainNameAccessAssociationArn" ],
  "createOnlyProperties" : [ "/properties/DomainNameArn", "/properties/AccessAssociationSource", "/properties/AccessAssociationSourceType", "/properties/Tags" ],
  "tagging" : {
    "taggable" : True,
    "tagOnCreate" : True,
    "tagUpdatable" : False,
    "cloudFormationSystemTags" : True,
    "tagProperty" : "/properties/Tags",
    "permissions" : [ "apigateway:POST", "apigateway:DELETE", "apigateway:GET" ]
  },
  "handlers" : {
    "create" : {
      "permissions" : [ "apigateway:POST", "apigateway:GET" ]
    },
    "read" : {
      "permissions" : [ "apigateway:GET" ]
    },
    "delete" : {
      "permissions" : [ "apigateway:DELETE", "apigateway:GET" ]
    },
    "list" : {
      "permissions" : [ "apigateway:GET" ]
    }
  }
}