SCHEMA = {
  "sourceUrl" : "https://github.com/aws-cloudformation/aws-cloudformation-rpdk.git",
  "tagging" : {
    "permissions" : [ "apigateway:PUT", "apigateway:DELETE", "apigateway:GET" ],
    "taggable" : True,
    "tagOnCreate" : True,
    "tagUpdatable" : True,
    "tagProperty" : "/properties/Tags",
    "cloudFormationSystemTags" : True
  },
  "handlers" : {
    "read" : {
      "permissions" : [ "apigateway:GET" ]
    },
    "create" : {
      "permissions" : [ "apigateway:GET", "apigateway:POST", "apigateway:PUT", "apigateway:PATCH", "apigateway:UpdateRestApiPolicy", "s3:GetObject", "iam:PassRole" ]
    },
    "update" : {
      "permissions" : [ "apigateway:GET", "apigateway:DELETE", "apigateway:PATCH", "apigateway:PUT", "apigateway:UpdateRestApiPolicy", "s3:GetObject", "iam:PassRole" ]
    },
    "list" : {
      "permissions" : [ "apigateway:GET" ]
    },
    "delete" : {
      "permissions" : [ "apigateway:DELETE" ]
    }
  },
  "typeName" : "AWS::ApiGateway::RestApi",
  "readOnlyProperties" : [ "/properties/RestApiId", "/properties/RootResourceId" ],
  "description" : "The ``AWS::ApiGateway::RestApi`` resource creates a REST API. For more information, see [restapi:create](https://docs.aws.amazon.com/apigateway/latest/api/API_CreateRestApi.html) in the *Amazon API Gateway REST API Reference*.\n On January 1, 2016, the Swagger Specification was donated to the [OpenAPI initiative](https://docs.aws.amazon.com/https://www.openapis.org/), becoming the foundation of the OpenAPI Specification.",
  "writeOnlyProperties" : [ "/properties/Body", "/properties/BodyS3Location", "/properties/CloneFrom", "/properties/FailOnWarnings", "/properties/Mode", "/properties/Parameters" ],
  "additionalProperties" : False,
  "primaryIdentifier" : [ "/properties/RestApiId" ],
  "definitions" : {
    "EndpointConfiguration" : {
      "description" : "The ``EndpointConfiguration`` property type specifies the endpoint types of a REST API.\n ``EndpointConfiguration`` is a property of the [AWS::ApiGateway::RestApi](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-restapi.html) resource.",
      "additionalProperties" : False,
      "type" : "object",
      "properties" : {
        "IpAddressType" : {
          "description" : "",
          "type" : "string"
        },
        "Types" : {
          "uniqueItems" : True,
          "description" : "",
          "type" : "array",
          "items" : {
            "type" : "string"
          }
        },
        "VpcEndpointIds" : {
          "uniqueItems" : True,
          "description" : "",
          "type" : "array",
          "items" : {
            "relationshipRef" : {
              "typeName" : "AWS::EC2::VPCEndpoint",
              "propertyPath" : "/properties/Id"
            },
            "type" : "string"
          }
        }
      }
    },
    "Tag" : {
      "description" : "",
      "additionalProperties" : False,
      "type" : "object",
      "properties" : {
        "Value" : {
          "type" : "string"
        },
        "Key" : {
          "type" : "string"
        }
      },
      "required" : [ "Key", "Value" ]
    },
    "S3Location" : {
      "description" : "``S3Location`` is a property of the [AWS::ApiGateway::RestApi](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-restapi.html) resource that specifies the Amazon S3 location of a OpenAPI (formerly Swagger) file that defines a set of RESTful APIs in JSON or YAML.\n On January 1, 2016, the Swagger Specification was donated to the [OpenAPI initiative](https://docs.aws.amazon.com/https://www.openapis.org/), becoming the foundation of the OpenAPI Specification.",
      "additionalProperties" : False,
      "type" : "object",
      "properties" : {
        "Bucket" : {
          "relationshipRef" : {
            "typeName" : "AWS::S3::Bucket",
            "propertyPath" : "/properties/BucketName"
          },
          "description" : "The name of the S3 bucket where the OpenAPI file is stored.",
          "type" : "string"
        },
        "ETag" : {
          "description" : "The Amazon S3 ETag (a file checksum) of the OpenAPI file. If you don't specify a value, API Gateway skips ETag validation of your OpenAPI file.",
          "type" : "string"
        },
        "Version" : {
          "description" : "For versioning-enabled buckets, a specific version of the OpenAPI file.",
          "type" : "string"
        },
        "Key" : {
          "description" : "The file name of the OpenAPI file (Amazon S3 object name).",
          "type" : "string"
        }
      }
    }
  },
  "properties" : {
    "Policy" : {
      "description" : "A policy document that contains the permissions for the ``RestApi`` resource. To set the ARN for the policy, use the ``!Join`` intrinsic function with ``\"\"`` as delimiter and values of ``\"execute-api:/\"`` and ``\"*\"``.",
      "type" : [ "object", "string" ]
    },
    "BodyS3Location" : {
      "description" : "The Amazon Simple Storage Service (Amazon S3) location that points to an OpenAPI file, which defines a set of RESTful APIs in JSON or YAML format.",
      "$ref" : "#/definitions/S3Location"
    },
    "Description" : {
      "description" : "",
      "type" : "string"
    },
    "MinimumCompressionSize" : {
      "description" : "",
      "type" : "integer"
    },
    "Parameters" : {
      "patternProperties" : {
        "[a-zA-Z0-9]+" : {
          "type" : "string"
        }
      },
      "description" : "",
      "additionalProperties" : False,
      "type" : [ "object", "string" ]
    },
    "CloneFrom" : {
      "description" : "",
      "type" : "string"
    },
    "Mode" : {
      "description" : "This property applies only when you use OpenAPI to define your REST API. The ``Mode`` determines how API Gateway handles resource updates.\n Valid values are ``overwrite`` or ``merge``. \n For ``overwrite``, the new API definition replaces the existing one. The existing API identifier remains unchanged.\n  For ``merge``, the new API definition is merged with the existing API.\n If you don't specify this property, a default value is chosen. For REST APIs created before March 29, 2021, the default is ``overwrite``. For REST APIs created after March 29, 2021, the new API definition takes precedence, but any container types such as endpoint configurations and binary media types are merged with the existing API. \n Use the default mode to define top-level ``RestApi`` properties in addition to using OpenAPI. Generally, it's preferred to use API Gateway's OpenAPI extensions to model these properties.",
      "type" : "string"
    },
    "RestApiId" : {
      "description" : "",
      "type" : "string"
    },
    "DisableExecuteApiEndpoint" : {
      "description" : "",
      "type" : "boolean"
    },
    "FailOnWarnings" : {
      "description" : "",
      "type" : "boolean"
    },
    "BinaryMediaTypes" : {
      "uniqueItems" : True,
      "description" : "",
      "type" : "array",
      "items" : {
        "type" : "string"
      }
    },
    "Name" : {
      "description" : "The name of the RestApi. A name is required if the REST API is not based on an OpenAPI specification.",
      "type" : "string"
    },
    "RootResourceId" : {
      "description" : "",
      "type" : "string"
    },
    "ApiKeySourceType" : {
      "description" : "",
      "type" : "string"
    },
    "EndpointConfiguration" : {
      "description" : "A list of the endpoint types of the API. Use this property when creating an API. When importing an existing API, specify the endpoint configuration types using the ``Parameters`` property.",
      "$ref" : "#/definitions/EndpointConfiguration"
    },
    "Body" : {
      "description" : "An OpenAPI specification that defines a set of RESTful APIs in JSON format. For YAML templates, you can also provide the specification in YAML format.",
      "type" : [ "object", "string" ]
    },
    "Tags" : {
      "uniqueItems" : False,
      "description" : "",
      "type" : "array",
      "items" : {
        "$ref" : "#/definitions/Tag"
      }
    }
  }
}