SCHEMA = {
  "typeName" : "AWS::ApiGateway::VpcLink",
  "description" : "The ``AWS::ApiGateway::VpcLink`` resource creates an API Gateway VPC link for a REST API to access resources in an Amazon Virtual Private Cloud (VPC). For more information, see [vpclink:create](https://docs.aws.amazon.com/apigateway/latest/api/API_CreateVpcLink.html) in the ``Amazon API Gateway REST API Reference``.",
  "sourceUrl" : "https://github.com/aws-cloudformation/aws-cloudformation-rpdk.git",
  "properties" : {
    "Name" : {
      "description" : "",
      "type" : "string"
    },
    "Description" : {
      "description" : "",
      "type" : "string"
    },
    "Tags" : {
      "description" : "An array of arbitrary tags (key-value pairs) to associate with the VPC link.",
      "insertionOrder" : False,
      "uniqueItems" : True,
      "type" : "array",
      "items" : {
        "$ref" : "#/definitions/Tag"
      }
    },
    "TargetArns" : {
      "description" : "",
      "type" : "array",
      "uniqueItems" : False,
      "insertionOrder" : False,
      "items" : {
        "type" : "string"
      }
    },
    "VpcLinkId" : {
      "description" : "",
      "type" : "string"
    }
  },
  "definitions" : {
    "Tag" : {
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "Value" : {
          "type" : "string"
        },
        "Key" : {
          "type" : "string"
        }
      },
      "required" : [ "Value", "Key" ],
      "description" : ""
    }
  },
  "required" : [ "Name", "TargetArns" ],
  "tagging" : {
    "taggable" : True,
    "tagOnCreate" : True,
    "tagUpdatable" : True,
    "cloudFormationSystemTags" : False,
    "tagProperty" : "/properties/Tags"
  },
  "handlers" : {
    "create" : {
      "permissions" : [ "apigateway:POST", "apigateway:PUT", "apigateway:GET", "ec2:CreateVpcEndpointServiceConfiguration", "ec2:DeleteVpcEndpointServiceConfigurations", "ec2:DescribeVpcEndpointServiceConfigurations", "ec2:ModifyVpcEndpointServicePermissions" ]
    },
    "update" : {
      "permissions" : [ "apigateway:PATCH", "apigateway:GET", "apigateway:PUT", "ec2:CreateVpcEndpointServiceConfiguration", "ec2:DeleteVpcEndpointServiceConfigurations", "ec2:DescribeVpcEndpointServiceConfigurations", "ec2:ModifyVpcEndpointServicePermissions" ]
    },
    "read" : {
      "permissions" : [ "apigateway:GET", "ec2:CreateVpcEndpointServiceConfiguration", "ec2:DeleteVpcEndpointServiceConfigurations", "ec2:DescribeVpcEndpointServiceConfigurations", "ec2:ModifyVpcEndpointServicePermissions" ]
    },
    "list" : {
      "permissions" : [ "apigateway:GET", "ec2:CreateVpcEndpointServiceConfiguration", "ec2:DeleteVpcEndpointServiceConfigurations", "ec2:DescribeVpcEndpointServiceConfigurations", "ec2:ModifyVpcEndpointServicePermissions" ]
    },
    "delete" : {
      "permissions" : [ "apigateway:GET", "apigateway:DELETE", "apigateway:PUT", "ec2:CreateVpcEndpointServiceConfiguration", "ec2:DeleteVpcEndpointServiceConfigurations", "ec2:DescribeVpcEndpointServiceConfigurations", "ec2:ModifyVpcEndpointServicePermissions" ]
    }
  },
  "createOnlyProperties" : [ "/properties/TargetArns" ],
  "additionalProperties" : False,
  "primaryIdentifier" : [ "/properties/VpcLinkId" ],
  "readOnlyProperties" : [ "/properties/VpcLinkId" ]
}