SCHEMA = {
  "typeName" : "AWS::ApiGatewayV2::Api",
  "description" : "The ``AWS::ApiGatewayV2::Api`` resource creates an API. WebSocket APIs and HTTP APIs are supported. For more information about WebSocket APIs, see [About WebSocket APIs in API Gateway](https://docs.aws.amazon.com/apigateway/latest/developerguide/apigateway-websocket-api-overview.html) in the *API Gateway Developer Guide*. For more information about HTTP APIs, see [HTTP APIs](https://docs.aws.amazon.com/apigateway/latest/developerguide/http-api.html) in the *API Gateway Developer Guide.*",
  "additionalProperties" : False,
  "properties" : {
    "RouteSelectionExpression" : {
      "type" : "string",
      "description" : "The route selection expression for the API. For HTTP APIs, the ``routeSelectionExpression`` must be ``${request.method} ${request.path}``. If not provided, this will be the default for HTTP APIs. This property is required for WebSocket APIs."
    },
    "Body" : {
      "type" : "object",
      "description" : "The OpenAPI definition. Supported only for HTTP APIs. To import an HTTP API, you must specify a ``Body`` or ``BodyS3Location``. If you specify a ``Body`` or ``BodyS3Location``, don't specify CloudFormation resources such as ``AWS::ApiGatewayV2::Authorizer`` or ``AWS::ApiGatewayV2::Route``. API Gateway doesn't support the combination of OpenAPI and CloudFormation resources."
    },
    "BodyS3Location" : {
      "$ref" : "#/definitions/BodyS3Location",
      "description" : "The S3 location of an OpenAPI definition. Supported only for HTTP APIs. To import an HTTP API, you must specify a ``Body`` or ``BodyS3Location``. If you specify a ``Body`` or ``BodyS3Location``, don't specify CloudFormation resources such as ``AWS::ApiGatewayV2::Authorizer`` or ``AWS::ApiGatewayV2::Route``. API Gateway doesn't support the combination of OpenAPI and CloudFormation resources."
    },
    "BasePath" : {
      "type" : "string",
      "description" : "Specifies how to interpret the base path of the API during import. Valid values are ``ignore``, ``prepend``, and ``split``. The default value is ``ignore``. To learn more, see [Set the OpenAPI basePath Property](https://docs.aws.amazon.com/apigateway/latest/developerguide/api-gateway-import-api-basePath.html). Supported only for HTTP APIs."
    },
    "CredentialsArn" : {
      "type" : "string",
      "description" : "This property is part of quick create. It specifies the credentials required for the integration, if any. For a Lambda integration, three options are available. To specify an IAM Role for API Gateway to assume, use the role's Amazon Resource Name (ARN). To require that the caller's identity be passed through from the request, specify ``arn:aws:iam::*:user/*``. To use resource-based permissions on supported AWS services, specify ``None``. Currently, this property is not used for HTTP integrations. Supported only for HTTP APIs."
    },
    "CorsConfiguration" : {
      "$ref" : "#/definitions/Cors",
      "description" : "A CORS configuration. Supported only for HTTP APIs. See [Configuring CORS](https://docs.aws.amazon.com/apigateway/latest/developerguide/http-api-cors.html) for more information."
    },
    "RouteKey" : {
      "type" : "string",
      "description" : "This property is part of quick create. If you don't specify a ``routeKey``, a default route of ``$default`` is created. The ``$default`` route acts as a catch-all for any request made to your API, for a particular stage. The ``$default`` route key can't be modified. You can add routes after creating the API, and you can update the route keys of additional routes. Supported only for HTTP APIs."
    },
    "Target" : {
      "type" : "string",
      "description" : "This property is part of quick create. Quick create produces an API with an integration, a default catch-all route, and a default stage which is configured to automatically deploy changes. For HTTP integrations, specify a fully qualified URL. For Lambda integrations, specify a function ARN. The type of the integration will be HTTP_PROXY or AWS_PROXY, respectively. Supported only for HTTP APIs."
    },
    "FailOnWarnings" : {
      "type" : "boolean",
      "description" : "Specifies whether to rollback the API creation when a warning is encountered. By default, API creation continues if a warning is encountered."
    },
    "ApiEndpoint" : {
      "type" : "string",
      "description" : ""
    },
    "Description" : {
      "type" : "string",
      "description" : "The description of the API."
    },
    "DisableExecuteApiEndpoint" : {
      "type" : "boolean",
      "description" : "Specifies whether clients can invoke your API by using the default ``execute-api`` endpoint. By default, clients can invoke your API with the default https://{api_id}.execute-api.{region}.amazonaws.com endpoint. To require that clients use a custom domain name to invoke your API, disable the default endpoint."
    },
    "DisableSchemaValidation" : {
      "type" : "boolean",
      "description" : "Avoid validating models when creating a deployment. Supported only for WebSocket APIs."
    },
    "Name" : {
      "type" : "string",
      "description" : "The name of the API. Required unless you specify an OpenAPI definition for ``Body`` or ``S3BodyLocation``."
    },
    "Version" : {
      "type" : "string",
      "description" : "A version identifier for the API."
    },
    "ProtocolType" : {
      "type" : "string",
      "description" : "The API protocol. Valid values are ``WEBSOCKET`` or ``HTTP``. Required unless you specify an OpenAPI definition for ``Body`` or ``S3BodyLocation``."
    },
    "ApiId" : {
      "type" : "string",
      "description" : ""
    },
    "Tags" : {
      "type" : "object",
      "description" : "The collection of tags. Each tag element is associated with a given resource.",
      "additionalProperties" : False,
      "patternProperties" : {
        ".*" : {
          "type" : "string"
        }
      }
    },
    "ApiKeySelectionExpression" : {
      "type" : "string",
      "description" : "An API key selection expression. Supported only for WebSocket APIs. See [API Key Selection Expressions](https://docs.aws.amazon.com/apigateway/latest/developerguide/apigateway-websocket-api-selection-expressions.html#apigateway-websocket-api-apikey-selection-expressions)."
    },
    "IpAddressType" : {
      "type" : "string",
      "description" : ""
    }
  },
  "definitions" : {
    "BodyS3Location" : {
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "Etag" : {
          "type" : "string",
          "description" : "The Etag of the S3 object."
        },
        "Bucket" : {
          "type" : "string",
          "description" : "The S3 bucket that contains the OpenAPI definition to import. Required if you specify a ``BodyS3Location`` for an API."
        },
        "Version" : {
          "type" : "string",
          "description" : "The version of the S3 object."
        },
        "Key" : {
          "type" : "string",
          "description" : "The key of the S3 object. Required if you specify a ``BodyS3Location`` for an API."
        }
      },
      "description" : "The ``BodyS3Location`` property specifies an S3 location from which to import an OpenAPI definition. Supported only for HTTP APIs."
    },
    "Cors" : {
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "AllowOrigins" : {
          "type" : "array",
          "uniqueItems" : False,
          "items" : {
            "type" : "string"
          },
          "description" : "Represents a collection of allowed origins. Supported only for HTTP APIs."
        },
        "AllowCredentials" : {
          "type" : "boolean",
          "description" : "Specifies whether credentials are included in the CORS request. Supported only for HTTP APIs."
        },
        "ExposeHeaders" : {
          "type" : "array",
          "uniqueItems" : False,
          "items" : {
            "type" : "string"
          },
          "description" : "Represents a collection of exposed headers. Supported only for HTTP APIs."
        },
        "AllowHeaders" : {
          "type" : "array",
          "uniqueItems" : False,
          "items" : {
            "type" : "string"
          },
          "description" : "Represents a collection of allowed headers. Supported only for HTTP APIs."
        },
        "MaxAge" : {
          "type" : "integer",
          "description" : "The number of seconds that the browser should cache preflight request results. Supported only for HTTP APIs."
        },
        "AllowMethods" : {
          "type" : "array",
          "uniqueItems" : False,
          "items" : {
            "type" : "string"
          },
          "description" : "Represents a collection of allowed HTTP methods. Supported only for HTTP APIs."
        }
      },
      "description" : "The ``Cors`` property specifies a CORS configuration for an API. Supported only for HTTP APIs. See [Configuring CORS](https://docs.aws.amazon.com/apigateway/latest/developerguide/http-api-cors.html) for more information."
    }
  },
  "createOnlyProperties" : [ "/properties/ProtocolType" ],
  "primaryIdentifier" : [ "/properties/ApiId" ],
  "readOnlyProperties" : [ "/properties/ApiId", "/properties/ApiEndpoint" ],
  "writeOnlyProperties" : [ "/properties/Body", "/properties/BasePath", "/properties/BodyS3Location", "/properties/BodyS3Location/Etag", "/properties/BodyS3Location/Bucket", "/properties/BodyS3Location/Version", "/properties/BodyS3Location/Key", "/properties/CredentialsArn", "/properties/FailOnWarnings", "/properties/RouteKey", "/properties/Target", "/properties/DisableSchemaValidation" ],
  "tagging" : {
    "taggable" : True,
    "tagOnCreate" : True,
    "tagUpdatable" : True,
    "cloudFormationSystemTags" : True,
    "tagProperty" : "/properties/Tags"
  },
  "handlers" : {
    "create" : {
      "permissions" : [ "apigateway:POST", "apigateway:PUT", "s3:getObject" ]
    },
    "update" : {
      "permissions" : [ "apigateway:PATCH", "apigateway:GET", "apigateway:PUT", "apigateway:POST", "s3:getObject" ]
    },
    "read" : {
      "permissions" : [ "apigateway:GET", "s3:getObject" ]
    },
    "delete" : {
      "permissions" : [ "apigateway:GET", "apigateway:DELETE", "s3:getObject" ]
    },
    "list" : {
      "permissions" : [ "apigateway:GET", "s3:getObject" ]
    }
  }
}