SCHEMA = {
  "typeName" : "AWS::AppConfig::ExtensionAssociation",
  "description" : "An example resource schema demonstrating some basic constructs and validation rules.",
  "sourceUrl" : "https://github.com/aws-cloudformation/aws-cloudformation-rpdk.git",
  "properties" : {
    "Id" : {
      "type" : "string"
    },
    "Arn" : {
      "type" : "string"
    },
    "ExtensionArn" : {
      "type" : "string"
    },
    "ResourceArn" : {
      "type" : "string"
    },
    "ExtensionIdentifier" : {
      "type" : "string"
    },
    "ResourceIdentifier" : {
      "type" : "string"
    },
    "ExtensionVersionNumber" : {
      "type" : "integer"
    },
    "Parameters" : {
      "type" : "object",
      "patternProperties" : {
        "^.+$" : {
          "type" : "string"
        }
      },
      "additionalProperties" : False
    },
    "Tags" : {
      "description" : "An array of key-value pairs to apply to this resource.",
      "type" : "array",
      "uniqueItems" : True,
      "insertionOrder" : False,
      "items" : {
        "$ref" : "#/definitions/Tag"
      }
    }
  },
  "definitions" : {
    "Tag" : {
      "description" : "A key-value pair to associate with a resource.",
      "type" : "object",
      "properties" : {
        "Key" : {
          "type" : "string",
          "description" : "The key name of the tag. You can specify a value that is 1 to 128 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -.",
          "minLength" : 1,
          "maxLength" : 128
        },
        "Value" : {
          "type" : "string",
          "description" : "The value for the tag. You can specify a value that is 0 to 256 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -.",
          "minLength" : 0,
          "maxLength" : 256
        }
      },
      "required" : [ "Key", "Value" ],
      "additionalProperties" : False
    }
  },
  "additionalProperties" : False,
  "readOnlyProperties" : [ "/properties/Id", "/properties/Arn", "/properties/ResourceArn", "/properties/ExtensionArn" ],
  "createOnlyProperties" : [ "/properties/ExtensionIdentifier", "/properties/ResourceIdentifier", "/properties/ExtensionVersionNumber" ],
  "writeOnlyProperties" : [ "/properties/ExtensionIdentifier", "/properties/ResourceIdentifier" ],
  "primaryIdentifier" : [ "/properties/Id" ],
  "handlers" : {
    "create" : {
      "permissions" : [ "appconfig:CreateExtensionAssociation", "appconfig:TagResource" ]
    },
    "read" : {
      "permissions" : [ "appconfig:GetExtensionAssociation", "appconfig:ListTagsForResource" ]
    },
    "update" : {
      "permissions" : [ "appconfig:UpdateExtensionAssociation", "appconfig:TagResource", "appconfig:UntagResource" ]
    },
    "delete" : {
      "permissions" : [ "appconfig:DeleteExtensionAssociation", "appconfig:UntagResource" ]
    },
    "list" : {
      "permissions" : [ "appconfig:ListExtensionAssociations" ]
    }
  },
  "tagging" : {
    "taggable" : True,
    "tagOnCreate" : True,
    "tagUpdatable" : True,
    "cloudFormationSystemTags" : True,
    "tagProperty" : "/properties/Tags",
    "permissions" : [ "appconfig:TagResource", "appconfig:UntagResource", "appconfig:ListTagsForResource" ]
  }
}