SCHEMA = {
  "sourceUrl" : "https://github.com/aws-cloudformation/aws-cloudformation-resource-providers-appconfig.git",
  "tagging" : {
    "taggable" : False,
    "tagOnCreate" : False,
    "tagUpdatable" : False,
    "cloudFormationSystemTags" : False
  },
  "handlers" : {
    "read" : {
      "permissions" : [ "appconfig:GetHostedConfigurationVersion" ]
    },
    "create" : {
      "permissions" : [ "appconfig:CreateHostedConfigurationVersion" ]
    },
    "list" : {
      "permissions" : [ "appconfig:ListHostedConfigurationVersions" ],
      "handlerSchema" : {
        "properties" : {
          "ConfigurationProfileId" : {
            "$ref" : "resource-schema.json#/properties/ConfigurationProfileId"
          },
          "ApplicationId" : {
            "$ref" : "resource-schema.json#/properties/ApplicationId"
          }
        },
        "required" : [ "ApplicationId", "ConfigurationProfileId" ]
      }
    },
    "delete" : {
      "permissions" : [ "appconfig:DeleteHostedConfigurationVersion" ]
    }
  },
  "typeName" : "AWS::AppConfig::HostedConfigurationVersion",
  "readOnlyProperties" : [ "/properties/VersionNumber" ],
  "description" : "Resource Type definition for AWS::AppConfig::HostedConfigurationVersion",
  "writeOnlyProperties" : [ "/properties/LatestVersionNumber" ],
  "createOnlyProperties" : [ "/properties/ApplicationId", "/properties/ConfigurationProfileId", "/properties/Description", "/properties/Content", "/properties/ContentType", "/properties/LatestVersionNumber", "/properties/VersionLabel" ],
  "additionalProperties" : False,
  "primaryIdentifier" : [ "/properties/ApplicationId", "/properties/ConfigurationProfileId", "/properties/VersionNumber" ],
  "properties" : {
    "ConfigurationProfileId" : {
      "pattern" : "[a-z0-9]{4,7}",
      "description" : "The configuration profile ID.",
      "type" : "string"
    },
    "Description" : {
      "minLength" : 0,
      "description" : "A description of the hosted configuration version.",
      "type" : "string",
      "maxLength" : 1024
    },
    "ContentType" : {
      "minLength" : 1,
      "description" : "A standard MIME type describing the format of the configuration content.",
      "type" : "string",
      "maxLength" : 255
    },
    "LatestVersionNumber" : {
      "description" : "An optional locking token used to prevent race conditions from overwriting configuration updates when creating a new version. To ensure your data is not overwritten when creating multiple hosted configuration versions in rapid succession, specify the version number of the latest hosted configuration version.",
      "type" : "integer"
    },
    "Content" : {
      "description" : "The content of the configuration or the configuration data.",
      "type" : "string"
    },
    "VersionLabel" : {
      "minLength" : 0,
      "pattern" : "^$|.*[^0-9].*",
      "description" : "A user-defined label for an AWS AppConfig hosted configuration version.",
      "type" : "string",
      "maxLength" : 64
    },
    "ApplicationId" : {
      "pattern" : "[a-z0-9]{4,7}",
      "description" : "The application ID.",
      "type" : "string"
    },
    "VersionNumber" : {
      "description" : "Current version number of hosted configuration version.",
      "type" : "string"
    }
  },
  "required" : [ "ApplicationId", "ConfigurationProfileId", "Content", "ContentType" ]
}