SCHEMA = {
  "typeName" : "AWS::AppStream::DirectoryConfig",
  "description" : "Resource Type definition for AWS::AppStream::DirectoryConfig",
  "additionalProperties" : False,
  "properties" : {
    "OrganizationalUnitDistinguishedNames" : {
      "type" : "array",
      "uniqueItems" : False,
      "items" : {
        "type" : "string"
      }
    },
    "ServiceAccountCredentials" : {
      "$ref" : "#/definitions/ServiceAccountCredentials"
    },
    "DirectoryName" : {
      "type" : "string"
    },
    "CertificateBasedAuthProperties" : {
      "$ref" : "#/definitions/CertificateBasedAuthProperties"
    }
  },
  "definitions" : {
    "ServiceAccountCredentials" : {
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "AccountName" : {
          "type" : "string"
        },
        "AccountPassword" : {
          "type" : "string"
        }
      },
      "required" : [ "AccountName", "AccountPassword" ]
    },
    "CertificateBasedAuthProperties" : {
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "Status" : {
          "type" : "string"
        },
        "CertificateAuthorityArn" : {
          "type" : "string"
        }
      }
    }
  },
  "required" : [ "DirectoryName", "OrganizationalUnitDistinguishedNames", "ServiceAccountCredentials" ],
  "writeOnlyProperties" : [ "/properties/ServiceAccountCredentials/AccountPassword" ],
  "createOnlyProperties" : [ "/properties/DirectoryName" ],
  "primaryIdentifier" : [ "/properties/DirectoryName" ],
  "tagging" : {
    "taggable" : False
  },
  "handlers" : {
    "create" : {
      "permissions" : [ "appstream:CreateDirectoryConfig", "appstream:DeleteDirectoryConfig", "appstream:DescribeDirectoryConfigs", "appstream:UpdateDirectoryConfig", "iam:CreateServiceLinkedRole", "iam:DeleteServiceLinkedRole", "iam:GetServiceLinkedRoleDeletionStatus" ]
    },
    "update" : {
      "permissions" : [ "appstream:CreateDirectoryConfig", "appstream:DeleteDirectoryConfig", "appstream:DescribeDirectoryConfigs", "appstream:UpdateDirectoryConfig", "iam:CreateServiceLinkedRole", "iam:DeleteServiceLinkedRole", "iam:GetServiceLinkedRoleDeletionStatus" ]
    },
    "read" : {
      "permissions" : [ "appstream:CreateDirectoryConfig", "appstream:DeleteDirectoryConfig", "appstream:DescribeDirectoryConfigs", "appstream:UpdateDirectoryConfig", "iam:CreateServiceLinkedRole", "iam:DeleteServiceLinkedRole", "iam:GetServiceLinkedRoleDeletionStatus" ]
    },
    "delete" : {
      "permissions" : [ "appstream:CreateDirectoryConfig", "appstream:DeleteDirectoryConfig", "appstream:DescribeDirectoryConfigs", "appstream:UpdateDirectoryConfig", "iam:CreateServiceLinkedRole", "iam:DeleteServiceLinkedRole", "iam:GetServiceLinkedRoleDeletionStatus" ]
    },
    "list" : {
      "permissions" : [ "appstream:CreateDirectoryConfig", "appstream:DeleteDirectoryConfig", "appstream:DescribeDirectoryConfigs", "appstream:UpdateDirectoryConfig", "iam:CreateServiceLinkedRole", "iam:DeleteServiceLinkedRole", "iam:GetServiceLinkedRoleDeletionStatus" ]
    }
  }
}