SCHEMA = {
  "typeName" : "AWS::APS::RuleGroupsNamespace",
  "description" : "RuleGroupsNamespace schema for cloudformation.",
  "sourceUrl" : "https://github.com/aws-cloudformation/aws-cloudformation-resource-providers-aps",
  "definitions" : {
    "Tag" : {
      "description" : "A key-value pair to associate with a resource.",
      "type" : "object",
      "properties" : {
        "Key" : {
          "type" : "string",
          "description" : "The key name of the tag. You can specify a value that is 1 to 128 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -.",
          "minLength" : 1,
          "maxLength" : 128
        },
        "Value" : {
          "type" : "string",
          "description" : "The value for the tag. You can specify a value that is 0 to 256 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -.",
          "minLength" : 0,
          "maxLength" : 256
        }
      },
      "required" : [ "Key", "Value" ],
      "additionalProperties" : False
    }
  },
  "properties" : {
    "Workspace" : {
      "description" : "Required to identify a specific APS Workspace associated with this RuleGroupsNamespace.",
      "type" : "string",
      "pattern" : "^arn:(aws|aws-us-gov|aws-cn):aps:[a-z0-9-]+:[0-9]+:workspace/[a-zA-Z0-9-]+$"
    },
    "Name" : {
      "description" : "The RuleGroupsNamespace name.",
      "type" : "string",
      "minLength" : 1,
      "maxLength" : 64
    },
    "Data" : {
      "description" : "The RuleGroupsNamespace data.",
      "type" : "string"
    },
    "Arn" : {
      "description" : "The RuleGroupsNamespace ARN.",
      "type" : "string",
      "pattern" : "^arn:(aws|aws-us-gov|aws-cn):aps:[a-z0-9-]+:[0-9]+:rulegroupsnamespace/[a-zA-Z0-9-]+/[0-9A-Za-z][-.0-9A-Z_a-z]*$"
    },
    "Tags" : {
      "description" : "An array of key-value pairs to apply to this resource.",
      "type" : "array",
      "uniqueItems" : True,
      "insertionOrder" : False,
      "items" : {
        "$ref" : "#/definitions/Tag"
      }
    }
  },
  "additionalProperties" : False,
  "required" : [ "Workspace", "Data", "Name" ],
  "createOnlyProperties" : [ "/properties/Name", "/properties/Workspace" ],
  "readOnlyProperties" : [ "/properties/Arn" ],
  "tagging" : {
    "taggable" : True,
    "tagOnCreate" : True,
    "tagUpdatable" : True,
    "cloudFormationSystemTags" : True,
    "tagProperty" : "/properties/Tags",
    "permissions" : [ "aps:TagResource", "aps:UntagResource" ]
  },
  "primaryIdentifier" : [ "/properties/Arn" ],
  "handlers" : {
    "create" : {
      "permissions" : [ "aps:CreateRuleGroupsNamespace", "aps:DescribeRuleGroupsNamespace", "aps:TagResource" ]
    },
    "read" : {
      "permissions" : [ "aps:DescribeRuleGroupsNamespace", "aps:ListTagsForResource" ]
    },
    "update" : {
      "permissions" : [ "aps:PutRuleGroupsNamespace", "aps:DescribeRuleGroupsNamespace", "aps:TagResource", "aps:UntagResource", "aps:ListTagsForResource" ]
    },
    "delete" : {
      "permissions" : [ "aps:DeleteRuleGroupsNamespace", "aps:DescribeRuleGroupsNamespace" ]
    },
    "list" : {
      "permissions" : [ "aps:ListRuleGroupsNamespaces", "aps:ListTagsForResource" ],
      "handlerSchema" : {
        "properties" : {
          "Arn" : {
            "$ref" : "resource-schema.json#/properties/Workspace"
          }
        },
        "required" : [ "Arn" ]
      }
    }
  }
}