SCHEMA = {
  "typeName" : "AWS::Batch::SchedulingPolicy",
  "description" : "Resource Type definition for AWS::Batch::SchedulingPolicy",
  "sourceUrl" : "https://github.com/aws-cloudformation/aws-cloudformation-resource-providers-batch.git",
  "definitions" : {
    "ResourceArn" : {
      "description" : "ARN of the Scheduling Policy.",
      "type" : "string"
    },
    "FairsharePolicy" : {
      "description" : "Fair Share Policy for the Job Queue.",
      "type" : "object",
      "properties" : {
        "ShareDecaySeconds" : {
          "type" : "number",
          "minimum" : 0,
          "maximum" : 604800
        },
        "ComputeReservation" : {
          "type" : "number",
          "minimum" : 0,
          "maximum" : 99
        },
        "ShareDistribution" : {
          "description" : "List of Share Attributes",
          "type" : "array",
          "insertionOrder" : False,
          "items" : {
            "$ref" : "#/definitions/ShareAttributes"
          }
        }
      },
      "required" : [ ],
      "additionalProperties" : False
    },
    "ShareAttributes" : {
      "type" : "object",
      "properties" : {
        "ShareIdentifier" : {
          "type" : "string"
        },
        "WeightFactor" : {
          "type" : "number",
          "minimum" : 0,
          "maximum" : 1000
        }
      },
      "required" : [ ],
      "additionalProperties" : False
    }
  },
  "properties" : {
    "Name" : {
      "description" : "Name of Scheduling Policy.",
      "type" : "string",
      "pattern" : ""
    },
    "Arn" : {
      "$ref" : "#/definitions/ResourceArn"
    },
    "FairsharePolicy" : {
      "$ref" : "#/definitions/FairsharePolicy"
    },
    "Tags" : {
      "type" : "object",
      "description" : "A key-value pair to associate with a resource.",
      "patternProperties" : {
        ".*" : {
          "type" : "string"
        }
      },
      "additionalProperties" : False
    }
  },
  "additionalProperties" : False,
  "tagging" : {
    "taggable" : True,
    "tagOnCreate" : True,
    "tagUpdatable" : False,
    "cloudFormationSystemTags" : False,
    "tagProperty" : "/properties/Tags",
    "permissions" : [ "Batch:TagResource", "Batch:UntagResource" ]
  },
  "primaryIdentifier" : [ "/properties/Arn" ],
  "createOnlyProperties" : [ "/properties/Name", "/properties/Tags" ],
  "readOnlyProperties" : [ "/properties/Arn" ],
  "handlers" : {
    "create" : {
      "permissions" : [ "Batch:CreateSchedulingPolicy", "Batch:TagResource" ]
    },
    "read" : {
      "permissions" : [ "Batch:DescribeSchedulingPolicies" ]
    },
    "update" : {
      "permissions" : [ "Batch:UpdateSchedulingPolicy", "Batch:TagResource", "Batch:UnTagResource" ]
    },
    "delete" : {
      "permissions" : [ "Batch:DescribeSchedulingPolicies", "Batch:DeleteSchedulingPolicy" ]
    },
    "list" : {
      "permissions" : [ "Batch:ListSchedulingPolicies", "Batch:DescribeSchedulingPolicies" ]
    }
  }
}