SCHEMA = {
  "typeName" : "AWS::CleanRooms::Collaboration",
  "description" : "Represents a collaboration between AWS accounts that allows for secure data collaboration",
  "documentationUrl" : "https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cleanrooms-collaboration.html",
  "definitions" : {
    "AnalyticsEngine" : {
      "type" : "string",
      "enum" : [ "CLEAN_ROOMS_SQL", "SPARK" ]
    },
    "CollaborationJobLogStatus" : {
      "type" : "string",
      "enum" : [ "ENABLED", "DISABLED" ]
    },
    "CollaborationQueryLogStatus" : {
      "type" : "string",
      "enum" : [ "ENABLED", "DISABLED" ]
    },
    "DataEncryptionMetadata" : {
      "type" : "object",
      "properties" : {
        "AllowCleartext" : {
          "type" : "boolean"
        },
        "AllowDuplicates" : {
          "type" : "boolean"
        },
        "AllowJoinsOnColumnsWithDifferentNames" : {
          "type" : "boolean"
        },
        "PreserveNulls" : {
          "type" : "boolean"
        }
      },
      "required" : [ "AllowCleartext", "AllowDuplicates", "AllowJoinsOnColumnsWithDifferentNames", "PreserveNulls" ],
      "additionalProperties" : False
    },
    "MemberAbility" : {
      "type" : "string",
      "enum" : [ "CAN_QUERY", "CAN_RUN_JOB", "CAN_RECEIVE_RESULTS" ]
    },
    "MemberAbilities" : {
      "type" : "array",
      "insertionOrder" : False,
      "items" : {
        "$ref" : "#/definitions/MemberAbility"
      },
      "uniqueItems" : True
    },
    "MLMemberAbilities" : {
      "type" : "object",
      "properties" : {
        "CustomMLMemberAbilities" : {
          "$ref" : "#/definitions/CustomMLMemberAbilities"
        }
      },
      "required" : [ "CustomMLMemberAbilities" ],
      "additionalProperties" : False
    },
    "CustomMLMemberAbility" : {
      "type" : "string",
      "enum" : [ "CAN_RECEIVE_MODEL_OUTPUT", "CAN_RECEIVE_INFERENCE_OUTPUT" ]
    },
    "CustomMLMemberAbilities" : {
      "type" : "array",
      "insertionOrder" : False,
      "items" : {
        "$ref" : "#/definitions/CustomMLMemberAbility"
      },
      "uniqueItems" : True
    },
    "MemberSpecification" : {
      "type" : "object",
      "properties" : {
        "AccountId" : {
          "type" : "string",
          "maxLength" : 12,
          "minLength" : 12,
          "pattern" : "^\\d+$"
        },
        "MemberAbilities" : {
          "$ref" : "#/definitions/MemberAbilities"
        },
        "MLMemberAbilities" : {
          "$ref" : "#/definitions/MLMemberAbilities"
        },
        "DisplayName" : {
          "$ref" : "#/definitions/Name"
        },
        "PaymentConfiguration" : {
          "$ref" : "#/definitions/PaymentConfiguration"
        }
      },
      "required" : [ "AccountId", "DisplayName", "MemberAbilities" ],
      "additionalProperties" : False
    },
    "MemberStatus" : {
      "type" : "string",
      "enum" : [ "INVITED", "ACTIVE", "LEFT", "REMOVED" ]
    },
    "Tag" : {
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "Key" : {
          "type" : "string",
          "minLength" : 1,
          "maxLength" : 128
        },
        "Value" : {
          "type" : "string",
          "minLength" : 1,
          "maxLength" : 256
        }
      },
      "required" : [ "Value", "Key" ]
    },
    "Name" : {
      "type" : "string",
      "maxLength" : 100,
      "minLength" : 1,
      "pattern" : "^(?!\\s*$)[\\u0020-\\uD7FF\\uE000-\\uFFFD\\uD800\\uDBFF-\\uDC00\\uDFFF\\t]*$"
    },
    "PaymentConfiguration" : {
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "JobCompute" : {
          "$ref" : "#/definitions/JobComputePaymentConfig"
        },
        "QueryCompute" : {
          "$ref" : "#/definitions/QueryComputePaymentConfig"
        },
        "MachineLearning" : {
          "$ref" : "#/definitions/MLPaymentConfig"
        }
      },
      "required" : [ "QueryCompute" ]
    },
    "JobComputePaymentConfig" : {
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "IsResponsible" : {
          "type" : "boolean"
        }
      },
      "required" : [ "IsResponsible" ]
    },
    "QueryComputePaymentConfig" : {
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "IsResponsible" : {
          "type" : "boolean"
        }
      },
      "required" : [ "IsResponsible" ]
    },
    "MLPaymentConfig" : {
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "ModelTraining" : {
          "$ref" : "#/definitions/ModelTrainingPaymentConfig"
        },
        "ModelInference" : {
          "$ref" : "#/definitions/ModelInferencePaymentConfig"
        }
      }
    },
    "ModelTrainingPaymentConfig" : {
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "IsResponsible" : {
          "type" : "boolean"
        }
      },
      "required" : [ "IsResponsible" ]
    },
    "ModelInferencePaymentConfig" : {
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "IsResponsible" : {
          "type" : "boolean"
        }
      },
      "required" : [ "IsResponsible" ]
    }
  },
  "properties" : {
    "Arn" : {
      "type" : "string",
      "maxLength" : 100
    },
    "Tags" : {
      "description" : "An arbitrary set of tags (key-value pairs) for this cleanrooms collaboration.",
      "insertionOrder" : False,
      "items" : {
        "$ref" : "#/definitions/Tag"
      },
      "uniqueItems" : True,
      "type" : "array"
    },
    "CollaborationIdentifier" : {
      "type" : "string",
      "maxLength" : 36,
      "minLength" : 36,
      "pattern" : "[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}"
    },
    "CreatorDisplayName" : {
      "$ref" : "#/definitions/Name"
    },
    "CreatorMemberAbilities" : {
      "$ref" : "#/definitions/MemberAbilities"
    },
    "CreatorMLMemberAbilities" : {
      "$ref" : "#/definitions/MLMemberAbilities"
    },
    "DataEncryptionMetadata" : {
      "$ref" : "#/definitions/DataEncryptionMetadata"
    },
    "Description" : {
      "type" : "string",
      "maxLength" : 255,
      "minLength" : 1,
      "pattern" : "^(?!\\s*$)[\\u0020-\\uD7FF\\uE000-\\uFFFD\\uD800\\uDBFF-\\uDC00\\uDFFF\\t\\r\\n]*$"
    },
    "Members" : {
      "type" : "array",
      "insertionOrder" : False,
      "items" : {
        "$ref" : "#/definitions/MemberSpecification"
      },
      "maxItems" : 9,
      "minItems" : 0
    },
    "Name" : {
      "type" : "string",
      "maxLength" : 100,
      "minLength" : 1,
      "pattern" : "^(?!\\s*$)[\\u0020-\\uD7FF\\uE000-\\uFFFD\\uD800\\uDBFF-\\uDC00\\uDFFF\\t]*$"
    },
    "JobLogStatus" : {
      "$ref" : "#/definitions/CollaborationJobLogStatus"
    },
    "QueryLogStatus" : {
      "$ref" : "#/definitions/CollaborationQueryLogStatus"
    },
    "AnalyticsEngine" : {
      "$ref" : "#/definitions/AnalyticsEngine"
    },
    "CreatorPaymentConfiguration" : {
      "$ref" : "#/definitions/PaymentConfiguration"
    }
  },
  "required" : [ "CreatorDisplayName", "CreatorMemberAbilities", "Members", "Name", "Description", "QueryLogStatus" ],
  "readOnlyProperties" : [ "/properties/Arn", "/properties/CollaborationIdentifier" ],
  "createOnlyProperties" : [ "/properties/CreatorDisplayName", "/properties/CreatorMemberAbilities", "/properties/CreatorMLMemberAbilities", "/properties/DataEncryptionMetadata", "/properties/JobLogStatus", "/properties/QueryLogStatus", "/properties/Members", "/properties/CreatorPaymentConfiguration" ],
  "primaryIdentifier" : [ "/properties/CollaborationIdentifier" ],
  "tagging" : {
    "taggable" : True,
    "tagOnCreate" : True,
    "tagUpdatable" : True,
    "cloudFormationSystemTags" : True,
    "tagProperty" : "/properties/Tags",
    "permissions" : [ "cleanrooms:ListTagsForResource", "cleanrooms:UntagResource", "cleanrooms:TagResource" ]
  },
  "handlers" : {
    "create" : {
      "permissions" : [ "cleanrooms:CreateCollaboration", "cleanrooms:GetCollaboration", "cleanrooms:ListMembers", "cleanrooms:ListTagsForResource", "cleanrooms:TagResource", "cleanrooms:GetCollaboration", "cleanrooms:ListCollaborations" ]
    },
    "read" : {
      "permissions" : [ "cleanrooms:GetCollaboration", "cleanrooms:ListMembers", "cleanrooms:ListTagsForResource" ]
    },
    "update" : {
      "permissions" : [ "cleanrooms:UpdateCollaboration", "cleanrooms:GetCollaboration", "cleanrooms:ListMembers", "cleanrooms:ListTagsForResource", "cleanrooms:TagResource", "cleanrooms:UntagResource" ]
    },
    "delete" : {
      "permissions" : [ "cleanrooms:DeleteCollaboration", "cleanrooms:GetCollaboration", "cleanrooms:ListTagsForResource", "cleanrooms:UntagResource", "cleanrooms:ListMembers", "cleanrooms:ListCollaborations" ]
    },
    "list" : {
      "permissions" : [ "cleanrooms:ListCollaborations" ]
    }
  },
  "additionalProperties" : False
}