SCHEMA = {
  "sourceUrl" : "https://github.com/aws-cloudformation/aws-cloudformation-resource-providers-cloudformation",
  "oneOf" : [ {
    "required" : [ "TypeVersionArn" ]
  }, {
    "required" : [ "TypeName", "VersionId" ]
  } ],
  "handlers" : {
    "read" : {
      "permissions" : [ "cloudformation:DescribeType" ]
    },
    "create" : {
      "permissions" : [ "cloudformation:SetTypeDefaultVersion" ]
    },
    "update" : {
      "permissions" : [ "cloudformation:SetTypeDefaultVersion" ]
    },
    "list" : {
      "permissions" : [ "cloudformation:ListTypeVersions" ]
    },
    "delete" : {
      "permissions" : [ "" ]
    }
  },
  "typeName" : "AWS::CloudFormation::ResourceDefaultVersion",
  "readOnlyProperties" : [ "/properties/Arn" ],
  "description" : "The default version of a resource that has been registered in the CloudFormation Registry.",
  "additionalIdentifiers" : [ [ "/properties/TypeName" ] ],
  "additionalProperties" : False,
  "primaryIdentifier" : [ "/properties/Arn" ],
  "properties" : {
    "VersionId" : {
      "pattern" : "^[A-Za-z0-9-]{1,128}$",
      "description" : "The ID of an existing version of the resource to set as the default.",
      "type" : "string"
    },
    "TypeName" : {
      "pattern" : "^[A-Za-z0-9]{2,64}::[A-Za-z0-9]{2,64}::[A-Za-z0-9]{2,64}$",
      "description" : "The name of the type being registered.\n\nWe recommend that type names adhere to the following pattern: company_or_organization::service::type.",
      "type" : "string"
    },
    "Arn" : {
      "pattern" : "^arn:aws[A-Za-z0-9-]{0,64}:cloudformation:[A-Za-z0-9-]{1,64}:([0-9]{12})?:type/resource/.+$",
      "description" : "The Amazon Resource Name (ARN) of the type. This is used to uniquely identify a ResourceDefaultVersion",
      "type" : "string"
    },
    "TypeVersionArn" : {
      "pattern" : "^arn:aws[A-Za-z0-9-]{0,64}:cloudformation:[A-Za-z0-9-]{1,64}:([0-9]{12})?:type/resource/.+$",
      "description" : "The Amazon Resource Name (ARN) of the type version.",
      "type" : "string"
    }
  }
}