SCHEMA = {
  "additionalProperties" : False,
  "createOnlyProperties" : [ "/properties/IpCount", "/properties/Name", "/properties/Tags" ],
  "definitions" : {
    "AnycastIpList" : {
      "additionalProperties" : False,
      "properties" : {
        "AnycastIps" : {
          "items" : {
            "type" : "string"
          },
          "type" : "array",
          "description" : "The static IP addresses that are allocated to the Anycast static IP list."
        },
        "Arn" : {
          "type" : "string",
          "description" : "The Amazon Resource Name (ARN) of the Anycast static IP list."
        },
        "Id" : {
          "type" : "string",
          "description" : "The ID of the Anycast static IP list."
        },
        "IpCount" : {
          "type" : "integer",
          "description" : "The number of IP addresses in the Anycast static IP list."
        },
        "LastModifiedTime" : {
          "format" : "date-time",
          "type" : "string",
          "description" : "The last time the Anycast static IP list was modified."
        },
        "Name" : {
          "maxLength" : 64,
          "minLength" : 1,
          "pattern" : "^[a-zA-Z0-9-_]{1,64}$",
          "type" : "string",
          "description" : "The name of the Anycast static IP list."
        },
        "Status" : {
          "type" : "string",
          "description" : "The status of the Anycast static IP list. Valid values: ``Deployed``, ``Deploying``, or ``Failed``."
        }
      },
      "required" : [ "AnycastIps", "Arn", "Id", "IpCount", "LastModifiedTime", "Name", "Status" ],
      "type" : "object",
      "description" : "An Anycast static IP list. For more information, see [Request Anycast static IPs to use for allowlisting](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/request-static-ips.html) in the *Amazon CloudFront Developer Guide*."
    },
    "Tag" : {
      "additionalProperties" : False,
      "properties" : {
        "Key" : {
          "maxLength" : 128,
          "minLength" : 1,
          "pattern" : "^([\\p{L}\\p{Z}\\p{N}_.:/=+\\-@]*)$",
          "type" : "string",
          "description" : "A string that contains ``Tag`` key.\n The string length should be between 1 and 128 characters. Valid characters include ``a-z``, ``A-Z``, ``0-9``, space, and the special characters ``_ - . : / = + @``."
        },
        "Value" : {
          "maxLength" : 256,
          "minLength" : 0,
          "pattern" : "^([\\p{L}\\p{Z}\\p{N}_.:/=+\\-@]*)$",
          "type" : "string",
          "description" : "A string that contains an optional ``Tag`` value.\n The string length should be between 0 and 256 characters. Valid characters include ``a-z``, ``A-Z``, ``0-9``, space, and the special characters ``_ - . : / = + @``."
        }
      },
      "required" : [ "Key" ],
      "type" : "object",
      "description" : "A complex type that contains ``Tag`` key and ``Tag`` value."
    },
    "Tags" : {
      "additionalProperties" : False,
      "properties" : {
        "Items" : {
          "items" : {
            "$ref" : "#/definitions/Tag"
          },
          "type" : "array",
          "description" : "A complex type that contains ``Tag`` elements."
        }
      },
      "type" : "object",
      "description" : "A complex type that contains zero or more ``Tag`` elements."
    }
  },
  "description" : "An Anycast static IP list. For more information, see [Request Anycast static IPs to use for allowlisting](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/request-static-ips.html) in the *Amazon CloudFront Developer Guide*.",
  "handlers" : {
    "create" : {
      "permissions" : [ "cloudfront:CreateAnycastIpList", "cloudfront:TagResource" ]
    },
    "delete" : {
      "permissions" : [ "cloudfront:DeleteAnycastIpList", "cloudfront:GetAnycastIpList" ]
    },
    "list" : {
      "permissions" : [ "cloudfront:ListAnycastIpLists" ]
    },
    "read" : {
      "permissions" : [ "cloudfront:GetAnycastIpList", "cloudfront:ListTagsForResource" ]
    }
  },
  "primaryIdentifier" : [ "/properties/Id" ],
  "properties" : {
    "AnycastIpList" : {
      "$ref" : "#/definitions/AnycastIpList",
      "description" : ""
    },
    "ETag" : {
      "type" : "string",
      "description" : ""
    },
    "Id" : {
      "type" : "string",
      "description" : ""
    },
    "IpCount" : {
      "type" : "integer",
      "description" : "The number of IP addresses in the Anycast static IP list."
    },
    "Name" : {
      "maxLength" : 64,
      "minLength" : 1,
      "pattern" : "^[a-zA-Z0-9-_]{1,64}$",
      "type" : "string",
      "description" : "The name of the Anycast static IP list."
    },
    "Tags" : {
      "$ref" : "#/definitions/Tags",
      "description" : "A complex type that contains zero or more ``Tag`` elements."
    }
  },
  "readOnlyProperties" : [ "/properties/AnycastIpList", "/properties/ETag", "/properties/Id" ],
  "required" : [ "IpCount", "Name" ],
  "tagging" : {
    "cloudFormationSystemTags" : False,
    "permissions" : [ "cloudfront:TagResource", "cloudfront:ListTagsForResource" ],
    "tagOnCreate" : True,
    "tagProperty" : "/properties/Tags",
    "tagUpdatable" : False,
    "taggable" : True
  },
  "typeName" : "AWS::CloudFront::AnycastIpList"
}