SCHEMA = {
  "additionalProperties" : False,
  "definitions" : {
    "Tag" : {
      "additionalProperties" : False,
      "properties" : {
        "Key" : {
          "type" : "string",
          "description" : "A string that contains ``Tag`` key.\n The string length should be between 1 and 128 characters. Valid characters include ``a-z``, ``A-Z``, ``0-9``, space, and the special characters ``_ - . : / = + @``."
        },
        "Value" : {
          "type" : "string",
          "description" : "A string that contains an optional ``Tag`` value.\n The string length should be between 0 and 256 characters. Valid characters include ``a-z``, ``A-Z``, ``0-9``, space, and the special characters ``_ - . : / = + @``."
        }
      },
      "required" : [ "Value", "Key" ],
      "type" : "object",
      "description" : "A complex type that contains ``Tag`` key and ``Tag`` value."
    }
  },
  "description" : "The connection group for your distribution tenants. When you first create a distribution tenant and you don't specify a connection group, CloudFront will automatically create a default connection group for you. When you create a new distribution tenant and don't specify a connection group, the default one will be associated with your distribution tenant.",
  "handlers" : {
    "create" : {
      "permissions" : [ "cloudfront:CreateConnectionGroup", "cloudfront:GetConnectionGroup", "cloudfront:TagResource" ]
    },
    "delete" : {
      "permissions" : [ "cloudfront:DeleteConnectionGroup", "cloudfront:GetConnectionGroup", "cloudfront:UpdateConnectionGroup" ]
    },
    "list" : {
      "permissions" : [ "cloudfront:ListConnectionGroups", "cloudfront:ListTagsForResource" ]
    },
    "read" : {
      "permissions" : [ "cloudfront:GetConnectionGroup", "cloudfront:ListTagsForResource" ]
    },
    "update" : {
      "permissions" : [ "cloudfront:GetConnectionGroup", "cloudfront:UpdateConnectionGroup", "cloudfront:ListTagsForResource", "cloudfront:TagResource", "cloudfront:UntagResource" ]
    }
  },
  "primaryIdentifier" : [ "/properties/Id" ],
  "properties" : {
    "Id" : {
      "type" : "string",
      "description" : ""
    },
    "Name" : {
      "type" : "string",
      "description" : "The name of the connection group."
    },
    "Arn" : {
      "type" : "string",
      "description" : ""
    },
    "CreatedTime" : {
      "format" : "date-time",
      "type" : "string",
      "description" : ""
    },
    "LastModifiedTime" : {
      "format" : "date-time",
      "type" : "string",
      "description" : ""
    },
    "Tags" : {
      "items" : {
        "$ref" : "#/definitions/Tag"
      },
      "type" : "array",
      "uniqueItems" : False,
      "description" : "A complex type that contains zero or more ``Tag`` elements."
    },
    "Ipv6Enabled" : {
      "type" : "boolean",
      "description" : "IPv6 is enabled for the connection group."
    },
    "RoutingEndpoint" : {
      "type" : "string",
      "description" : ""
    },
    "AnycastIpListId" : {
      "type" : "string",
      "description" : "The ID of the Anycast static IP list."
    },
    "Status" : {
      "type" : "string",
      "description" : ""
    },
    "Enabled" : {
      "type" : "boolean",
      "description" : "Whether the connection group is enabled."
    },
    "IsDefault" : {
      "type" : "boolean",
      "description" : ""
    },
    "ETag" : {
      "type" : "string",
      "description" : ""
    }
  },
  "createOnlyProperties" : [ "/properties/Name" ],
  "readOnlyProperties" : [ "/properties/Id", "/properties/Arn", "/properties/CreatedTime", "/properties/LastModifiedTime", "/properties/RoutingEndpoint", "/properties/Status", "/properties/IsDefault", "/properties/ETag" ],
  "required" : [ "Name" ],
  "tagging" : {
    "cloudFormationSystemTags" : False,
    "permissions" : [ "cloudfront:TagResource", "cloudfront:ListTagsForResource", "cloudfront:UntagResource" ],
    "tagOnCreate" : True,
    "tagProperty" : "/properties/Tags",
    "tagUpdatable" : True,
    "taggable" : True
  },
  "typeName" : "AWS::CloudFront::ConnectionGroup"
}