SCHEMA = {
  "additionalProperties" : False,
  "definitions" : {
    "AccessControlAllowHeaders" : {
      "additionalProperties" : False,
      "properties" : {
        "Items" : {
          "insertionOrder" : False,
          "items" : {
            "type" : "string"
          },
          "type" : "array",
          "description" : "The list of HTTP header names. You can specify ``*`` to allow all headers."
        }
      },
      "required" : [ "Items" ],
      "type" : "object",
      "description" : "A list of HTTP header names that CloudFront includes as values for the ``Access-Control-Allow-Headers`` HTTP response header.\n For more information about the ``Access-Control-Allow-Headers`` HTTP response header, see [Access-Control-Allow-Headers](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Access-Control-Allow-Headers) in the MDN Web Docs."
    },
    "AccessControlAllowMethods" : {
      "additionalProperties" : False,
      "properties" : {
        "Items" : {
          "insertionOrder" : False,
          "items" : {
            "type" : "string"
          },
          "type" : "array",
          "description" : "The list of HTTP methods. Valid values are:\n  +   ``GET`` \n  +   ``DELETE`` \n  +   ``HEAD`` \n  +   ``OPTIONS`` \n  +   ``PATCH`` \n  +   ``POST`` \n  +   ``PUT`` \n  +   ``ALL`` \n  \n ``ALL`` is a special value that includes all of the listed HTTP methods."
        }
      },
      "required" : [ "Items" ],
      "type" : "object",
      "description" : "A list of HTTP methods that CloudFront includes as values for the ``Access-Control-Allow-Methods`` HTTP response header.\n For more information about the ``Access-Control-Allow-Methods`` HTTP response header, see [Access-Control-Allow-Methods](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Access-Control-Allow-Methods) in the MDN Web Docs."
    },
    "AccessControlAllowOrigins" : {
      "additionalProperties" : False,
      "properties" : {
        "Items" : {
          "insertionOrder" : False,
          "items" : {
            "type" : "string"
          },
          "type" : "array",
          "description" : "The list of origins (domain names). You can specify ``*`` to allow all origins."
        }
      },
      "required" : [ "Items" ],
      "type" : "object",
      "description" : "A list of origins (domain names) that CloudFront can use as the value for the ``Access-Control-Allow-Origin`` HTTP response header.\n For more information about the ``Access-Control-Allow-Origin`` HTTP response header, see [Access-Control-Allow-Origin](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Access-Control-Allow-Origin) in the MDN Web Docs."
    },
    "AccessControlExposeHeaders" : {
      "additionalProperties" : False,
      "properties" : {
        "Items" : {
          "insertionOrder" : False,
          "items" : {
            "type" : "string"
          },
          "type" : "array",
          "description" : "The list of HTTP headers. You can specify ``*`` to expose all headers."
        }
      },
      "required" : [ "Items" ],
      "type" : "object",
      "description" : "A list of HTTP headers that CloudFront includes as values for the ``Access-Control-Expose-Headers`` HTTP response header.\n For more information about the ``Access-Control-Expose-Headers`` HTTP response header, see [Access-Control-Expose-Headers](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Access-Control-Expose-Headers) in the MDN Web Docs."
    },
    "ContentSecurityPolicy" : {
      "additionalProperties" : False,
      "properties" : {
        "ContentSecurityPolicy" : {
          "type" : "string",
          "description" : "The policy directives and their values that CloudFront includes as values for the ``Content-Security-Policy`` HTTP response header.\n For more information about the ``Content-Security-Policy`` HTTP response header, see [Content-Security-Policy](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Content-Security-Policy) in the MDN Web Docs."
        },
        "Override" : {
          "type" : "boolean",
          "description" : "A Boolean that determines whether CloudFront overrides the ``Content-Security-Policy`` HTTP response header received from the origin with the one specified in this response headers policy."
        }
      },
      "required" : [ "Override", "ContentSecurityPolicy" ],
      "type" : "object",
      "description" : "The policy directives and their values that CloudFront includes as values for the ``Content-Security-Policy`` HTTP response header.\n For more information about the ``Content-Security-Policy`` HTTP response header, see [Content-Security-Policy](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Content-Security-Policy) in the MDN Web Docs."
    },
    "ContentTypeOptions" : {
      "additionalProperties" : False,
      "properties" : {
        "Override" : {
          "type" : "boolean",
          "description" : "A Boolean that determines whether CloudFront overrides the ``X-Content-Type-Options`` HTTP response header received from the origin with the one specified in this response headers policy."
        }
      },
      "required" : [ "Override" ],
      "type" : "object",
      "description" : "Determines whether CloudFront includes the ``X-Content-Type-Options`` HTTP response header with its value set to ``nosniff``.\n For more information about the ``X-Content-Type-Options`` HTTP response header, see [X-Content-Type-Options](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/X-Content-Type-Options) in the MDN Web Docs."
    },
    "CorsConfig" : {
      "additionalProperties" : False,
      "properties" : {
        "AccessControlAllowCredentials" : {
          "type" : "boolean",
          "description" : "A Boolean that CloudFront uses as the value for the ``Access-Control-Allow-Credentials`` HTTP response header.\n For more information about the ``Access-Control-Allow-Credentials`` HTTP response header, see [Access-Control-Allow-Credentials](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Access-Control-Allow-Credentials) in the MDN Web Docs."
        },
        "AccessControlAllowHeaders" : {
          "$ref" : "#/definitions/AccessControlAllowHeaders",
          "description" : "A list of HTTP header names that CloudFront includes as values for the ``Access-Control-Allow-Headers`` HTTP response header.\n For more information about the ``Access-Control-Allow-Headers`` HTTP response header, see [Access-Control-Allow-Headers](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Access-Control-Allow-Headers) in the MDN Web Docs."
        },
        "AccessControlAllowMethods" : {
          "$ref" : "#/definitions/AccessControlAllowMethods",
          "description" : "A list of HTTP methods that CloudFront includes as values for the ``Access-Control-Allow-Methods`` HTTP response header.\n For more information about the ``Access-Control-Allow-Methods`` HTTP response header, see [Access-Control-Allow-Methods](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Access-Control-Allow-Methods) in the MDN Web Docs."
        },
        "AccessControlAllowOrigins" : {
          "$ref" : "#/definitions/AccessControlAllowOrigins",
          "description" : "A list of origins (domain names) that CloudFront can use as the value for the ``Access-Control-Allow-Origin`` HTTP response header.\n For more information about the ``Access-Control-Allow-Origin`` HTTP response header, see [Access-Control-Allow-Origin](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Access-Control-Allow-Origin) in the MDN Web Docs."
        },
        "AccessControlExposeHeaders" : {
          "$ref" : "#/definitions/AccessControlExposeHeaders",
          "description" : "A list of HTTP headers that CloudFront includes as values for the ``Access-Control-Expose-Headers`` HTTP response header.\n For more information about the ``Access-Control-Expose-Headers`` HTTP response header, see [Access-Control-Expose-Headers](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Access-Control-Expose-Headers) in the MDN Web Docs."
        },
        "AccessControlMaxAgeSec" : {
          "type" : "integer",
          "description" : "A number that CloudFront uses as the value for the ``Access-Control-Max-Age`` HTTP response header.\n For more information about the ``Access-Control-Max-Age`` HTTP response header, see [Access-Control-Max-Age](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Access-Control-Max-Age) in the MDN Web Docs."
        },
        "OriginOverride" : {
          "type" : "boolean",
          "description" : "A Boolean that determines whether CloudFront overrides HTTP response headers received from the origin with the ones specified in this response headers policy."
        }
      },
      "required" : [ "AccessControlAllowOrigins", "AccessControlAllowHeaders", "AccessControlAllowMethods", "AccessControlAllowCredentials", "OriginOverride" ],
      "type" : "object",
      "description" : "A configuration for a set of HTTP response headers that are used for cross-origin resource sharing (CORS). CloudFront adds these headers to HTTP responses that it sends for CORS requests that match a cache behavior associated with this response headers policy.\n For more information about CORS, see [Cross-Origin Resource Sharing (CORS)](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/CORS) in the MDN Web Docs."
    },
    "CustomHeader" : {
      "additionalProperties" : False,
      "properties" : {
        "Header" : {
          "type" : "string",
          "description" : "The HTTP response header name."
        },
        "Override" : {
          "type" : "boolean",
          "description" : "A Boolean that determines whether CloudFront overrides a response header with the same name received from the origin with the header specified here."
        },
        "Value" : {
          "type" : "string",
          "description" : "The value for the HTTP response header."
        }
      },
      "required" : [ "Header", "Value", "Override" ],
      "type" : "object",
      "description" : "An HTTP response header name and its value. CloudFront includes this header in HTTP responses that it sends for requests that match a cache behavior that's associated with this response headers policy."
    },
    "CustomHeadersConfig" : {
      "additionalProperties" : False,
      "properties" : {
        "Items" : {
          "insertionOrder" : False,
          "items" : {
            "$ref" : "#/definitions/CustomHeader"
          },
          "type" : "array",
          "uniqueItems" : False,
          "description" : "The list of HTTP response headers and their values."
        }
      },
      "required" : [ "Items" ],
      "type" : "object",
      "description" : "A list of HTTP response header names and their values. CloudFront includes these headers in HTTP responses that it sends for requests that match a cache behavior that's associated with this response headers policy."
    },
    "FrameOptions" : {
      "additionalProperties" : False,
      "properties" : {
        "FrameOption" : {
          "pattern" : "^(DENY|SAMEORIGIN)$",
          "type" : "string",
          "description" : "The value of the ``X-Frame-Options`` HTTP response header. Valid values are ``DENY`` and ``SAMEORIGIN``.\n For more information about these values, see [X-Frame-Options](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/X-Frame-Options) in the MDN Web Docs."
        },
        "Override" : {
          "type" : "boolean",
          "description" : "A Boolean that determines whether CloudFront overrides the ``X-Frame-Options`` HTTP response header received from the origin with the one specified in this response headers policy."
        }
      },
      "required" : [ "Override", "FrameOption" ],
      "type" : "object",
      "description" : "Determines whether CloudFront includes the ``X-Frame-Options`` HTTP response header and the header's value.\n For more information about the ``X-Frame-Options`` HTTP response header, see [X-Frame-Options](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/X-Frame-Options) in the MDN Web Docs."
    },
    "ReferrerPolicy" : {
      "additionalProperties" : False,
      "properties" : {
        "Override" : {
          "type" : "boolean",
          "description" : "A Boolean that determines whether CloudFront overrides the ``Referrer-Policy`` HTTP response header received from the origin with the one specified in this response headers policy."
        },
        "ReferrerPolicy" : {
          "pattern" : "^(no-referrer|no-referrer-when-downgrade|origin|origin-when-cross-origin|same-origin|strict-origin|strict-origin-when-cross-origin|unsafe-url)$",
          "type" : "string",
          "description" : "Determines whether CloudFront includes the ``Referrer-Policy`` HTTP response header and the header's value.\n For more information about the ``Referrer-Policy`` HTTP response header, see [Referrer-Policy](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Referrer-Policy) in the MDN Web Docs."
        }
      },
      "required" : [ "Override", "ReferrerPolicy" ],
      "type" : "object",
      "description" : "Determines whether CloudFront includes the ``Referrer-Policy`` HTTP response header and the header's value.\n For more information about the ``Referrer-Policy`` HTTP response header, see [Referrer-Policy](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Referrer-Policy) in the MDN Web Docs."
    },
    "RemoveHeader" : {
      "additionalProperties" : False,
      "properties" : {
        "Header" : {
          "type" : "string",
          "description" : "The HTTP header name."
        }
      },
      "required" : [ "Header" ],
      "type" : "object",
      "description" : "The name of an HTTP header that CloudFront removes from HTTP responses to requests that match the cache behavior that this response headers policy is attached to."
    },
    "RemoveHeadersConfig" : {
      "additionalProperties" : False,
      "properties" : {
        "Items" : {
          "insertionOrder" : False,
          "items" : {
            "$ref" : "#/definitions/RemoveHeader"
          },
          "type" : "array",
          "uniqueItems" : True,
          "description" : "The list of HTTP header names."
        }
      },
      "required" : [ "Items" ],
      "type" : "object",
      "description" : "A list of HTTP header names that CloudFront removes from HTTP responses to requests that match the cache behavior that this response headers policy is attached to."
    },
    "ResponseHeadersPolicyConfig" : {
      "additionalProperties" : False,
      "properties" : {
        "Comment" : {
          "type" : "string",
          "description" : "A comment to describe the response headers policy.\n The comment cannot be longer than 128 characters."
        },
        "CorsConfig" : {
          "$ref" : "#/definitions/CorsConfig",
          "description" : "A configuration for a set of HTTP response headers that are used for cross-origin resource sharing (CORS)."
        },
        "CustomHeadersConfig" : {
          "$ref" : "#/definitions/CustomHeadersConfig",
          "description" : "A configuration for a set of custom HTTP response headers."
        },
        "Name" : {
          "type" : "string",
          "description" : "A name to identify the response headers policy.\n The name must be unique for response headers policies in this AWS-account."
        },
        "RemoveHeadersConfig" : {
          "$ref" : "#/definitions/RemoveHeadersConfig",
          "description" : "A configuration for a set of HTTP headers to remove from the HTTP response."
        },
        "SecurityHeadersConfig" : {
          "$ref" : "#/definitions/SecurityHeadersConfig",
          "description" : "A configuration for a set of security-related HTTP response headers."
        },
        "ServerTimingHeadersConfig" : {
          "$ref" : "#/definitions/ServerTimingHeadersConfig",
          "description" : "A configuration for enabling the ``Server-Timing`` header in HTTP responses sent from CloudFront."
        }
      },
      "required" : [ "Name" ],
      "type" : "object",
      "description" : "A response headers policy configuration.\n A response headers policy configuration contains metadata about the response headers policy, and configurations for sets of HTTP response headers."
    },
    "SecurityHeadersConfig" : {
      "additionalProperties" : False,
      "properties" : {
        "ContentSecurityPolicy" : {
          "$ref" : "#/definitions/ContentSecurityPolicy",
          "description" : "The policy directives and their values that CloudFront includes as values for the ``Content-Security-Policy`` HTTP response header.\n For more information about the ``Content-Security-Policy`` HTTP response header, see [Content-Security-Policy](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Content-Security-Policy) in the MDN Web Docs."
        },
        "ContentTypeOptions" : {
          "$ref" : "#/definitions/ContentTypeOptions",
          "description" : "Determines whether CloudFront includes the ``X-Content-Type-Options`` HTTP response header with its value set to ``nosniff``.\n For more information about the ``X-Content-Type-Options`` HTTP response header, see [X-Content-Type-Options](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/X-Content-Type-Options) in the MDN Web Docs."
        },
        "FrameOptions" : {
          "$ref" : "#/definitions/FrameOptions",
          "description" : "Determines whether CloudFront includes the ``X-Frame-Options`` HTTP response header and the header's value.\n For more information about the ``X-Frame-Options`` HTTP response header, see [X-Frame-Options](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/X-Frame-Options) in the MDN Web Docs."
        },
        "ReferrerPolicy" : {
          "$ref" : "#/definitions/ReferrerPolicy",
          "description" : "Determines whether CloudFront includes the ``Referrer-Policy`` HTTP response header and the header's value.\n For more information about the ``Referrer-Policy`` HTTP response header, see [Referrer-Policy](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Referrer-Policy) in the MDN Web Docs."
        },
        "StrictTransportSecurity" : {
          "$ref" : "#/definitions/StrictTransportSecurity",
          "description" : "Determines whether CloudFront includes the ``Strict-Transport-Security`` HTTP response header and the header's value.\n For more information about the ``Strict-Transport-Security`` HTTP response header, see [Security headers](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/understanding-response-headers-policies.html#understanding-response-headers-policies-security) in the *Amazon CloudFront Developer Guide* and [Strict-Transport-Security](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Strict-Transport-Security) in the MDN Web Docs."
        },
        "XSSProtection" : {
          "$ref" : "#/definitions/XSSProtection",
          "description" : "Determines whether CloudFront includes the ``X-XSS-Protection`` HTTP response header and the header's value.\n For more information about the ``X-XSS-Protection`` HTTP response header, see [X-XSS-Protection](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/X-XSS-Protection) in the MDN Web Docs."
        }
      },
      "required" : [ ],
      "type" : "object",
      "description" : "A configuration for a set of security-related HTTP response headers. CloudFront adds these headers to HTTP responses that it sends for requests that match a cache behavior associated with this response headers policy."
    },
    "ServerTimingHeadersConfig" : {
      "additionalProperties" : False,
      "properties" : {
        "Enabled" : {
          "type" : "boolean",
          "description" : "A Boolean that determines whether CloudFront adds the ``Server-Timing`` header to HTTP responses that it sends in response to requests that match a cache behavior that's associated with this response headers policy."
        },
        "SamplingRate" : {
          "maximum" : 100,
          "minimum" : 0,
          "multipleOf" : 1.0E-4,
          "type" : "number",
          "description" : "A number 0–100 (inclusive) that specifies the percentage of responses that you want CloudFront to add the ``Server-Timing`` header to. When you set the sampling rate to 100, CloudFront adds the ``Server-Timing`` header to the HTTP response for every request that matches the cache behavior that this response headers policy is attached to. When you set it to 50, CloudFront adds the header to 50% of the responses for requests that match the cache behavior. You can set the sampling rate to any number 0–100 with up to four decimal places."
        }
      },
      "required" : [ "Enabled" ],
      "type" : "object",
      "description" : "A configuration for enabling the ``Server-Timing`` header in HTTP responses sent from CloudFront."
    },
    "StrictTransportSecurity" : {
      "additionalProperties" : False,
      "properties" : {
        "AccessControlMaxAgeSec" : {
          "type" : "integer",
          "description" : "A number that CloudFront uses as the value for the ``max-age`` directive in the ``Strict-Transport-Security`` HTTP response header."
        },
        "IncludeSubdomains" : {
          "type" : "boolean",
          "description" : "A Boolean that determines whether CloudFront includes the ``includeSubDomains`` directive in the ``Strict-Transport-Security`` HTTP response header."
        },
        "Override" : {
          "type" : "boolean",
          "description" : "A Boolean that determines whether CloudFront overrides the ``Strict-Transport-Security`` HTTP response header received from the origin with the one specified in this response headers policy."
        },
        "Preload" : {
          "type" : "boolean",
          "description" : "A Boolean that determines whether CloudFront includes the ``preload`` directive in the ``Strict-Transport-Security`` HTTP response header."
        }
      },
      "required" : [ "Override", "AccessControlMaxAgeSec" ],
      "type" : "object",
      "description" : "Determines whether CloudFront includes the ``Strict-Transport-Security`` HTTP response header and the header's value.\n For more information about the ``Strict-Transport-Security`` HTTP response header, see [Strict-Transport-Security](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Strict-Transport-Security) in the MDN Web Docs."
    },
    "XSSProtection" : {
      "additionalProperties" : False,
      "properties" : {
        "ModeBlock" : {
          "type" : "boolean",
          "description" : "A Boolean that determines whether CloudFront includes the ``mode=block`` directive in the ``X-XSS-Protection`` header.\n For more information about this directive, see [X-XSS-Protection](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/X-XSS-Protection) in the MDN Web Docs."
        },
        "Override" : {
          "type" : "boolean",
          "description" : "A Boolean that determines whether CloudFront overrides the ``X-XSS-Protection`` HTTP response header received from the origin with the one specified in this response headers policy."
        },
        "Protection" : {
          "type" : "boolean",
          "description" : "A Boolean that determines the value of the ``X-XSS-Protection`` HTTP response header. When this setting is ``True``, the value of the ``X-XSS-Protection`` header is ``1``. When this setting is ``False``, the value of the ``X-XSS-Protection`` header is ``0``.\n For more information about these settings, see [X-XSS-Protection](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/X-XSS-Protection) in the MDN Web Docs."
        },
        "ReportUri" : {
          "type" : "string",
          "description" : "A reporting URI, which CloudFront uses as the value of the ``report`` directive in the ``X-XSS-Protection`` header.\n You cannot specify a ``ReportUri`` when ``ModeBlock`` is ``True``.\n For more information about using a reporting URL, see [X-XSS-Protection](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/X-XSS-Protection) in the MDN Web Docs."
        }
      },
      "required" : [ "Override", "Protection" ],
      "type" : "object",
      "description" : "Determines whether CloudFront includes the ``X-XSS-Protection`` HTTP response header and the header's value.\n For more information about the ``X-XSS-Protection`` HTTP response header, see [X-XSS-Protection](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/X-XSS-Protection) in the MDN Web Docs."
    }
  },
  "description" : "A response headers policy.\n A response headers policy contains information about a set of HTTP response headers.\n After you create a response headers policy, you can use its ID to attach it to one or more cache behaviors in a CloudFront distribution. When it's attached to a cache behavior, the response headers policy affects the HTTP headers that CloudFront includes in HTTP responses to requests that match the cache behavior. CloudFront adds or removes response headers according to the configuration of the response headers policy.\n For more information, see [Adding or removing HTTP headers in CloudFront responses](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/modifying-response-headers.html) in the *Amazon CloudFront Developer Guide*.",
  "handlers" : {
    "create" : {
      "permissions" : [ "cloudfront:CreateResponseHeadersPolicy" ]
    },
    "delete" : {
      "permissions" : [ "cloudfront:DeleteResponseHeadersPolicy", "cloudfront:GetResponseHeadersPolicy" ]
    },
    "list" : {
      "permissions" : [ "cloudfront:ListResponseHeadersPolicies" ]
    },
    "read" : {
      "permissions" : [ "cloudfront:GetResponseHeadersPolicy" ]
    },
    "update" : {
      "permissions" : [ "cloudfront:UpdateResponseHeadersPolicy", "cloudfront:GetResponseHeadersPolicy" ]
    }
  },
  "primaryIdentifier" : [ "/properties/Id" ],
  "properties" : {
    "Id" : {
      "type" : "string",
      "description" : ""
    },
    "LastModifiedTime" : {
      "type" : "string",
      "description" : ""
    },
    "ResponseHeadersPolicyConfig" : {
      "$ref" : "#/definitions/ResponseHeadersPolicyConfig",
      "description" : "A response headers policy configuration."
    }
  },
  "readOnlyProperties" : [ "/properties/Id", "/properties/LastModifiedTime" ],
  "required" : [ "ResponseHeadersPolicyConfig" ],
  "tagging" : {
    "cloudFormationSystemTags" : False,
    "tagOnCreate" : False,
    "tagUpdatable" : False,
    "taggable" : False
  },
  "typeName" : "AWS::CloudFront::ResponseHeadersPolicy"
}