SCHEMA = {
  "typeName" : "AWS::CloudTrail::EventDataStore",
  "description" : "A storage lake of event data against which you can run complex SQL-based queries. An event data store can include events that you have logged on your account from the last 7 to 2557 or 3653 days (about seven or ten years) depending on the selected BillingMode.",
  "sourceUrl" : "https://github.com/aws-cloudformation/aws-cloudformation-resource-providers-cloudtrail.git",
  "definitions" : {
    "AdvancedFieldSelector" : {
      "description" : "A single selector statement in an advanced event selector.",
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "Field" : {
          "description" : "A field in an event record on which to filter events to be logged. Supported fields include readOnly, eventCategory, eventSource (for management events), eventName, resources.type, and resources.ARN.",
          "type" : "string",
          "pattern" : "([\\w|\\d|\\.|_]+)",
          "minLength" : 1,
          "maxLength" : 1000
        },
        "Equals" : {
          "description" : "An operator that includes events that match the exact value of the event record field specified as the value of Field. This is the only valid operator that you can use with the readOnly, eventCategory, and resources.type fields.",
          "type" : "array",
          "uniqueItems" : True,
          "insertionOrder" : False,
          "minItems" : 1,
          "items" : {
            "type" : "string",
            "pattern" : "(.+)",
            "minLength" : 1,
            "maxLength" : 2048
          }
        },
        "StartsWith" : {
          "description" : "An operator that includes events that match the first few characters of the event record field specified as the value of Field.",
          "type" : "array",
          "uniqueItems" : True,
          "insertionOrder" : False,
          "minItems" : 1,
          "items" : {
            "type" : "string",
            "pattern" : "(.+)",
            "minLength" : 1,
            "maxLength" : 2048
          }
        },
        "EndsWith" : {
          "description" : "An operator that includes events that match the last few characters of the event record field specified as the value of Field.",
          "type" : "array",
          "uniqueItems" : True,
          "insertionOrder" : False,
          "minItems" : 1,
          "items" : {
            "type" : "string",
            "pattern" : "(.+)",
            "minLength" : 1,
            "maxLength" : 2048
          }
        },
        "NotEquals" : {
          "description" : "An operator that excludes events that match the exact value of the event record field specified as the value of Field.",
          "type" : "array",
          "uniqueItems" : True,
          "insertionOrder" : False,
          "minItems" : 1,
          "items" : {
            "type" : "string",
            "pattern" : "(.+)",
            "minLength" : 1,
            "maxLength" : 2048
          }
        },
        "NotStartsWith" : {
          "description" : "An operator that excludes events that match the first few characters of the event record field specified as the value of Field.",
          "type" : "array",
          "uniqueItems" : True,
          "insertionOrder" : False,
          "minItems" : 1,
          "items" : {
            "type" : "string",
            "pattern" : "(.+)",
            "minLength" : 1,
            "maxLength" : 2048
          }
        },
        "NotEndsWith" : {
          "description" : "An operator that excludes events that match the last few characters of the event record field specified as the value of Field.",
          "type" : "array",
          "uniqueItems" : True,
          "insertionOrder" : False,
          "minItems" : 1,
          "items" : {
            "type" : "string",
            "pattern" : "(.+)",
            "minLength" : 1,
            "maxLength" : 2048
          }
        }
      },
      "required" : [ "Field" ]
    },
    "AdvancedEventSelector" : {
      "description" : "Advanced event selectors let you create fine-grained selectors for the following AWS CloudTrail event record ﬁelds. They help you control costs by logging only those events that are important to you.",
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "Name" : {
          "description" : "An optional, descriptive name for an advanced event selector, such as \"Log data events for only two S3 buckets\".",
          "type" : "string",
          "minLength" : 1,
          "maxLength" : 1000
        },
        "FieldSelectors" : {
          "description" : "Contains all selector statements in an advanced event selector.",
          "type" : "array",
          "uniqueItems" : True,
          "insertionOrder" : False,
          "minItems" : 1,
          "items" : {
            "$ref" : "#/definitions/AdvancedFieldSelector"
          }
        }
      },
      "required" : [ "FieldSelectors" ]
    },
    "Tag" : {
      "description" : "An arbitrary set of tags (key-value pairs) for this event data store.",
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "Key" : {
          "description" : "The key name of the tag. You can specify a value that is 1 to 127 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -.",
          "type" : "string"
        },
        "Value" : {
          "description" : "The value for the tag. You can specify a value that is 1 to 255 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -.",
          "type" : "string"
        }
      },
      "required" : [ "Value", "Key" ]
    },
    "InsightSelector" : {
      "description" : "A string that contains Insights types that are logged on an event data store.",
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "InsightType" : {
          "description" : "The type of Insights to log on an event data store.",
          "type" : "string"
        }
      }
    },
    "Timestamp" : {
      "type" : "string"
    }
  },
  "properties" : {
    "AdvancedEventSelectors" : {
      "description" : "The advanced event selectors that were used to select events for the data store.",
      "type" : "array",
      "items" : {
        "$ref" : "#/definitions/AdvancedEventSelector"
      },
      "uniqueItems" : True,
      "insertionOrder" : False
    },
    "CreatedTimestamp" : {
      "description" : "The timestamp of the event data store's creation.",
      "$ref" : "#/definitions/Timestamp"
    },
    "EventDataStoreArn" : {
      "description" : "The ARN of the event data store.",
      "type" : "string"
    },
    "FederationEnabled" : {
      "description" : "Indicates whether federation is enabled on an event data store.",
      "type" : "boolean"
    },
    "FederationRoleArn" : {
      "description" : "The ARN of the role used for event data store federation.",
      "type" : "string"
    },
    "MultiRegionEnabled" : {
      "description" : "Indicates whether the event data store includes events from all regions, or only from the region in which it was created.",
      "type" : "boolean"
    },
    "Name" : {
      "description" : "The name of the event data store.",
      "type" : "string"
    },
    "OrganizationEnabled" : {
      "description" : "Indicates that an event data store is collecting logged events for an organization.",
      "type" : "boolean"
    },
    "BillingMode" : {
      "description" : "The mode that the event data store will use to charge for event storage.",
      "type" : "string"
    },
    "RetentionPeriod" : {
      "description" : "The retention period, in days.",
      "type" : "integer"
    },
    "Status" : {
      "description" : "The status of an event data store. Values are STARTING_INGESTION, ENABLED, STOPPING_INGESTION, STOPPED_INGESTION and PENDING_DELETION.",
      "type" : "string"
    },
    "TerminationProtectionEnabled" : {
      "description" : "Indicates whether the event data store is protected from termination.",
      "type" : "boolean"
    },
    "UpdatedTimestamp" : {
      "description" : "The timestamp showing when an event data store was updated, if applicable. UpdatedTimestamp is always either the same or newer than the time shown in CreatedTimestamp.",
      "$ref" : "#/definitions/Timestamp"
    },
    "KmsKeyId" : {
      "description" : "Specifies the KMS key ID to use to encrypt the events delivered by CloudTrail. The value can be an alias name prefixed by 'alias/', a fully specified ARN to an alias, a fully specified ARN to a key, or a globally unique identifier.",
      "type" : "string"
    },
    "Tags" : {
      "type" : "array",
      "uniqueItems" : False,
      "insertionOrder" : False,
      "items" : {
        "$ref" : "#/definitions/Tag"
      }
    },
    "InsightSelectors" : {
      "description" : "Lets you enable Insights event logging by specifying the Insights selectors that you want to enable on an existing event data store. Both InsightSelectors and InsightsDestination need to have a value in order to enable Insights events on an event data store.",
      "type" : "array",
      "items" : {
        "$ref" : "#/definitions/InsightSelector"
      },
      "uniqueItems" : True,
      "insertionOrder" : False
    },
    "InsightsDestination" : {
      "description" : "Specifies the ARN of the event data store that will collect Insights events. Both InsightSelectors and InsightsDestination need to have a value in order to enable Insights events on an event data store",
      "type" : "string"
    },
    "IngestionEnabled" : {
      "description" : "Indicates whether the event data store is ingesting events.",
      "type" : "boolean"
    }
  },
  "required" : [ ],
  "readOnlyProperties" : [ "/properties/EventDataStoreArn", "/properties/CreatedTimestamp", "/properties/UpdatedTimestamp", "/properties/Status", "/properties/FederationStatus" ],
  "primaryIdentifier" : [ "/properties/EventDataStoreArn" ],
  "propertyTransform" : {
    "/properties/KmsKeyId" : "$join([\"arn:(aws)[-]{0,1}[a-z]{0,2}[-]{0,1}[a-z]{0,3}:kms:[a-z]{2}[-]{1}[a-z]{3,10}[-]{0,1}[a-z]{0,10}[-]{1}[1-3]{1}:[0-9]{12}[:]{1}key\\/\", KmsKeyId])"
  },
  "handlers" : {
    "create" : {
      "permissions" : [ "CloudTrail:CreateEventDataStore", "CloudTrail:AddTags", "CloudTrail:PutInsightSelectors", "CloudTrail:EnableFederation", "CloudTrail:GetEventDataStore", "iam:PassRole", "iam:GetRole", "iam:CreateServiceLinkedRole", "organizations:DescribeOrganization", "organizations:ListAWSServiceAccessForOrganization", "kms:GenerateDataKey", "kms:Decrypt", "glue:CreateDatabase", "glue:CreateTable", "glue:PassConnection", "lakeformation:RegisterResource" ]
    },
    "read" : {
      "permissions" : [ "CloudTrail:GetEventDataStore", "CloudTrail:ListEventDataStores", "CloudTrail:GetInsightSelectors", "CloudTrail:ListTags" ]
    },
    "update" : {
      "permissions" : [ "CloudTrail:UpdateEventDataStore", "CloudTrail:RestoreEventDataStore", "CloudTrail:AddTags", "CloudTrail:RemoveTags", "CloudTrail:StartEventDataStoreIngestion", "CloudTrail:StopEventDataStoreIngestion", "CloudTrail:GetEventDataStore", "CloudTrail:PutInsightSelectors", "CloudTrail:GetInsightSelectors", "CloudTrail:EnableFederation", "CloudTrail:DisableFederation", "iam:PassRole", "iam:GetRole", "iam:CreateServiceLinkedRole", "organizations:DescribeOrganization", "organizations:ListAWSServiceAccessForOrganization", "glue:CreateDatabase", "glue:CreateTable", "glue:PassConnection", "lakeformation:RegisterResource", "glue:DeleteTable", "lakeformation:DeregisterResource", "kms:DescribeKey" ]
    },
    "delete" : {
      "permissions" : [ "CloudTrail:DeleteEventDataStore", "CloudTrail:GetEventDataStore", "CloudTrail:DisableFederation", "glue:DeleteTable", "lakeformation:DeregisterResource" ]
    },
    "list" : {
      "permissions" : [ "CloudTrail:ListEventDataStores", "CloudTrail:GetEventDataStore", "CloudTrail:GetInsightSelectors", "CloudTrail:ListTags" ]
    }
  },
  "additionalProperties" : False,
  "tagging" : {
    "taggable" : True,
    "tagOnCreate" : True,
    "tagUpdatable" : True,
    "cloudFormationSystemTags" : False,
    "tagProperty" : "/properties/Tags",
    "permissions" : [ "CloudTrail:AddTags", "CloudTrail:RemoveTags", "CloudTrail:ListTags" ]
  }
}