SCHEMA = {
  "typeName" : "AWS::Cognito::ManagedLoginBranding",
  "description" : "Resource Type definition for AWS::Cognito::ManagedLoginBranding",
  "sourceUrl" : "https://github.com/aws-cloudformation/aws-cloudformation-rpdk.git",
  "definitions" : {
    "ManagedLoginBrandingIdType" : {
      "type" : "string",
      "pattern" : "^[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[4][0-9a-fA-F]{3}-[89abAB][0-9a-fA-F]{3}-[0-9a-fA-F]{12}$"
    },
    "CategoryType" : {
      "type" : "string",
      "enum" : [ "FAVICON_ICO", "FAVICON_SVG", "EMAIL_GRAPHIC", "SMS_GRAPHIC", "AUTH_APP_GRAPHIC", "PASSWORD_GRAPHIC", "PASSKEY_GRAPHIC", "PAGE_HEADER_LOGO", "PAGE_HEADER_BACKGROUND", "PAGE_FOOTER_LOGO", "PAGE_FOOTER_BACKGROUND", "PAGE_BACKGROUND", "FORM_BACKGROUND", "FORM_LOGO", "IDP_BUTTON_ICON" ]
    },
    "ColorModeType" : {
      "type" : "string",
      "enum" : [ "LIGHT", "DARK", "DYNAMIC" ]
    },
    "ExtensionType" : {
      "type" : "string",
      "enum" : [ "ICO", "JPEG", "PNG", "SVG", "WEBP" ]
    },
    "BytesType" : {
      "type" : "string",
      "maxLength" : 1000000
    },
    "ResourceIdType" : {
      "type" : "string",
      "pattern" : "^[\\w\\- ]+$",
      "minLength" : 1,
      "maxLength" : 40
    },
    "AssetType" : {
      "type" : "object",
      "properties" : {
        "Category" : {
          "$ref" : "#/definitions/CategoryType"
        },
        "ColorMode" : {
          "$ref" : "#/definitions/ColorModeType"
        },
        "Extension" : {
          "$ref" : "#/definitions/ExtensionType"
        },
        "Bytes" : {
          "$ref" : "#/definitions/BytesType"
        },
        "ResourceId" : {
          "$ref" : "#/definitions/ResourceIdType"
        }
      },
      "additionalProperties" : False,
      "required" : [ "Category", "ColorMode", "Extension" ]
    },
    "AssetList" : {
      "type" : "array",
      "items" : {
        "$ref" : "#/definitions/AssetType"
      }
    }
  },
  "properties" : {
    "UserPoolId" : {
      "type" : "string"
    },
    "ClientId" : {
      "type" : "string"
    },
    "UseCognitoProvidedValues" : {
      "type" : "boolean"
    },
    "Settings" : {
      "type" : "object"
    },
    "Assets" : {
      "$ref" : "#/definitions/AssetList"
    },
    "ManagedLoginBrandingId" : {
      "$ref" : "#/definitions/ManagedLoginBrandingIdType"
    },
    "ReturnMergedResources" : {
      "type" : "boolean"
    }
  },
  "tagging" : {
    "taggable" : False,
    "tagOnCreate" : False,
    "tagUpdatable" : False,
    "cloudFormationSystemTags" : False
  },
  "additionalProperties" : False,
  "required" : [ "UserPoolId" ],
  "createOnlyProperties" : [ "/properties/UserPoolId", "/properties/ClientId" ],
  "readOnlyProperties" : [ "/properties/ManagedLoginBrandingId" ],
  "primaryIdentifier" : [ "/properties/UserPoolId", "/properties/ManagedLoginBrandingId" ],
  "writeOnlyProperties" : [ "/properties/ClientId", "/properties/ReturnMergedResources" ],
  "handlers" : {
    "create" : {
      "permissions" : [ "cognito-idp:CreateManagedLoginBranding" ],
      "timeoutInMinutes" : 2
    },
    "read" : {
      "permissions" : [ "cognito-idp:DescribeManagedLoginBranding" ],
      "timeoutInMinutes" : 2
    },
    "update" : {
      "permissions" : [ "cognito-idp:UpdateManagedLoginBranding" ],
      "timeoutInMinutes" : 2
    },
    "delete" : {
      "permissions" : [ "cognito-idp:DeleteManagedLoginBranding" ],
      "timeoutInMinutes" : 2
    }
  }
}