SCHEMA = {
  "typeName" : "AWS::Config::AggregationAuthorization",
  "description" : "Resource Type definition for AWS::Config::AggregationAuthorization",
  "sourceUrl" : "https://github.com/aws-cloudformation/aws-cloudformation-resource-providers-config.git",
  "additionalProperties" : False,
  "properties" : {
    "AuthorizedAccountId" : {
      "description" : "The 12-digit account ID of the account authorized to aggregate data.",
      "type" : "string",
      "pattern" : "^\\d{12}$"
    },
    "AuthorizedAwsRegion" : {
      "description" : "The region authorized to collect aggregated data.",
      "type" : "string",
      "minLength" : 1,
      "maxLength" : 64
    },
    "AggregationAuthorizationArn" : {
      "description" : "The ARN of the AggregationAuthorization.",
      "type" : "string"
    },
    "Tags" : {
      "description" : "The tags for the AggregationAuthorization.",
      "type" : "array",
      "maxItems" : 50,
      "uniqueItems" : True,
      "items" : {
        "$ref" : "#/definitions/Tag"
      }
    }
  },
  "definitions" : {
    "Tag" : {
      "description" : "A key-value pair to associate with a resource.",
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "Key" : {
          "type" : "string",
          "description" : "The key name of the tag. You can specify a value that is 1 to 127 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -. ",
          "minLength" : 1,
          "maxLength" : 128
        },
        "Value" : {
          "type" : "string",
          "description" : "The value for the tag. You can specify a value that is 1 to 255 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -. ",
          "minLength" : 0,
          "maxLength" : 256
        }
      },
      "required" : [ "Key", "Value" ]
    }
  },
  "required" : [ "AuthorizedAccountId", "AuthorizedAwsRegion" ],
  "readOnlyProperties" : [ "/properties/AggregationAuthorizationArn" ],
  "createOnlyProperties" : [ "/properties/AuthorizedAccountId", "/properties/AuthorizedAwsRegion" ],
  "tagging" : {
    "taggable" : True,
    "tagOnCreate" : True,
    "tagUpdatable" : True,
    "cloudFormationSystemTags" : False,
    "tagProperty" : "/properties/Tags",
    "permissions" : [ "config:TagResource", "config:UntagResource", "config:ListTagsForResource" ]
  },
  "primaryIdentifier" : [ "/properties/AuthorizedAccountId", "/properties/AuthorizedAwsRegion" ],
  "handlers" : {
    "create" : {
      "permissions" : [ "config:DescribeAggregationAuthorizations", "config:PutAggregationAuthorization", "config:TagResource" ]
    },
    "update" : {
      "permissions" : [ "config:DescribeAggregationAuthorizations", "config:TagResource", "config:UntagResource", "config:ListTagsForResource" ]
    },
    "read" : {
      "permissions" : [ "config:DescribeAggregationAuthorizations", "config:ListTagsForResource" ]
    },
    "delete" : {
      "permissions" : [ "config:DescribeAggregationAuthorizations", "config:DeleteAggregationAuthorization", "config:UntagResource" ]
    },
    "list" : {
      "permissions" : [ "config:DescribeAggregationAuthorizations" ]
    }
  }
}