SCHEMA = {
  "typeName" : "AWS::Connect::TrafficDistributionGroup",
  "description" : "Resource Type definition for AWS::Connect::TrafficDistributionGroup",
  "sourceUrl" : "https://github.com/aws-cloudformation/aws-cloudformation-resource-providers-connect",
  "definitions" : {
    "Tag" : {
      "description" : "A key-value pair to associate with a resource.",
      "type" : "object",
      "properties" : {
        "Key" : {
          "type" : "string",
          "description" : "The key name of the tag. You can specify a value that is 1 to 128 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -.",
          "minLength" : 1,
          "maxLength" : 128
        },
        "Value" : {
          "type" : "string",
          "description" : "The value for the tag. You can specify a value that is 1 to 256 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -.",
          "minLength" : 1,
          "maxLength" : 256
        }
      },
      "required" : [ "Key", "Value" ],
      "additionalProperties" : False
    }
  },
  "properties" : {
    "InstanceArn" : {
      "description" : "The identifier of the Amazon Connect instance that has been replicated.",
      "type" : "string",
      "pattern" : "^arn:(aws|aws-us-gov):connect:[a-z]{2}-[a-z]+-[0-9]{1}:[0-9]{1,20}:instance/[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}$",
      "minLength" : 1,
      "maxLength" : 250
    },
    "TrafficDistributionGroupArn" : {
      "description" : "The identifier of the traffic distribution group.",
      "type" : "string",
      "pattern" : "^arn:(aws|aws-us-gov):connect:[a-z]{2}-[a-z]+-[0-9]{1}:[0-9]{1,20}:traffic-distribution-group/[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}$"
    },
    "Description" : {
      "description" : "A description for the traffic distribution group.",
      "type" : "string",
      "pattern" : "(^[\\S].*[\\S]$)|(^[\\S]$)",
      "minLength" : 1,
      "maxLength" : 250
    },
    "Name" : {
      "description" : "The name for the traffic distribution group.",
      "type" : "string",
      "pattern" : "(^[\\S].*[\\S]$)|(^[\\S]$)",
      "minLength" : 1,
      "maxLength" : 128
    },
    "Status" : {
      "description" : "The status of the traffic distribution group.",
      "type" : "string",
      "enum" : [ "CREATION_IN_PROGRESS", "ACTIVE", "CREATION_FAILED", "PENDING_DELETION", "DELETION_FAILED", "UPDATE_IN_PROGRESS" ]
    },
    "Tags" : {
      "type" : "array",
      "maxItems" : 50,
      "uniqueItems" : True,
      "insertionOrder" : False,
      "description" : "One or more tags.",
      "items" : {
        "$ref" : "#/definitions/Tag"
      }
    },
    "IsDefault" : {
      "description" : "If this is the default traffic distribution group.",
      "type" : "boolean"
    }
  },
  "tagging" : {
    "taggable" : True,
    "tagOnCreate" : True,
    "tagUpdatable" : True,
    "cloudFormationSystemTags" : True,
    "tagProperty" : "/properties/Tags",
    "permissions" : [ "connect:TagResource", "connect:UntagResource" ]
  },
  "additionalProperties" : False,
  "required" : [ "InstanceArn", "Name" ],
  "readOnlyProperties" : [ "/properties/TrafficDistributionGroupArn", "/properties/Status", "/properties/IsDefault" ],
  "createOnlyProperties" : [ "/properties/Description", "/properties/Name" ],
  "primaryIdentifier" : [ "/properties/TrafficDistributionGroupArn" ],
  "handlers" : {
    "create" : {
      "permissions" : [ "connect:CreateTrafficDistributionGroup", "connect:DescribeTrafficDistributionGroup", "connect:TagResource" ]
    },
    "read" : {
      "permissions" : [ "connect:DescribeTrafficDistributionGroup" ]
    },
    "update" : {
      "permissions" : [ "connect:TagResource", "connect:UntagResource" ]
    },
    "delete" : {
      "permissions" : [ "connect:DeleteTrafficDistributionGroup", "connect:DescribeTrafficDistributionGroup", "connect:UntagResource" ]
    },
    "list" : {
      "permissions" : [ "connect:ListTrafficDistributionGroups" ]
    }
  }
}