SCHEMA = {
  "typeName" : "AWS::DataBrew::Project",
  "description" : "Resource schema for AWS::DataBrew::Project.",
  "sourceUrl" : "https://github.com/aws-cloudformation/aws-cloudformation-resource-providers-databrew.git",
  "properties" : {
    "DatasetName" : {
      "description" : "Dataset name",
      "type" : "string",
      "minLength" : 1,
      "maxLength" : 255
    },
    "Name" : {
      "description" : "Project name",
      "type" : "string",
      "minLength" : 1,
      "maxLength" : 255
    },
    "RecipeName" : {
      "description" : "Recipe name",
      "type" : "string",
      "minLength" : 1,
      "maxLength" : 255
    },
    "RoleArn" : {
      "description" : "Role arn",
      "type" : "string"
    },
    "Sample" : {
      "description" : "Sample",
      "$ref" : "#/definitions/Sample"
    },
    "Tags" : {
      "type" : "array",
      "insertionOrder" : False,
      "uniqueItems" : False,
      "items" : {
        "$ref" : "#/definitions/Tag"
      }
    }
  },
  "definitions" : {
    "Sample" : {
      "type" : "object",
      "properties" : {
        "Size" : {
          "description" : "Sample size",
          "minimum" : 1,
          "type" : "integer"
        },
        "Type" : {
          "description" : "Sample type",
          "enum" : [ "FIRST_N", "LAST_N", "RANDOM" ],
          "type" : "string"
        }
      },
      "additionalProperties" : False,
      "required" : [ "Type" ]
    },
    "Tag" : {
      "description" : "A key-value pair to associate with a resource.",
      "type" : "object",
      "properties" : {
        "Key" : {
          "type" : "string",
          "minLength" : 1,
          "maxLength" : 128
        },
        "Value" : {
          "type" : "string",
          "minLength" : 0,
          "maxLength" : 256
        }
      },
      "additionalProperties" : False,
      "required" : [ "Value", "Key" ]
    }
  },
  "additionalProperties" : False,
  "required" : [ "DatasetName", "Name", "RecipeName", "RoleArn" ],
  "primaryIdentifier" : [ "/properties/Name" ],
  "createOnlyProperties" : [ "/properties/Name" ],
  "tagging" : {
    "taggable" : True,
    "tagOnCreate" : True,
    "tagUpdatable" : True,
    "cloudFormationSystemTags" : True,
    "tagProperty" : "/properties/Tags",
    "permissions" : [ "databrew:TagResource", "databrew:UntagResource", "databrew:ListTagsForResource" ]
  },
  "handlers" : {
    "create" : {
      "permissions" : [ "databrew:CreateProject", "databrew:DescribeProject", "databrew:TagResource", "databrew:UntagResource", "iam:PassRole" ]
    },
    "read" : {
      "permissions" : [ "databrew:DescribeProject", "iam:ListRoles" ]
    },
    "update" : {
      "permissions" : [ "databrew:UpdateProject", "databrew:TagResource", "databrew:UntagResource", "iam:PassRole" ]
    },
    "delete" : {
      "permissions" : [ "databrew:DeleteProject" ]
    },
    "list" : {
      "permissions" : [ "databrew:ListProjects", "databrew:ListTagsForResource", "iam:ListRoles" ]
    }
  }
}