SCHEMA = {
  "typeName" : "AWS::EC2::CapacityReservation",
  "description" : "Resource Type definition for AWS::EC2::CapacityReservation",
  "additionalProperties" : False,
  "properties" : {
    "Tenancy" : {
      "type" : "string"
    },
    "EndDateType" : {
      "type" : "string"
    },
    "TagSpecifications" : {
      "type" : "array",
      "insertionOrder" : False,
      "uniqueItems" : False,
      "items" : {
        "$ref" : "#/definitions/TagSpecification"
      }
    },
    "AvailabilityZone" : {
      "type" : "string"
    },
    "TotalInstanceCount" : {
      "type" : "integer"
    },
    "EndDate" : {
      "type" : "string"
    },
    "EbsOptimized" : {
      "type" : "boolean"
    },
    "OutPostArn" : {
      "type" : "string"
    },
    "InstanceCount" : {
      "type" : "integer"
    },
    "PlacementGroupArn" : {
      "type" : "string"
    },
    "AvailableInstanceCount" : {
      "type" : "integer"
    },
    "InstancePlatform" : {
      "type" : "string"
    },
    "Id" : {
      "type" : "string"
    },
    "InstanceType" : {
      "type" : "string"
    },
    "EphemeralStorage" : {
      "type" : "boolean"
    },
    "InstanceMatchCriteria" : {
      "type" : "string"
    },
    "UnusedReservationBillingOwnerId" : {
      "type" : "string"
    },
    "AvailabilityZoneId" : {
      "type" : "string"
    },
    "StartDate" : {
      "type" : "string"
    },
    "CapacityReservationArn" : {
      "type" : "string"
    },
    "CreateDate" : {
      "type" : "string"
    },
    "State" : {
      "type" : "string"
    },
    "OwnerId" : {
      "type" : "string"
    },
    "DeliveryPreference" : {
      "type" : "string"
    },
    "CapacityReservationFleetId" : {
      "type" : "string"
    },
    "ReservationType" : {
      "type" : "string"
    },
    "CapacityAllocationSet" : {
      "type" : "array",
      "insertionOrder" : False,
      "uniqueItems" : False,
      "items" : {
        "$ref" : "#/definitions/CapacityAllocation"
      }
    },
    "CommitmentInfo" : {
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "CommitmentEndDate" : {
          "type" : "string"
        },
        "CommittedInstanceCount" : {
          "type" : "integer"
        }
      }
    }
  },
  "definitions" : {
    "Tag" : {
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "Value" : {
          "type" : "string"
        },
        "Key" : {
          "type" : "string"
        }
      },
      "required" : [ "Value", "Key" ]
    },
    "TagSpecification" : {
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "ResourceType" : {
          "type" : "string"
        },
        "Tags" : {
          "type" : "array",
          "insertionOrder" : False,
          "uniqueItems" : False,
          "items" : {
            "$ref" : "#/definitions/Tag"
          }
        }
      }
    },
    "CapacityAllocation" : {
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "AllocationType" : {
          "type" : "string"
        },
        "Count" : {
          "type" : "integer"
        }
      }
    }
  },
  "required" : [ "InstanceCount", "InstancePlatform", "InstanceType" ],
  "createOnlyProperties" : [ "/properties/Tenancy", "/properties/InstancePlatform", "/properties/InstanceType", "/properties/AvailabilityZone", "/properties/TagSpecifications", "/properties/OutPostArn", "/properties/EphemeralStorage", "/properties/EbsOptimized", "/properties/PlacementGroupArn", "/properties/AvailabilityZoneId" ],
  "primaryIdentifier" : [ "/properties/Id" ],
  "readOnlyProperties" : [ "/properties/Id", "/properties/AvailableInstanceCount", "/properties/TotalInstanceCount", "/properties/StartDate", "/properties/CapacityReservationArn", "/properties/CreateDate", "/properties/State", "/properties/OwnerId", "/properties/ReservationType", "/properties/CapacityAllocationSet", "/properties/CommitmentInfo", "/properties/DeliveryPreference", "/properties/CapacityReservationFleetId" ],
  "writeOnlyProperties" : [ "/properties/UnusedReservationBillingOwnerId" ],
  "tagging" : {
    "taggable" : True,
    "tagOnCreate" : True,
    "tagUpdatable" : True,
    "cloudFormationSystemTags" : True,
    "tagProperty" : "/properties/TagSpecifications",
    "permissions" : [ "ec2:CreateTags", "ec2:DeleteTags" ]
  },
  "handlers" : {
    "create" : {
      "permissions" : [ "ec2:CreateCapacityReservation", "ec2:DescribeCapacityReservations", "ec2:CancelCapacityReservation", "ec2:CreateTags" ]
    },
    "delete" : {
      "permissions" : [ "ec2:CreateCapacityReservation", "ec2:DescribeCapacityReservations", "ec2:CancelCapacityReservation", "ec2:DeleteTags" ]
    },
    "list" : {
      "permissions" : [ "ec2:DescribeCapacityReservations" ]
    },
    "read" : {
      "permissions" : [ "ec2:DescribeCapacityReservations" ]
    },
    "update" : {
      "permissions" : [ "ec2:ModifyCapacityReservation", "ec2:CreateCapacityReservation", "ec2:DescribeCapacityReservations", "ec2:CancelCapacityReservation", "ec2:AssociateCapacityReservationBillingOwner", "ec2:CreateTags", "ec2:DeleteTags" ]
    }
  }
}