SCHEMA = {
  "typeName" : "AWS::EC2::CapacityReservationFleet",
  "description" : "Resource Type definition for AWS::EC2::CapacityReservationFleet",
  "additionalProperties" : False,
  "taggable" : True,
  "properties" : {
    "AllocationStrategy" : {
      "type" : "string"
    },
    "TagSpecifications" : {
      "type" : "array",
      "insertionOrder" : False,
      "uniqueItems" : False,
      "items" : {
        "$ref" : "#/definitions/TagSpecification"
      }
    },
    "InstanceTypeSpecifications" : {
      "type" : "array",
      "insertionOrder" : False,
      "uniqueItems" : True,
      "maxItems" : 50,
      "items" : {
        "$ref" : "#/definitions/InstanceTypeSpecification"
      }
    },
    "TotalTargetCapacity" : {
      "type" : "integer",
      "minimum" : 1,
      "maximum" : 25000
    },
    "EndDate" : {
      "type" : "string"
    },
    "InstanceMatchCriteria" : {
      "type" : "string",
      "enum" : [ "open" ]
    },
    "CapacityReservationFleetId" : {
      "type" : "string"
    },
    "Tenancy" : {
      "type" : "string",
      "enum" : [ "default" ]
    },
    "RemoveEndDate" : {
      "type" : "boolean"
    },
    "NoRemoveEndDate" : {
      "type" : "boolean"
    }
  },
  "definitions" : {
    "InstanceTypeSpecification" : {
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "InstanceType" : {
          "type" : "string"
        },
        "InstancePlatform" : {
          "type" : "string"
        },
        "Weight" : {
          "type" : "number"
        },
        "AvailabilityZone" : {
          "type" : "string"
        },
        "AvailabilityZoneId" : {
          "type" : "string"
        },
        "EbsOptimized" : {
          "type" : "boolean"
        },
        "Priority" : {
          "type" : "integer",
          "minimum" : 0,
          "maximum" : 999
        }
      }
    },
    "Tag" : {
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "Value" : {
          "type" : "string"
        },
        "Key" : {
          "type" : "string"
        }
      },
      "required" : [ "Value", "Key" ]
    },
    "TagSpecification" : {
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "ResourceType" : {
          "type" : "string"
        },
        "Tags" : {
          "type" : "array",
          "insertionOrder" : False,
          "uniqueItems" : False,
          "items" : {
            "$ref" : "#/definitions/Tag"
          }
        }
      }
    }
  },
  "createOnlyProperties" : [ "/properties/InstanceTypeSpecifications", "/properties/AllocationStrategy", "/properties/TagSpecifications", "/properties/EndDate", "/properties/Tenancy", "/properties/InstanceMatchCriteria" ],
  "primaryIdentifier" : [ "/properties/CapacityReservationFleetId" ],
  "readOnlyProperties" : [ "/properties/CapacityReservationFleetId" ],
  "handlers" : {
    "create" : {
      "permissions" : [ "ec2:CreateCapacityReservationFleet", "ec2:ModifyCapacityReservationFleet", "ec2:DescribeCapacityReservationFleets", "ec2:CancelCapacityReservationFleets", "ec2:CreateCapacityReservation", "ec2:DescribeCapacityReservations", "ec2:CancelCapacityReservation", "ec2:DescribeInstances", "ec2:CreateTags", "iam:CreateServiceLinkedRole" ]
    },
    "delete" : {
      "permissions" : [ "ec2:CreateCapacityReservationFleet", "ec2:ModifyCapacityReservationFleet", "ec2:DescribeCapacityReservationFleets", "ec2:CancelCapacityReservationFleets", "ec2:CreateCapacityReservation", "ec2:DescribeCapacityReservations", "ec2:CancelCapacityReservation", "ec2:DeleteTags" ]
    },
    "list" : {
      "permissions" : [ "ec2:DescribeCapacityReservationFleets", "ec2:DescribeCapacityReservations", "ec2:DescribeInstances" ]
    },
    "read" : {
      "permissions" : [ "ec2:DescribeCapacityReservationFleets", "ec2:DescribeInstances", "ec2:DescribeCapacityReservations" ]
    },
    "update" : {
      "permissions" : [ "ec2:CreateCapacityReservationFleet", "ec2:ModifyCapacityReservationFleet", "ec2:DescribeCapacityReservationFleets", "ec2:CancelCapacityReservationFleets", "ec2:CreateCapacityReservation", "ec2:ModifyCapacityReservation", "ec2:DescribeCapacityReservations", "ec2:CancelCapacityReservation", "ec2:DescribeInstances", "ec2:DeleteTags" ]
    }
  }
}