SCHEMA = {
  "typeName" : "AWS::EC2::LocalGatewayRouteTableVPCAssociation",
  "description" : "Resource Type definition for Local Gateway Route Table VPC Association which describes an association between a local gateway route table and a VPC.",
  "sourceUrl" : "https://github.com/aws-cloudformation/aws-cloudformation-resource-providers-ec2-lgw.git",
  "definitions" : {
    "Tags" : {
      "type" : "array",
      "insertionOrder" : False,
      "uniqueItems" : True,
      "items" : {
        "$ref" : "#/definitions/Tag"
      }
    },
    "Tag" : {
      "type" : "object",
      "properties" : {
        "Key" : {
          "type" : "string",
          "minLength" : 1,
          "maxLength" : 127,
          "pattern" : "^(?!aws:.*)"
        },
        "Value" : {
          "type" : "string",
          "minLength" : 1,
          "maxLength" : 255,
          "pattern" : "^(?!aws:.*)"
        }
      },
      "additionalProperties" : False
    }
  },
  "properties" : {
    "LocalGatewayId" : {
      "description" : "The ID of the local gateway.",
      "type" : "string"
    },
    "LocalGatewayRouteTableId" : {
      "description" : "The ID of the local gateway route table.",
      "type" : "string"
    },
    "LocalGatewayRouteTableVpcAssociationId" : {
      "description" : "The ID of the association.",
      "type" : "string"
    },
    "State" : {
      "description" : "The state of the association.",
      "type" : "string"
    },
    "VpcId" : {
      "description" : "The ID of the VPC.",
      "type" : "string"
    },
    "Tags" : {
      "description" : "The tags for the association.",
      "$ref" : "#/definitions/Tags"
    }
  },
  "required" : [ "LocalGatewayRouteTableId", "VpcId" ],
  "createOnlyProperties" : [ "/properties/LocalGatewayRouteTableId", "/properties/VpcId" ],
  "readOnlyProperties" : [ "/properties/LocalGatewayId", "/properties/LocalGatewayRouteTableVpcAssociationId", "/properties/State" ],
  "primaryIdentifier" : [ "/properties/LocalGatewayRouteTableVpcAssociationId" ],
  "tagging" : {
    "taggable" : True,
    "tagOnCreate" : True,
    "tagUpdatable" : True,
    "cloudFormationSystemTags" : True,
    "tagProperty" : "/properties/Tags",
    "permissions" : [ "ec2:DeleteTags", "ec2:CreateTags", "ec2:DescribeTags" ]
  },
  "handlers" : {
    "create" : {
      "permissions" : [ "ec2:CreateLocalGatewayRouteTableVpcAssociation", "ec2:DescribeLocalGatewayRouteTableVpcAssociations", "ec2:CreateTags" ]
    },
    "read" : {
      "permissions" : [ "ec2:DescribeLocalGatewayRouteTableVpcAssociations", "ec2:DescribeTags" ]
    },
    "update" : {
      "permissions" : [ "ec2:DescribeLocalGatewayRouteTableVpcAssociations", "ec2:CreateTags", "ec2:DeleteTags", "ec2:DescribeTags" ]
    },
    "delete" : {
      "permissions" : [ "ec2:DeleteLocalGatewayRouteTableVpcAssociation", "ec2:DescribeLocalGatewayRouteTableVpcAssociations", "ec2:DeleteTags" ]
    },
    "list" : {
      "permissions" : [ "ec2:DescribeLocalGatewayRouteTableVpcAssociations" ]
    }
  },
  "additionalProperties" : False
}