SCHEMA = {
  "tagging" : {
    "permissions" : [ "ec2:DeleteTags", "ec2:CreateTags" ],
    "taggable" : True,
    "tagOnCreate" : True,
    "tagUpdatable" : True,
    "tagProperty" : "/properties/Tags",
    "cloudFormationSystemTags" : True
  },
  "handlers" : {
    "read" : {
      "permissions" : [ "ec2:DescribeNatGateways" ]
    },
    "create" : {
      "permissions" : [ "ec2:CreateNatGateway", "ec2:DescribeNatGateways", "ec2:CreateTags" ]
    },
    "update" : {
      "permissions" : [ "ec2:DescribeNatGateways", "ec2:CreateTags", "ec2:DeleteTags", "ec2:AssociateNatGatewayAddress", "ec2:DisassociateNatGatewayAddress", "ec2:AssignPrivateNatGatewayAddress", "ec2:UnassignPrivateNatGatewayAddress" ]
    },
    "list" : {
      "permissions" : [ "ec2:DescribeNatGateways" ]
    },
    "delete" : {
      "permissions" : [ "ec2:DeleteNatGateway", "ec2:DescribeNatGateways" ]
    }
  },
  "typeName" : "AWS::EC2::NatGateway",
  "readOnlyProperties" : [ "/properties/NatGatewayId" ],
  "description" : "Specifies a network address translation (NAT) gateway in the specified subnet. You can create either a public NAT gateway or a private NAT gateway. The default is a public NAT gateway. If you create a public NAT gateway, you must specify an elastic IP address.\n With a NAT gateway, instances in a private subnet can connect to the internet, other AWS services, or an on-premises network using the IP address of the NAT gateway. For more information, see [NAT gateways](https://docs.aws.amazon.com/vpc/latest/userguide/vpc-nat-gateway.html) in the *Amazon VPC User Guide*.\n If you add a default route (``AWS::EC2::Route`` resource) that points to a NAT gateway, specify the NAT gateway ID for the route's ``NatGatewayId`` property.\n  When you associate an Elastic IP address or secondary Elastic IP address with a public NAT gateway, the network border group of the Elastic IP address must match the network border group of the Availability Zone (AZ) that the public NAT gateway is in. Otherwise, the NAT gateway fails to launch. You can see the network border group for the AZ by viewing the details of the subnet. Similarly, you can view the network border group for the Elastic IP address by viewing its details. For more information, see [Allocate an Elastic IP address](https://docs.aws.amazon.com/vpc/latest/userguide/vpc-eips.html#allocate-eip) in the *Amazon VPC User Guide*.",
  "writeOnlyProperties" : [ "/properties/MaxDrainDurationSeconds" ],
  "createOnlyProperties" : [ "/properties/SubnetId", "/properties/ConnectivityType", "/properties/AllocationId", "/properties/PrivateIpAddress" ],
  "additionalProperties" : False,
  "primaryIdentifier" : [ "/properties/NatGatewayId" ],
  "definitions" : {
    "Tag" : {
      "description" : "Specifies a tag. For more information, see [Resource tags](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-resource-tags.html).",
      "additionalProperties" : False,
      "type" : "object",
      "properties" : {
        "Value" : {
          "description" : "The tag value.",
          "type" : "string"
        },
        "Key" : {
          "description" : "The tag key.",
          "type" : "string"
        }
      },
      "required" : [ "Value", "Key" ]
    }
  },
  "required" : [ "SubnetId" ],
  "properties" : {
    "SecondaryAllocationIds" : {
      "uniqueItems" : True,
      "description" : "Secondary EIP allocation IDs. For more information, see [Create a NAT gateway](https://docs.aws.amazon.com/vpc/latest/userguide/nat-gateway-working-with.html) in the *Amazon VPC User Guide*.",
      "insertionOrder" : True,
      "type" : "array",
      "items" : {
        "type" : "string"
      }
    },
    "PrivateIpAddress" : {
      "description" : "The private IPv4 address to assign to the NAT gateway. If you don't provide an address, a private IPv4 address will be automatically assigned.",
      "type" : "string"
    },
    "ConnectivityType" : {
      "description" : "Indicates whether the NAT gateway supports public or private connectivity. The default is public connectivity.",
      "type" : "string"
    },
    "SecondaryPrivateIpAddresses" : {
      "uniqueItems" : True,
      "description" : "Secondary private IPv4 addresses. For more information about secondary addresses, see [Create a NAT gateway](https://docs.aws.amazon.com/vpc/latest/userguide/vpc-nat-gateway.html#nat-gateway-creating) in the *Amazon Virtual Private Cloud User Guide*.\n ``SecondaryPrivateIpAddressCount`` and ``SecondaryPrivateIpAddresses`` cannot be set at the same time.",
      "insertionOrder" : True,
      "type" : "array",
      "items" : {
        "type" : "string"
      }
    },
    "SecondaryPrivateIpAddressCount" : {
      "description" : "[Private NAT gateway only] The number of secondary private IPv4 addresses you want to assign to the NAT gateway. For more information about secondary addresses, see [Create a NAT gateway](https://docs.aws.amazon.com/vpc/latest/userguide/vpc-nat-gateway.html#nat-gateway-creating) in the *Amazon Virtual Private Cloud User Guide*.\n ``SecondaryPrivateIpAddressCount`` and ``SecondaryPrivateIpAddresses`` cannot be set at the same time.",
      "type" : "integer",
      "minimum" : 1
    },
    "AllocationId" : {
      "description" : "[Public NAT gateway only] The allocation ID of the Elastic IP address that's associated with the NAT gateway. This property is required for a public NAT gateway and cannot be specified with a private NAT gateway.",
      "type" : "string"
    },
    "SubnetId" : {
      "description" : "The ID of the subnet in which the NAT gateway is located.",
      "type" : "string"
    },
    "NatGatewayId" : {
      "description" : "",
      "type" : "string"
    },
    "Tags" : {
      "uniqueItems" : False,
      "description" : "The tags for the NAT gateway.",
      "insertionOrder" : False,
      "type" : "array",
      "items" : {
        "$ref" : "#/definitions/Tag"
      }
    },
    "MaxDrainDurationSeconds" : {
      "description" : "The maximum amount of time to wait (in seconds) before forcibly releasing the IP addresses if connections are still in progress. Default value is 350 seconds.",
      "type" : "integer"
    }
  }
}