SCHEMA = {
  "sourceUrl" : "https://github.com/aws-cloudformation/aws-cloudformation-resource-providers-ec2",
  "tagging" : {
    "permissions" : [ "ec2:CreateTags", "ec2:DeleteTags" ],
    "taggable" : True,
    "tagOnCreate" : True,
    "tagUpdatable" : True,
    "tagProperty" : "/properties/Tags",
    "cloudFormationSystemTags" : True
  },
  "handlers" : {
    "read" : {
      "permissions" : [ "ec2:DescribeRouteTables" ]
    },
    "create" : {
      "permissions" : [ "ec2:CreateRouteTable", "ec2:CreateTags", "ec2:DescribeRouteTables" ]
    },
    "update" : {
      "permissions" : [ "ec2:CreateTags", "ec2:DeleteTags", "ec2:DescribeRouteTables" ]
    },
    "list" : {
      "permissions" : [ "ec2:DescribeRouteTables" ]
    },
    "delete" : {
      "permissions" : [ "ec2:DescribeRouteTables", "ec2:DeleteRouteTable" ]
    }
  },
  "typeName" : "AWS::EC2::RouteTable",
  "readOnlyProperties" : [ "/properties/RouteTableId" ],
  "description" : "Specifies a route table for the specified VPC. After you create a route table, you can add routes and associate the table with a subnet.\n For more information, see [Route tables](https://docs.aws.amazon.com/vpc/latest/userguide/VPC_Route_Tables.html) in the *Amazon VPC User Guide*.",
  "createOnlyProperties" : [ "/properties/VpcId" ],
  "additionalProperties" : False,
  "primaryIdentifier" : [ "/properties/RouteTableId" ],
  "definitions" : {
    "Tag" : {
      "description" : "Specifies a tag. For more information, see [Resource tags](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-resource-tags.html).",
      "additionalProperties" : False,
      "type" : "object",
      "properties" : {
        "Value" : {
          "description" : "The tag value.",
          "type" : "string"
        },
        "Key" : {
          "description" : "The tag key.",
          "type" : "string"
        }
      },
      "required" : [ "Value", "Key" ]
    }
  },
  "properties" : {
    "RouteTableId" : {
      "description" : "",
      "type" : "string"
    },
    "VpcId" : {
      "description" : "The ID of the VPC.",
      "type" : "string"
    },
    "Tags" : {
      "uniqueItems" : False,
      "description" : "Any tags assigned to the route table.",
      "insertionOrder" : False,
      "type" : "array",
      "items" : {
        "$ref" : "#/definitions/Tag"
      }
    }
  },
  "required" : [ "VpcId" ]
}