SCHEMA = {
  "typeName" : "AWS::EC2::TransitGateway",
  "sourceUrl" : "https://github.com/aws-cloudformation/aws-cloudformation-resource-providers-transitgateway",
  "description" : "Resource Type definition for AWS::EC2::TransitGateway",
  "additionalProperties" : False,
  "properties" : {
    "DefaultRouteTablePropagation" : {
      "type" : "string"
    },
    "TransitGatewayArn" : {
      "type" : "string"
    },
    "Description" : {
      "type" : "string"
    },
    "AutoAcceptSharedAttachments" : {
      "type" : "string"
    },
    "DefaultRouteTableAssociation" : {
      "type" : "string"
    },
    "Id" : {
      "type" : "string"
    },
    "VpnEcmpSupport" : {
      "type" : "string"
    },
    "DnsSupport" : {
      "type" : "string"
    },
    "SecurityGroupReferencingSupport" : {
      "type" : "string"
    },
    "MulticastSupport" : {
      "type" : "string"
    },
    "AmazonSideAsn" : {
      "type" : "integer",
      "format" : "int64"
    },
    "TransitGatewayCidrBlocks" : {
      "type" : "array",
      "items" : {
        "type" : "string"
      }
    },
    "Tags" : {
      "type" : "array",
      "uniqueItems" : False,
      "items" : {
        "$ref" : "#/definitions/Tag"
      }
    },
    "AssociationDefaultRouteTableId" : {
      "type" : "string"
    },
    "PropagationDefaultRouteTableId" : {
      "type" : "string"
    }
  },
  "definitions" : {
    "Tag" : {
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "Value" : {
          "type" : "string"
        },
        "Key" : {
          "type" : "string"
        }
      },
      "required" : [ "Value", "Key" ]
    }
  },
  "primaryIdentifier" : [ "/properties/Id" ],
  "readOnlyProperties" : [ "/properties/Id", "/properties/TransitGatewayArn" ],
  "createOnlyProperties" : [ "/properties/AmazonSideAsn", "/properties/MulticastSupport" ],
  "tagging" : {
    "taggable" : True,
    "tagOnCreate" : True,
    "tagUpdatable" : True,
    "cloudFormationSystemTags" : True,
    "tagProperty" : "/properties/Tags",
    "permissions" : [ "ec2:CreateTags", "ec2:DeleteTags" ]
  },
  "handlers" : {
    "create" : {
      "permissions" : [ "ec2:CreateTransitGateway", "ec2:CreateTags", "ec2:DescribeTransitGateways", "ec2:DescribeTags" ]
    },
    "read" : {
      "permissions" : [ "ec2:DescribeTransitGateways", "ec2:DescribeTags" ]
    },
    "delete" : {
      "permissions" : [ "ec2:DescribeTransitGateways", "ec2:DescribeTags", "ec2:DeleteTransitGateway", "ec2:DeleteTags" ]
    },
    "update" : {
      "permissions" : [ "ec2:CreateTransitGateway", "ec2:CreateTags", "ec2:DescribeTransitGateways", "ec2:DescribeTags", "ec2:DeleteTransitGateway", "ec2:DeleteTags", "ec2:ModifyTransitGateway", "ec2:ModifyTransitGatewayOptions" ]
    },
    "list" : {
      "permissions" : [ "ec2:DescribeTransitGateways", "ec2:DescribeTags" ]
    }
  }
}