SCHEMA = {
  "typeName" : "AWS::EC2::TransitGatewayMulticastDomain",
  "description" : "The AWS::EC2::TransitGatewayMulticastDomain type",
  "sourceUrl" : "https://github.com/aws-cloudformation/aws-cloudformation-resource-providers-transitgateway/aws-ec2-transitgatewaymulticastdomain",
  "properties" : {
    "TransitGatewayMulticastDomainId" : {
      "description" : "The ID of the transit gateway multicast domain.",
      "type" : "string"
    },
    "TransitGatewayMulticastDomainArn" : {
      "description" : "The Amazon Resource Name (ARN) of the transit gateway multicast domain.",
      "type" : "string"
    },
    "TransitGatewayId" : {
      "description" : "The ID of the transit gateway.",
      "type" : "string"
    },
    "State" : {
      "description" : "The state of the transit gateway multicast domain.",
      "type" : "string"
    },
    "CreationTime" : {
      "description" : "The time the transit gateway multicast domain was created.",
      "type" : "string",
      "format" : "date-time"
    },
    "Tags" : {
      "description" : "The tags for the transit gateway multicast domain.",
      "type" : "array",
      "items" : {
        "$ref" : "#/definitions/Tag"
      }
    },
    "Options" : {
      "description" : "The options for the transit gateway multicast domain.",
      "type" : "object",
      "properties" : {
        "AutoAcceptSharedAssociations" : {
          "description" : "Indicates whether to automatically cross-account subnet associations that are associated with the transit gateway multicast domain. Valid Values: enable | disable",
          "type" : "string"
        },
        "Igmpv2Support" : {
          "description" : "Indicates whether Internet Group Management Protocol (IGMP) version 2 is turned on for the transit gateway multicast domain. Valid Values: enable | disable",
          "type" : "string"
        },
        "StaticSourcesSupport" : {
          "description" : "Indicates whether support for statically configuring transit gateway multicast group sources is turned on. Valid Values: enable | disable",
          "type" : "string"
        }
      },
      "additionalProperties" : False
    }
  },
  "required" : [ "TransitGatewayId" ],
  "definitions" : {
    "Tag" : {
      "type" : "object",
      "properties" : {
        "Key" : {
          "description" : "The key of the tag. Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with aws:.",
          "type" : "string"
        },
        "Value" : {
          "description" : "The value of the tag. Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.",
          "type" : "string"
        }
      },
      "additionalProperties" : False
    }
  },
  "additionalProperties" : False,
  "createOnlyProperties" : [ "/properties/TransitGatewayId" ],
  "tagging" : {
    "taggable" : True,
    "tagOnCreate" : True,
    "tagUpdatable" : True,
    "cloudFormationSystemTags" : False,
    "tagProperty" : "/properties/Tags",
    "permissions" : [ "ec2:CreateTags", "ec2:DeleteTags" ]
  },
  "readOnlyProperties" : [ "/properties/TransitGatewayMulticastDomainId", "/properties/State", "/properties/CreationTime", "/properties/TransitGatewayMulticastDomainArn" ],
  "primaryIdentifier" : [ "/properties/TransitGatewayMulticastDomainId" ],
  "handlers" : {
    "create" : {
      "permissions" : [ "ec2:DescribeTransitGatewayMulticastDomains", "ec2:CreateTransitGatewayMulticastDomain", "ec2:CreateTags", "ec2:DescribeTags" ]
    },
    "read" : {
      "permissions" : [ "ec2:DescribeTransitGatewayMulticastDomains", "ec2:DescribeTags" ]
    },
    "update" : {
      "permissions" : [ "ec2:DescribeTransitGatewayMulticastDomains", "ec2:DeleteTags", "ec2:CreateTags", "ec2:DescribeTags" ]
    },
    "delete" : {
      "permissions" : [ "ec2:DescribeTransitGatewayMulticastDomains", "ec2:DeleteTransitGatewayMulticastDomain", "ec2:DeleteTags", "ec2:DescribeTags" ]
    },
    "list" : {
      "permissions" : [ "ec2:DescribeTransitGatewayMulticastDomains", "ec2:DescribeTags" ]
    }
  }
}