SCHEMA = {
  "tagging" : {
    "permissions" : [ "ec2:CreateTags", "ec2:DeleteTags" ],
    "taggable" : True,
    "tagOnCreate" : True,
    "tagUpdatable" : True,
    "tagProperty" : "/properties/Tags",
    "cloudFormationSystemTags" : True
  },
  "typeName" : "AWS::EC2::TransitGatewayPeeringAttachment",
  "readOnlyProperties" : [ "/properties/TransitGatewayAttachmentId", "/properties/Status", "/properties/State", "/properties/CreationTime" ],
  "description" : "The AWS::EC2::TransitGatewayPeeringAttachment type",
  "createOnlyProperties" : [ "/properties/TransitGatewayId", "/properties/PeerTransitGatewayId", "/properties/PeerRegion", "/properties/PeerAccountId" ],
  "primaryIdentifier" : [ "/properties/TransitGatewayAttachmentId" ],
  "required" : [ "TransitGatewayId", "PeerTransitGatewayId", "PeerAccountId", "PeerRegion" ],
  "sourceUrl" : "https://github.com/aws-cloudformation/aws-cloudformation-resource-providers-myservice",
  "handlers" : {
    "read" : {
      "permissions" : [ "ec2:DescribeTransitGatewayPeeringAttachments", "ec2:DescribeTags" ]
    },
    "create" : {
      "permissions" : [ "ec2:CreateTransitGatewayPeeringAttachment", "ec2:DescribeTransitGatewayPeeringAttachments", "ec2:CreateTags", "ec2:DescribeTags" ]
    },
    "update" : {
      "permissions" : [ "ec2:DescribeTransitGatewayPeeringAttachments", "ec2:CreateTags", "ec2:DeleteTags", "ec2:DescribeTags" ]
    },
    "list" : {
      "permissions" : [ "ec2:DescribeTransitGatewayPeeringAttachments", "ec2:DescribeTags" ]
    },
    "delete" : {
      "permissions" : [ "ec2:DeleteTransitGatewayPeeringAttachment", "ec2:DescribeTransitGatewayPeeringAttachments", "ec2:DeleteTags", "ec2:DescribeTags" ]
    }
  },
  "additionalProperties" : False,
  "definitions" : {
    "Tag" : {
      "additionalProperties" : False,
      "type" : "object",
      "properties" : {
        "Value" : {
          "description" : "The value of the tag. Constraints: Tag values are case-sensitive and accept a maximum of 255 Unicode characters.",
          "type" : "string"
        },
        "Key" : {
          "description" : "The key of the tag. Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with aws:.",
          "type" : "string"
        }
      }
    },
    "PeeringAttachmentStatus" : {
      "additionalProperties" : False,
      "type" : "object",
      "properties" : {
        "Message" : {
          "description" : "The status message, if applicable.",
          "type" : "string"
        },
        "Code" : {
          "description" : "The status code.",
          "type" : "string"
        }
      }
    }
  },
  "properties" : {
    "Status" : {
      "description" : "The status of the transit gateway peering attachment.",
      "$ref" : "#/definitions/PeeringAttachmentStatus"
    },
    "TransitGatewayId" : {
      "description" : "The ID of the transit gateway.",
      "type" : "string"
    },
    "PeerTransitGatewayId" : {
      "description" : "The ID of the peer transit gateway.",
      "type" : "string"
    },
    "PeerAccountId" : {
      "description" : "The ID of the peer account",
      "type" : "string"
    },
    "State" : {
      "description" : "The state of the transit gateway peering attachment. Note that the initiating state has been deprecated.",
      "type" : "string"
    },
    "CreationTime" : {
      "format" : "date-time",
      "description" : "The time the transit gateway peering attachment was created.",
      "type" : "string"
    },
    "PeerRegion" : {
      "description" : "Peer Region",
      "type" : "string"
    },
    "Tags" : {
      "description" : "The tags for the transit gateway peering attachment.",
      "type" : "array",
      "items" : {
        "$ref" : "#/definitions/Tag"
      }
    },
    "TransitGatewayAttachmentId" : {
      "description" : "The ID of the transit gateway peering attachment.",
      "type" : "string"
    }
  }
}