SCHEMA = {
  "sourceUrl" : "https://github.com/aws-cloudformation/aws-cloudformation-resource-providers-transitgateway.git",
  "tagging" : {
    "permissions" : [ "ec2:CreateTags", "ec2:DeleteTags" ],
    "taggable" : True,
    "tagOnCreate" : True,
    "tagUpdatable" : True,
    "tagProperty" : "/properties/Tags",
    "cloudFormationSystemTags" : False
  },
  "handlers" : {
    "read" : {
      "permissions" : [ "ec2:DescribeTransitGatewayRouteTables" ]
    },
    "create" : {
      "permissions" : [ "ec2:CreateTransitGatewayRouteTable", "ec2:CreateTags", "ec2:DescribeTransitGatewayRouteTables" ]
    },
    "update" : {
      "permissions" : [ "ec2:DescribeTransitGatewayRouteTables", "ec2:CreateTags", "ec2:DeleteTags" ]
    },
    "list" : {
      "permissions" : [ "ec2:DescribeTransitGatewayRouteTables" ]
    },
    "delete" : {
      "permissions" : [ "ec2:DeleteTransitGatewayRouteTable", "ec2:DescribeTransitGatewayRouteTables", "ec2:GetTransitGatewayRouteTableAssociations", "ec2:DisassociateTransitGatewayRouteTable" ]
    }
  },
  "typeName" : "AWS::EC2::TransitGatewayRouteTable",
  "readOnlyProperties" : [ "/properties/TransitGatewayRouteTableId" ],
  "description" : "Resource Type definition for AWS::EC2::TransitGatewayRouteTable",
  "createOnlyProperties" : [ "/properties/TransitGatewayId" ],
  "additionalProperties" : False,
  "primaryIdentifier" : [ "/properties/TransitGatewayRouteTableId" ],
  "definitions" : {
    "Tag" : {
      "additionalProperties" : False,
      "type" : "object",
      "properties" : {
        "Value" : {
          "description" : "The value of the associated tag key-value pair",
          "type" : "string"
        },
        "Key" : {
          "description" : "The key of the associated tag key-value pair",
          "type" : "string"
        }
      },
      "required" : [ "Value", "Key" ]
    }
  },
  "properties" : {
    "TransitGatewayRouteTableId" : {
      "description" : "Transit Gateway Route Table primary identifier",
      "type" : "string"
    },
    "TransitGatewayId" : {
      "description" : "The ID of the transit gateway.",
      "type" : "string"
    },
    "Tags" : {
      "uniqueItems" : False,
      "description" : "Tags are composed of a Key/Value pair. You can use tags to categorize and track each parameter group. The tag value None is permitted.",
      "insertionOrder" : False,
      "type" : "array",
      "items" : {
        "$ref" : "#/definitions/Tag"
      }
    }
  },
  "required" : [ "TransitGatewayId" ]
}