SCHEMA = {
  "typeName" : "AWS::EC2::VPCBlockPublicAccessExclusion",
  "description" : "Resource Type definition for AWS::EC2::VPCBlockPublicAccessExclusion.",
  "sourceUrl" : "https://github.com/aws-cloudformation/aws-cloudformation-resource-providers-ec2-vpcblockpublicaccessexclusion.git",
  "tagging" : {
    "taggable" : True,
    "tagOnCreate" : True,
    "tagUpdatable" : True,
    "cloudFormationSystemTags" : True,
    "tagProperty" : "/properties/Tags",
    "permissions" : [ "ec2:CreateTags", "ec2:DeleteTags" ]
  },
  "definitions" : {
    "Tag" : {
      "description" : "A key-value pair to associate with a resource.",
      "type" : "object",
      "properties" : {
        "Key" : {
          "type" : "string",
          "description" : "The key name of the tag. You can specify a value that is 1 to 128 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -.",
          "minLength" : 1,
          "maxLength" : 128
        },
        "Value" : {
          "type" : "string",
          "description" : "The value for the tag. You can specify a value that is 0 to 256 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -.",
          "minLength" : 0,
          "maxLength" : 256
        }
      },
      "required" : [ "Key", "Value" ],
      "additionalProperties" : False
    }
  },
  "properties" : {
    "ExclusionId" : {
      "type" : "string",
      "description" : "The ID of the exclusion"
    },
    "InternetGatewayExclusionMode" : {
      "description" : "The desired Block Public Access Exclusion Mode for a specific VPC/Subnet.",
      "type" : "string",
      "enum" : [ "allow-bidirectional", "allow-egress" ]
    },
    "VpcId" : {
      "type" : "string",
      "description" : "The ID of the vpc. Required only if you don't specify SubnetId."
    },
    "SubnetId" : {
      "type" : "string",
      "description" : "The ID of the subnet. Required only if you don't specify VpcId"
    },
    "Tags" : {
      "description" : "An array of key-value pairs to apply to this resource.",
      "type" : "array",
      "uniqueItems" : False,
      "insertionOrder" : False,
      "items" : {
        "$ref" : "#/definitions/Tag"
      }
    }
  },
  "additionalProperties" : False,
  "oneOf" : [ {
    "required" : [ "VpcId" ]
  }, {
    "required" : [ "SubnetId" ]
  } ],
  "required" : [ "InternetGatewayExclusionMode" ],
  "createOnlyProperties" : [ "/properties/VpcId", "/properties/SubnetId" ],
  "readOnlyProperties" : [ "/properties/ExclusionId" ],
  "primaryIdentifier" : [ "/properties/ExclusionId" ],
  "handlers" : {
    "create" : {
      "permissions" : [ "ec2:DescribeVpcBlockPublicAccessExclusions", "ec2:CreateVpcBlockPublicAccessExclusion", "ec2:CreateTags" ]
    },
    "read" : {
      "permissions" : [ "ec2:DescribeVpcBlockPublicAccessExclusions" ]
    },
    "update" : {
      "permissions" : [ "ec2:DescribeVpcBlockPublicAccessExclusions", "ec2:ModifyVpcBlockPublicAccessExclusion", "ec2:CreateTags", "ec2:DeleteTags" ]
    },
    "delete" : {
      "permissions" : [ "ec2:DescribeVpcBlockPublicAccessExclusions", "ec2:DeleteVpcBlockPublicAccessExclusion" ]
    },
    "list" : {
      "permissions" : [ "ec2:DescribeVpcBlockPublicAccessExclusions" ]
    }
  }
}