SCHEMA = {
  "sourceUrl" : "https://github.com/aws-cloudformation/aws-cloudformation-resource-providers-ec2-vpc-endpoint",
  "tagging" : {
    "taggable" : False,
    "tagOnCreate" : False,
    "tagUpdatable" : False,
    "cloudFormationSystemTags" : False
  },
  "handlers" : {
    "read" : {
      "permissions" : [ "ec2:DescribeVpcEndpointConnectionNotifications" ]
    },
    "create" : {
      "permissions" : [ "ec2:CreateVpcEndpointConnectionNotification" ]
    },
    "update" : {
      "permissions" : [ "ec2:ModifyVpcEndpointConnectionNotification", "ec2:DescribeVpcEndpointConnectionNotifications" ]
    },
    "list" : {
      "permissions" : [ "ec2:DescribeVpcEndpointConnectionNotifications" ]
    },
    "delete" : {
      "permissions" : [ "ec2:DeleteVpcEndpointConnectionNotifications" ]
    }
  },
  "typeName" : "AWS::EC2::VPCEndpointConnectionNotification",
  "readOnlyProperties" : [ "/properties/VPCEndpointConnectionNotificationId" ],
  "description" : "Resource Type definition for AWS::EC2::VPCEndpointConnectionNotification",
  "createOnlyProperties" : [ "/properties/ServiceId", "/properties/VPCEndpointId" ],
  "additionalProperties" : False,
  "primaryIdentifier" : [ "/properties/VPCEndpointConnectionNotificationId" ],
  "properties" : {
    "ConnectionEvents" : {
      "uniqueItems" : False,
      "description" : "The endpoint events for which to receive notifications.",
      "insertionOrder" : False,
      "type" : "array",
      "items" : {
        "type" : "string"
      }
    },
    "VPCEndpointId" : {
      "description" : "The ID of the endpoint.",
      "type" : "string"
    },
    "VPCEndpointConnectionNotificationId" : {
      "description" : "VPC Endpoint Connection ID generated by service",
      "type" : "string"
    },
    "ConnectionNotificationArn" : {
      "description" : "The ARN of the SNS topic for the notifications.",
      "type" : "string"
    },
    "ServiceId" : {
      "description" : "The ID of the endpoint service.",
      "type" : "string"
    }
  },
  "required" : [ "ConnectionEvents", "ConnectionNotificationArn" ]
}