SCHEMA = {
  "tagging" : {
    "permissions" : [ "ec2:CreateTags", "ec2:DeleteTags" ],
    "taggable" : True,
    "tagOnCreate" : True,
    "tagUpdatable" : True,
    "tagProperty" : "/properties/Tags",
    "cloudFormationSystemTags" : True
  },
  "typeName" : "AWS::EC2::VPCPeeringConnection",
  "readOnlyProperties" : [ "/properties/Id" ],
  "description" : "Resource Type definition for AWS::EC2::VPCPeeringConnection",
  "createOnlyProperties" : [ "/properties/PeerRegion", "/properties/PeerOwnerId", "/properties/PeerVpcId", "/properties/PeerRoleArn", "/properties/VpcId" ],
  "primaryIdentifier" : [ "/properties/Id" ],
  "required" : [ "VpcId", "PeerVpcId" ],
  "sourceUrl" : "https://github.com/aws-cloudformation/aws-cloudformation-ec2-vpcpeering.git",
  "handlers" : {
    "read" : {
      "permissions" : [ "ec2:DescribeVpcPeeringConnections" ]
    },
    "create" : {
      "permissions" : [ "ec2:CreateVpcPeeringConnection", "ec2:DescribeVpcPeeringConnections", "ec2:AcceptVpcPeeringConnection", "ec2:CreateTags", "sts:AssumeRole" ]
    },
    "update" : {
      "permissions" : [ "ec2:CreateTags", "ec2:DeleteTags", "ec2:DescribeVpcPeeringConnections" ]
    },
    "list" : {
      "permissions" : [ "ec2:DescribeVpcPeeringConnections" ]
    },
    "delete" : {
      "permissions" : [ "ec2:DeleteVpcPeeringConnection", "ec2:DescribeVpcPeeringConnections" ]
    }
  },
  "writeOnlyProperties" : [ "/properties/PeerRoleArn" ],
  "additionalProperties" : False,
  "definitions" : {
    "Tag" : {
      "description" : "A key-value pair to associate with a resource.",
      "additionalProperties" : False,
      "type" : "object",
      "properties" : {
        "Value" : {
          "description" : "The value for the tag. You can specify a value that is 0 to 256 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -.",
          "type" : "string"
        },
        "Key" : {
          "description" : "The key name of the tag. You can specify a value that is 1 to 128 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -.",
          "type" : "string"
        }
      },
      "required" : [ "Key", "Value" ]
    }
  },
  "properties" : {
    "PeerRoleArn" : {
      "description" : "The Amazon Resource Name (ARN) of the VPC peer role for the peering connection in another AWS account.",
      "type" : "string"
    },
    "VpcId" : {
      "description" : "The ID of the VPC.",
      "type" : "string"
    },
    "PeerVpcId" : {
      "description" : "The ID of the VPC with which you are creating the VPC peering connection. You must specify this parameter in the request.",
      "type" : "string"
    },
    "Id" : {
      "type" : "string"
    },
    "PeerRegion" : {
      "description" : "The Region code for the accepter VPC, if the accepter VPC is located in a Region other than the Region in which you make the request.",
      "type" : "string"
    },
    "PeerOwnerId" : {
      "description" : "The AWS account ID of the owner of the accepter VPC.",
      "type" : "string"
    },
    "Tags" : {
      "uniqueItems" : False,
      "insertionOrder" : False,
      "type" : "array",
      "items" : {
        "$ref" : "#/definitions/Tag"
      }
    }
  }
}