SCHEMA = {
  "sourceUrl" : "https://github.com/aws-cloudformation/aws-cloudformation-resource-providers-ec2.git",
  "tagging" : {
    "taggable" : False
  },
  "handlers" : {
    "read" : {
      "permissions" : [ "ec2:DescribeVpnConnections" ]
    },
    "create" : {
      "permissions" : [ "ec2:CreateVpnConnectionRoute", "ec2:DescribeVpnConnections" ]
    },
    "list" : {
      "permissions" : [ "ec2:DescribeVpnConnections" ]
    },
    "delete" : {
      "permissions" : [ "ec2:DeleteVpnConnectionRoute", "ec2:DescribeVpnConnections" ]
    }
  },
  "typeName" : "AWS::EC2::VPNConnectionRoute",
  "description" : "Specifies a static route for a VPN connection between an existing virtual private gateway and a VPN customer gateway. The static route allows traffic to be routed from the virtual private gateway to the VPN customer gateway.\n For more information, see [](https://docs.aws.amazon.com/vpn/latest/s2svpn/VPC_VPN.html) in the *User Guide*.",
  "createOnlyProperties" : [ "/properties/DestinationCidrBlock", "/properties/VpnConnectionId" ],
  "additionalProperties" : False,
  "primaryIdentifier" : [ "/properties/DestinationCidrBlock", "/properties/VpnConnectionId" ],
  "properties" : {
    "DestinationCidrBlock" : {
      "description" : "The CIDR block associated with the local subnet of the customer network.",
      "type" : "string"
    },
    "VpnConnectionId" : {
      "description" : "The ID of the VPN connection.",
      "type" : "string"
    }
  },
  "required" : [ "DestinationCidrBlock", "VpnConnectionId" ]
}