SCHEMA = {
  "sourceUrl" : "https://github.com/aws-cloudformation/aws-cloudformation-rpdk.git",
  "tagging" : {
    "taggable" : False
  },
  "handlers" : {
    "read" : {
      "permissions" : [ "elasticfilesystem:DescribeMountTargets", "elasticfilesystem:DescribeMountTargetSecurityGroups" ]
    },
    "create" : {
      "permissions" : [ "elasticfilesystem:CreateMountTarget", "elasticfilesystem:DescribeMountTargets" ]
    },
    "update" : {
      "permissions" : [ "elasticfilesystem:DescribeMountTargets", "elasticfilesystem:DescribeMountTargetSecurityGroups", "elasticfilesystem:ModifyMountTargetSecurityGroups" ]
    },
    "list" : {
      "permissions" : [ "elasticfilesystem:DescribeMountTargets", "elasticfilesystem:DescribeMountTargetSecurityGroups" ],
      "handlerSchema" : {
        "properties" : {
          "FileSystemId" : {
            "$ref" : "resource-schema.json#/properties/FileSystemId"
          }
        },
        "required" : [ "FileSystemId" ]
      }
    },
    "delete" : {
      "permissions" : [ "elasticfilesystem:DescribeMountTargets", "elasticfilesystem:DeleteMountTarget" ]
    }
  },
  "typeName" : "AWS::EFS::MountTarget",
  "readOnlyProperties" : [ "/properties/Id" ],
  "description" : "The ``AWS::EFS::MountTarget`` resource is an Amazon EFS resource that creates a mount target for an EFS file system. You can then mount the file system on Amazon EC2 instances or other resources by using the mount target.",
  "createOnlyProperties" : [ "/properties/IpAddress", "/properties/SubnetId", "/properties/FileSystemId" ],
  "additionalProperties" : False,
  "primaryIdentifier" : [ "/properties/Id" ],
  "required" : [ "FileSystemId", "SecurityGroups", "SubnetId" ],
  "properties" : {
    "SecurityGroups" : {
      "uniqueItems" : True,
      "description" : "VPC security group IDs, of the form ``sg-xxxxxxxx``. These must be for the same VPC as the subnet specified. The maximum number of security groups depends on account quota. For more information, see [Amazon VPC Quotas](https://docs.aws.amazon.com/vpc/latest/userguide/amazon-vpc-limits.html) in the *Amazon VPC User Guide* (see the *Security Groups* table).",
      "insertionOrder" : False,
      "type" : "array",
      "items" : {
        "type" : "string"
      }
    },
    "FileSystemId" : {
      "description" : "The ID of the file system for which to create the mount target.",
      "type" : "string"
    },
    "IpAddress" : {
      "description" : "Valid IPv4 address within the address range of the specified subnet.",
      "type" : "string"
    },
    "Id" : {
      "description" : "",
      "type" : "string"
    },
    "SubnetId" : {
      "description" : "The ID of the subnet to add the mount target in. For One Zone file systems, use the subnet that is associated with the file system's Availability Zone.",
      "type" : "string"
    }
  }
}