SCHEMA = {
  "tagging" : {
    "permissions" : [ "elasticloadbalancing:AddTags", "elasticloadbalancing:DescribeTags", "elasticloadbalancing:RemoveTags" ],
    "taggable" : True,
    "tagOnCreate" : False,
    "tagUpdatable" : True,
    "tagProperty" : "/properties/Tags",
    "cloudFormationSystemTags" : False
  },
  "handlers" : {
    "read" : {
      "permissions" : [ "elasticloadbalancing:DescribeTargetGroups", "elasticloadbalancing:DescribeTargetGroupAttributes", "elasticloadbalancing:DescribeTargetHealth", "elasticloadbalancing:DescribeTags" ]
    },
    "create" : {
      "permissions" : [ "elasticloadbalancing:CreateTargetGroup", "elasticloadbalancing:DescribeTargetGroups", "elasticloadbalancing:RegisterTargets", "elasticloadbalancing:ModifyTargetGroupAttributes", "elasticloadbalancing:DescribeTargetHealth", "elasticloadbalancing:AddTags" ]
    },
    "update" : {
      "permissions" : [ "elasticloadbalancing:DescribeTargetGroups", "elasticloadbalancing:ModifyTargetGroup", "elasticloadbalancing:ModifyTargetGroupAttributes", "elasticloadbalancing:RegisterTargets", "elasticloadbalancing:DescribeTargetHealth", "elasticloadbalancing:DeregisterTargets", "elasticloadbalancing:AddTags", "elasticloadbalancing:RemoveTags" ]
    },
    "list" : {
      "permissions" : [ "elasticloadbalancing:DescribeTargetGroups" ]
    },
    "delete" : {
      "permissions" : [ "elasticloadbalancing:DeleteTargetGroup", "elasticloadbalancing:DescribeTargetGroups" ]
    }
  },
  "typeName" : "AWS::ElasticLoadBalancingV2::TargetGroup",
  "readOnlyProperties" : [ "/properties/LoadBalancerArns", "/properties/TargetGroupArn", "/properties/TargetGroupName", "/properties/TargetGroupFullName" ],
  "description" : "Resource Type definition for AWS::ElasticLoadBalancingV2::TargetGroup",
  "createOnlyProperties" : [ "/properties/TargetType", "/properties/ProtocolVersion", "/properties/Port", "/properties/Name", "/properties/VpcId", "/properties/Protocol", "/properties/IpAddressType" ],
  "additionalProperties" : False,
  "primaryIdentifier" : [ "/properties/TargetGroupArn" ],
  "definitions" : {
    "Matcher" : {
      "additionalProperties" : False,
      "type" : "object",
      "properties" : {
        "GrpcCode" : {
          "description" : "You can specify values between 0 and 99. You can specify multiple values, or a range of values. The default value is 12.",
          "type" : "string"
        },
        "HttpCode" : {
          "description" : "For Application Load Balancers, you can specify values between 200 and 499, and the default value is 200. You can specify multiple values or a range of values. ",
          "type" : "string"
        }
      }
    },
    "TargetDescription" : {
      "additionalProperties" : False,
      "type" : "object",
      "properties" : {
        "Port" : {
          "description" : "The port on which the target is listening. If the target group protocol is GENEVE, the supported port is 6081. If the target type is alb, the targeted Application Load Balancer must have at least one listener whose port matches the target group port. Not used if the target is a Lambda function.",
          "type" : "integer"
        },
        "AvailabilityZone" : {
          "description" : "An Availability Zone or all. This determines whether the target receives traffic from the load balancer nodes in the specified Availability Zone or from all enabled Availability Zones for the load balancer.",
          "type" : "string"
        },
        "Id" : {
          "description" : "The ID of the target. If the target type of the target group is instance, specify an instance ID. If the target type is ip, specify an IP address. If the target type is lambda, specify the ARN of the Lambda function. If the target type is alb, specify the ARN of the Application Load Balancer target. ",
          "type" : "string"
        }
      },
      "required" : [ "Id" ]
    },
    "TargetGroupAttribute" : {
      "additionalProperties" : False,
      "type" : "object",
      "properties" : {
        "Value" : {
          "description" : "The name of the attribute.",
          "type" : "string"
        },
        "Key" : {
          "description" : "The value of the attribute.",
          "type" : "string"
        }
      }
    },
    "Tag" : {
      "additionalProperties" : False,
      "type" : "object",
      "properties" : {
        "Value" : {
          "description" : "The key name of the tag. ",
          "type" : "string"
        },
        "Key" : {
          "description" : "The value for the tag. ",
          "type" : "string"
        }
      },
      "required" : [ "Value", "Key" ]
    }
  },
  "properties" : {
    "IpAddressType" : {
      "description" : "The type of IP address used for this target group. The possible values are ipv4 and ipv6. ",
      "type" : "string"
    },
    "TargetGroupArn" : {
      "description" : "The ARN of the Target Group",
      "type" : "string"
    },
    "HealthCheckIntervalSeconds" : {
      "description" : "The approximate amount of time, in seconds, between health checks of an individual target.",
      "type" : "integer"
    },
    "LoadBalancerArns" : {
      "uniqueItems" : False,
      "description" : "The Amazon Resource Names (ARNs) of the load balancers that route traffic to this target group.",
      "insertionOrder" : False,
      "type" : "array",
      "items" : {
        "type" : "string"
      }
    },
    "Matcher" : {
      "description" : "[HTTP/HTTPS health checks] The HTTP or gRPC codes to use when checking for a successful response from a target.",
      "$ref" : "#/definitions/Matcher"
    },
    "HealthCheckPath" : {
      "description" : "[HTTP/HTTPS health checks] The destination for health checks on the targets. [HTTP1 or HTTP2 protocol version] The ping path. The default is /. [GRPC protocol version] The path of a custom health check method with the format /package.service/method. The default is /AWS.ALB/healthcheck.",
      "type" : "string"
    },
    "Port" : {
      "description" : "The port on which the targets receive traffic. This port is used unless you specify a port override when registering the target. If the target is a Lambda function, this parameter does not apply. If the protocol is GENEVE, the supported port is 6081.",
      "type" : "integer"
    },
    "Targets" : {
      "uniqueItems" : True,
      "description" : "The targets.",
      "insertionOrder" : False,
      "type" : "array",
      "items" : {
        "$ref" : "#/definitions/TargetDescription"
      }
    },
    "HealthCheckEnabled" : {
      "description" : "Indicates whether health checks are enabled. If the target type is lambda, health checks are disabled by default but can be enabled. If the target type is instance, ip, or alb, health checks are always enabled and cannot be disabled.",
      "type" : "boolean"
    },
    "ProtocolVersion" : {
      "description" : "[HTTP/HTTPS protocol] The protocol version. The possible values are GRPC, HTTP1, and HTTP2.",
      "type" : "string"
    },
    "UnhealthyThresholdCount" : {
      "description" : "The number of consecutive health check failures required before considering a target unhealthy.",
      "type" : "integer"
    },
    "HealthCheckTimeoutSeconds" : {
      "description" : "The amount of time, in seconds, during which no response from a target means a failed health check.",
      "type" : "integer"
    },
    "Name" : {
      "description" : "The name of the target group.",
      "type" : "string"
    },
    "VpcId" : {
      "description" : "The identifier of the virtual private cloud (VPC). If the target is a Lambda function, this parameter does not apply.",
      "type" : "string"
    },
    "TargetGroupFullName" : {
      "description" : "The full name of the target group.",
      "type" : "string"
    },
    "HealthyThresholdCount" : {
      "description" : "The number of consecutive health checks successes required before considering an unhealthy target healthy. ",
      "type" : "integer"
    },
    "HealthCheckProtocol" : {
      "description" : "The protocol the load balancer uses when performing health checks on targets. ",
      "type" : "string"
    },
    "TargetGroupAttributes" : {
      "arrayType" : "AttributeList",
      "uniqueItems" : True,
      "description" : "The attributes.",
      "insertionOrder" : False,
      "type" : "array",
      "items" : {
        "$ref" : "#/definitions/TargetGroupAttribute"
      }
    },
    "TargetType" : {
      "description" : "The type of target that you must specify when registering targets with this target group. You can't specify targets for a target group using more than one target type.",
      "type" : "string"
    },
    "HealthCheckPort" : {
      "description" : "The port the load balancer uses when performing health checks on targets. ",
      "type" : "string"
    },
    "Protocol" : {
      "description" : "The protocol to use for routing traffic to the targets.",
      "type" : "string"
    },
    "TargetGroupName" : {
      "description" : "The name of the target group.",
      "type" : "string"
    },
    "Tags" : {
      "uniqueItems" : False,
      "description" : "The tags.",
      "insertionOrder" : False,
      "type" : "array",
      "items" : {
        "$ref" : "#/definitions/Tag"
      }
    }
  }
}