SCHEMA = {
  "typeName" : "AWS::Events::Archive",
  "description" : "Resource Type definition for AWS::Events::Archive",
  "additionalProperties" : False,
  "properties" : {
    "ArchiveName" : {
      "type" : "string",
      "minLength" : 1,
      "maxLength" : 48,
      "pattern" : "[\\.\\-_A-Za-z0-9]+"
    },
    "SourceArn" : {
      "type" : "string"
    },
    "Description" : {
      "type" : "string"
    },
    "EventPattern" : {
      "type" : "object"
    },
    "Arn" : {
      "type" : "string",
      "pattern" : "^arn:aws([a-z]|\\-)*:events:([a-z]|\\d|\\-)*:([0-9]{12})?:.+\\/.+$"
    },
    "RetentionDays" : {
      "type" : "integer"
    },
    "KmsKeyIdentifier" : {
      "type" : "string",
      "maxLength" : 2048,
      "minLength" : 0
    }
  },
  "required" : [ "SourceArn" ],
  "readOnlyProperties" : [ "/properties/Arn" ],
  "createOnlyProperties" : [ "/properties/ArchiveName", "/properties/SourceArn" ],
  "primaryIdentifier" : [ "/properties/ArchiveName" ],
  "tagging" : {
    "taggable" : False,
    "tagOnCreate" : False,
    "tagUpdatable" : False,
    "cloudFormationSystemTags" : False
  },
  "handlers" : {
    "create" : {
      "permissions" : [ "events:DescribeArchive", "events:CreateArchive", "kms:DescribeKey", "kms:GenerateDataKey", "kms:Decrypt" ]
    },
    "delete" : {
      "permissions" : [ "events:DescribeArchive", "events:DeleteArchive" ]
    },
    "list" : {
      "permissions" : [ "events:ListArchives" ]
    },
    "update" : {
      "permissions" : [ "events:DescribeArchive", "events:UpdateArchive", "kms:DescribeKey", "kms:GenerateDataKey", "kms:Decrypt", "kms:ReEncryptTo", "kms:ReEncryptFrom" ]
    },
    "read" : {
      "permissions" : [ "events:DescribeArchive", "kms:Decrypt" ]
    }
  }
}