SCHEMA = {
  "typeName" : "AWS::Glue::Registry",
  "description" : "This resource creates a Registry for authoring schemas as part of Glue Schema Registry.",
  "tagging" : {
    "taggable" : True,
    "tagOnCreate" : True,
    "tagUpdatable" : True,
    "cloudFormationSystemTags" : True,
    "tagProperty" : "/properties/Tags",
    "permissions" : [ "glue:GetTags", "glue:TagResource", "glue:UntagResource" ]
  },
  "sourceUrl" : "https://github.com/aws-cloudformation/aws-cloudformation-resource-providers-glue.git",
  "definitions" : {
    "Tag" : {
      "type" : "object",
      "properties" : {
        "Key" : {
          "description" : "A key to identify the tag.",
          "type" : "string",
          "minLength" : 1,
          "maxLength" : 128
        },
        "Value" : {
          "description" : "Corresponding tag value for the key.",
          "type" : "string",
          "minLength" : 0,
          "maxLength" : 256
        }
      },
      "required" : [ "Key", "Value" ],
      "additionalProperties" : False
    }
  },
  "properties" : {
    "Arn" : {
      "description" : "Amazon Resource Name for the created Registry.",
      "type" : "string",
      "pattern" : "arn:aws(-(cn|us-gov|iso(-[bef])?))?:glue:.*"
    },
    "Name" : {
      "description" : "Name of the registry to be created of max length of 255, and may only contain letters, numbers, hyphen, underscore, dollar sign, or hash mark.  No whitespace.",
      "type" : "string",
      "maxLength" : 255,
      "minLength" : 1
    },
    "Description" : {
      "description" : "A description of the registry. If description is not provided, there will not be any default value for this.",
      "type" : "string",
      "maxLength" : 1000,
      "minLength" : 0
    },
    "Tags" : {
      "description" : "List of tags to tag the Registry",
      "type" : "array",
      "minItems" : 0,
      "maxItems" : 10,
      "items" : {
        "$ref" : "#/definitions/Tag"
      }
    }
  },
  "createOnlyProperties" : [ "/properties/Name" ],
  "readOnlyProperties" : [ "/properties/Arn" ],
  "primaryIdentifier" : [ "/properties/Arn" ],
  "additionalProperties" : False,
  "required" : [ "Name" ],
  "handlers" : {
    "create" : {
      "permissions" : [ "glue:CreateRegistry", "glue:GetRegistry", "glue:GetTags", "glue:TagResource" ]
    },
    "read" : {
      "permissions" : [ "glue:GetRegistry", "glue:GetTags" ]
    },
    "delete" : {
      "permissions" : [ "glue:GetRegistry", "glue:DeleteRegistry" ]
    },
    "update" : {
      "permissions" : [ "glue:UpdateRegistry", "glue:GetRegistry", "glue:TagResource", "glue:UntagResource", "glue:GetTags" ]
    },
    "list" : {
      "permissions" : [ "glue:ListRegistries" ]
    }
  }
}