SCHEMA = {
  "typeName" : "AWS::IAM::OIDCProvider",
  "description" : "Resource Type definition for AWS::IAM::OIDCProvider",
  "additionalProperties" : False,
  "properties" : {
    "ClientIdList" : {
      "type" : "array",
      "insertionOrder" : False,
      "items" : {
        "minLength" : 1,
        "maxLength" : 255,
        "type" : "string"
      }
    },
    "Url" : {
      "minLength" : 1,
      "maxLength" : 255,
      "type" : "string"
    },
    "ThumbprintList" : {
      "type" : "array",
      "insertionOrder" : False,
      "items" : {
        "minLength" : 40,
        "maxLength" : 40,
        "pattern" : "[0-9A-Fa-f]{40}",
        "type" : "string"
      },
      "maxItems" : 5
    },
    "Arn" : {
      "description" : "Amazon Resource Name (ARN) of the OIDC provider",
      "minLength" : 20,
      "maxLength" : 2048,
      "type" : "string"
    },
    "Tags" : {
      "type" : "array",
      "uniqueItems" : False,
      "insertionOrder" : False,
      "items" : {
        "$ref" : "#/definitions/Tag"
      }
    }
  },
  "definitions" : {
    "Tag" : {
      "description" : "A key-value pair to associate with a resource.",
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "Value" : {
          "description" : "The value for the tag. You can specify a value that is 0 to 256 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -.",
          "type" : "string",
          "minLength" : 1,
          "maxLength" : 256
        },
        "Key" : {
          "description" : "The key name of the tag. You can specify a value that is 1 to 128 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -.",
          "type" : "string",
          "minLength" : 1,
          "maxLength" : 128
        }
      },
      "required" : [ "Value", "Key" ]
    }
  },
  "createOnlyProperties" : [ "/properties/Url" ],
  "readOnlyProperties" : [ "/properties/Arn" ],
  "primaryIdentifier" : [ "/properties/Arn" ],
  "handlers" : {
    "create" : {
      "permissions" : [ "iam:CreateOpenIDConnectProvider", "iam:TagOpenIDConnectProvider", "iam:GetOpenIDConnectProvider" ]
    },
    "read" : {
      "permissions" : [ "iam:GetOpenIDConnectProvider" ]
    },
    "update" : {
      "permissions" : [ "iam:UpdateOpenIDConnectProviderThumbprint", "iam:RemoveClientIDFromOpenIDConnectProvider", "iam:AddClientIDToOpenIDConnectProvider", "iam:GetOpenIDConnectProvider", "iam:TagOpenIDConnectProvider", "iam:UntagOpenIDConnectProvider", "iam:ListOpenIDConnectProviderTags" ]
    },
    "delete" : {
      "permissions" : [ "iam:DeleteOpenIDConnectProvider" ]
    },
    "list" : {
      "permissions" : [ "iam:ListOpenIDConnectProviders", "iam:GetOpenIDConnectProvider" ]
    }
  },
  "tagging" : {
    "taggable" : True,
    "tagOnCreate" : True,
    "tagUpdatable" : True,
    "cloudFormationSystemTags" : False,
    "tagProperty" : "/properties/Tags",
    "permissions" : [ "iam:TagOpenIDConnectProvider", "iam:UntagOpenIDConnectProvider", "iam:ListOpenIDConnectProviderTags" ]
  }
}