SCHEMA = {
  "typeName" : "AWS::IoT::BillingGroup",
  "description" : "Resource Type definition for AWS::IoT::BillingGroup",
  "additionalProperties" : False,
  "properties" : {
    "Id" : {
      "type" : "string"
    },
    "Arn" : {
      "type" : "string"
    },
    "BillingGroupName" : {
      "type" : "string",
      "pattern" : "[a-zA-Z0-9:_-]+",
      "minLength" : 1,
      "maxLength" : 128
    },
    "Tags" : {
      "description" : "An array of key-value pairs to apply to this resource.",
      "type" : "array",
      "maxItems" : 50,
      "uniqueItems" : True,
      "insertionOrder" : False,
      "items" : {
        "$ref" : "#/definitions/Tag"
      }
    },
    "BillingGroupProperties" : {
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "BillingGroupDescription" : {
          "type" : "string",
          "maxLength" : 2028,
          "pattern" : "[\\p{Graph}\\x20]*"
        }
      }
    }
  },
  "definitions" : {
    "Tag" : {
      "description" : "A key-value pair to associate with a resource.",
      "type" : "object",
      "properties" : {
        "Key" : {
          "type" : "string",
          "description" : "Tag key (1-128 chars). No 'aws:' prefix. Allows: [A-Za-z0-9 _.:/=+-]",
          "minLength" : 1,
          "maxLength" : 128,
          "pattern" : "^([\\p{L}\\p{Z}\\p{N}_.:/=+\\-@]*)$"
        },
        "Value" : {
          "type" : "string",
          "description" : "Tag value (1-256 chars). No 'aws:' prefix. Allows: [A-Za-z0-9 _.:/=+-]",
          "minLength" : 1,
          "maxLength" : 256
        }
      },
      "required" : [ "Key", "Value" ],
      "additionalProperties" : False
    }
  },
  "tagging" : {
    "taggable" : True,
    "tagOnCreate" : True,
    "tagUpdatable" : True,
    "cloudFormationSystemTags" : True,
    "tagProperty" : "/properties/Tags",
    "permissions" : [ "iot:ListTagsForResource", "iot:TagResource", "iot:UntagResource" ]
  },
  "readOnlyProperties" : [ "/properties/Arn", "/properties/Id" ],
  "createOnlyProperties" : [ "/properties/BillingGroupName" ],
  "primaryIdentifier" : [ "/properties/BillingGroupName" ],
  "handlers" : {
    "create" : {
      "permissions" : [ "iot:DescribeBillingGroup", "iot:ListTagsForResource", "iot:CreateBillingGroup", "iot:TagResource" ]
    },
    "delete" : {
      "permissions" : [ "iot:DescribeBillingGroup", "iot:DeleteBillingGroup" ]
    },
    "list" : {
      "permissions" : [ "iot:ListBillingGroups", "iot:ListTagsForResource" ]
    },
    "read" : {
      "permissions" : [ "iot:DescribeBillingGroup", "iot:ListTagsForResource" ]
    },
    "update" : {
      "permissions" : [ "iot:DescribeBillingGroup", "iot:UpdateBillingGroup", "iot:ListTagsForResource", "iot:TagResource", "iot:UntagResource" ]
    }
  }
}