SCHEMA = {
  "typeName" : "AWS::IoT::CertificateProvider",
  "description" : "Use the AWS::IoT::CertificateProvider resource to declare an AWS IoT Certificate Provider.",
  "sourceUrl" : "https://github.com/aws-cloudformation/aws-cloudformation-rpdk.git",
  "definitions" : {
    "Tag" : {
      "description" : "A key-value pair to associate with a resource.",
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "Key" : {
          "type" : "string",
          "description" : "The key name of the tag. You can specify a value that is 1 to 127 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -.",
          "minLength" : 1,
          "maxLength" : 127
        },
        "Value" : {
          "type" : "string",
          "description" : "The value for the tag. You can specify a value that is 1 to 255 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -.",
          "minLength" : 1,
          "maxLength" : 255
        }
      },
      "required" : [ "Value", "Key" ]
    },
    "CertificateProviderOperation" : {
      "type" : "string",
      "enum" : [ "CreateCertificateFromCsr" ]
    }
  },
  "properties" : {
    "CertificateProviderName" : {
      "type" : "string",
      "pattern" : "[\\w=,@-]+",
      "minLength" : 1,
      "maxLength" : 128
    },
    "LambdaFunctionArn" : {
      "type" : "string",
      "minLength" : 1,
      "maxLength" : 170
    },
    "AccountDefaultForOperations" : {
      "type" : "array",
      "minItems" : 1,
      "maxItems" : 1,
      "uniqueItems" : True,
      "insertionOrder" : False,
      "items" : {
        "$ref" : "#/definitions/CertificateProviderOperation"
      }
    },
    "Tags" : {
      "description" : "An array of key-value pairs to apply to this resource.",
      "type" : "array",
      "maxItems" : 50,
      "uniqueItems" : True,
      "insertionOrder" : False,
      "items" : {
        "$ref" : "#/definitions/Tag"
      }
    },
    "Arn" : {
      "type" : "string"
    }
  },
  "tagging" : {
    "taggable" : True,
    "tagOnCreate" : True,
    "tagUpdatable" : True,
    "cloudFormationSystemTags" : True,
    "tagProperty" : "/properties/Tags",
    "permissions" : [ "iot:ListTagsForResource", "iot:TagResource", "iot:UntagResource" ]
  },
  "replacementStrategy" : "delete_then_create",
  "additionalProperties" : False,
  "required" : [ "LambdaFunctionArn", "AccountDefaultForOperations" ],
  "readOnlyProperties" : [ "/properties/Arn" ],
  "createOnlyProperties" : [ "/properties/CertificateProviderName" ],
  "primaryIdentifier" : [ "/properties/CertificateProviderName" ],
  "handlers" : {
    "create" : {
      "permissions" : [ "iot:CreateCertificateProvider", "iot:DescribeCertificateProvider", "iot:TagResource", "iot:ListTagsForResource" ]
    },
    "read" : {
      "permissions" : [ "iot:DescribeCertificateProvider", "iot:ListTagsForResource" ]
    },
    "update" : {
      "permissions" : [ "iot:UpdateCertificateProvider", "iot:DescribeCertificateProvider", "iot:TagResource", "iot:UntagResource", "iot:ListTagsForResource" ]
    },
    "delete" : {
      "permissions" : [ "iot:DeleteCertificateProvider", "iot:DescribeCertificateProvider" ]
    },
    "list" : {
      "permissions" : [ "iot:ListCertificateProviders" ]
    }
  }
}