SCHEMA = {
  "typeName" : "AWS::IoT::SoftwarePackage",
  "description" : "resource definition",
  "definitions" : {
    "Tag" : {
      "description" : "A key-value pair to associate with a resource.",
      "type" : "object",
      "properties" : {
        "Key" : {
          "type" : "string",
          "description" : "The key name of the tag. You can specify a value that is 1 to 128 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -. ",
          "minLength" : 1,
          "maxLength" : 128,
          "pattern" : "^([\\p{L}\\p{Z}\\p{N}_.:/=+\\-@]*)$"
        },
        "Value" : {
          "type" : "string",
          "description" : "The value for the tag. You can specify a value that is 1 to 256 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -. ",
          "minLength" : 1,
          "maxLength" : 256
        }
      },
      "required" : [ "Key", "Value" ],
      "additionalProperties" : False
    }
  },
  "properties" : {
    "Description" : {
      "type" : "string",
      "maxLength" : 1024,
      "minLength" : 0,
      "pattern" : "^[^\\p{C}]+$"
    },
    "PackageArn" : {
      "type" : "string"
    },
    "PackageName" : {
      "type" : "string",
      "maxLength" : 128,
      "minLength" : 1,
      "pattern" : "^[a-zA-Z0-9-_.]+$"
    },
    "Tags" : {
      "description" : "An array of key-value pairs to apply to this resource.",
      "type" : "array",
      "maxItems" : 50,
      "uniqueItems" : True,
      "insertionOrder" : False,
      "items" : {
        "$ref" : "#/definitions/Tag"
      }
    }
  },
  "tagging" : {
    "taggable" : True,
    "tagOnCreate" : True,
    "tagUpdatable" : True,
    "cloudFormationSystemTags" : False,
    "tagProperty" : "/properties/Tags",
    "permissions" : [ "iot:TagResource", "iot:UntagResource", "iot:ListTagsForResource" ]
  },
  "readOnlyProperties" : [ "/properties/PackageArn" ],
  "createOnlyProperties" : [ "/properties/PackageName" ],
  "primaryIdentifier" : [ "/properties/PackageName" ],
  "handlers" : {
    "create" : {
      "permissions" : [ "iot:CreatePackage", "iot:GetPackage", "iot:TagResource", "iot:GetIndexingConfiguration" ]
    },
    "read" : {
      "permissions" : [ "iot:GetPackage", "iot:ListTagsForResource" ]
    },
    "update" : {
      "permissions" : [ "iot:CreatePackage", "iot:UpdatePackage", "iot:GetPackage", "iot:ListTagsForResource", "iot:TagResource", "iot:UntagResource", "iot:GetIndexingConfiguration" ]
    },
    "delete" : {
      "permissions" : [ "iot:DeletePackage", "iot:DeletePackageVersion", "iot:GetPackage", "iot:GetPackageVersion", "iot:UpdatePackage", "iot:UpdatePackageVersion", "iot:GetIndexingConfiguration", "iot:ListPackageVersions" ]
    },
    "list" : {
      "permissions" : [ "iot:ListPackages" ]
    }
  },
  "additionalProperties" : False
}