SCHEMA = {
  "typeName" : "AWS::IoTFleetWise::Vehicle",
  "description" : "Definition of AWS::IoTFleetWise::Vehicle Resource Type",
  "definitions" : {
    "VehicleAssociationBehavior" : {
      "type" : "string",
      "enum" : [ "CreateIotThing", "ValidateIotThingExists" ]
    },
    "attributesMap" : {
      "type" : "object",
      "patternProperties" : {
        "^[a-zA-Z0-9_.-]+$" : {
          "type" : "string"
        }
      },
      "minProperties" : 1,
      "additionalProperties" : False
    },
    "Tag" : {
      "type" : "object",
      "properties" : {
        "Key" : {
          "type" : "string",
          "maxLength" : 128,
          "minLength" : 1
        },
        "Value" : {
          "type" : "string",
          "maxLength" : 256,
          "minLength" : 0
        }
      },
      "required" : [ "Key", "Value" ],
      "additionalProperties" : False
    },
    "OnChangeStateTemplateUpdateStrategy" : {
      "additionalProperties" : False,
      "type" : "object"
    },
    "PeriodicStateTemplateUpdateStrategy" : {
      "additionalProperties" : False,
      "type" : "object",
      "properties" : {
        "StateTemplateUpdateRate" : {
          "$ref" : "#/definitions/TimePeriod"
        }
      },
      "required" : [ "StateTemplateUpdateRate" ]
    },
    "StateTemplateUpdateStrategy" : {
      "oneOf" : [ {
        "additionalProperties" : False,
        "type" : "object",
        "properties" : {
          "Periodic" : {
            "$ref" : "#/definitions/PeriodicStateTemplateUpdateStrategy"
          }
        },
        "required" : [ "Periodic" ]
      }, {
        "additionalProperties" : False,
        "type" : "object",
        "properties" : {
          "OnChange" : {
            "$ref" : "#/definitions/OnChangeStateTemplateUpdateStrategy"
          }
        },
        "required" : [ "OnChange" ]
      } ]
    },
    "StateTemplateAssociation" : {
      "type" : "object",
      "properties" : {
        "Identifier" : {
          "type" : "string",
          "maxLength" : 100,
          "minLength" : 1
        },
        "StateTemplateUpdateStrategy" : {
          "$ref" : "#/definitions/StateTemplateUpdateStrategy"
        }
      },
      "required" : [ "Identifier", "StateTemplateUpdateStrategy" ],
      "additionalProperties" : False,
      "minProperties" : 0
    },
    "TimePeriod" : {
      "type" : "object",
      "properties" : {
        "Unit" : {
          "$ref" : "#/definitions/TimeUnit"
        },
        "Value" : {
          "type" : "number",
          "minimum" : 1
        }
      },
      "required" : [ "Unit", "Value" ],
      "additionalProperties" : False
    },
    "TimeUnit" : {
      "type" : "string",
      "enum" : [ "MILLISECOND", "SECOND", "MINUTE", "HOUR" ]
    }
  },
  "properties" : {
    "Arn" : {
      "type" : "string"
    },
    "AssociationBehavior" : {
      "$ref" : "#/definitions/VehicleAssociationBehavior"
    },
    "Attributes" : {
      "$ref" : "#/definitions/attributesMap"
    },
    "CreationTime" : {
      "type" : "string",
      "format" : "date-time"
    },
    "DecoderManifestArn" : {
      "type" : "string"
    },
    "Name" : {
      "type" : "string",
      "maxLength" : 100,
      "minLength" : 1,
      "pattern" : "^[a-zA-Z\\d\\-_:]+$"
    },
    "LastModificationTime" : {
      "type" : "string",
      "format" : "date-time"
    },
    "ModelManifestArn" : {
      "type" : "string"
    },
    "Tags" : {
      "type" : "array",
      "items" : {
        "$ref" : "#/definitions/Tag"
      },
      "insertionOrder" : False,
      "uniqueItems" : True,
      "maxItems" : 50,
      "minItems" : 0
    },
    "StateTemplates" : {
      "type" : "array",
      "insertionOrder" : False,
      "uniqueItems" : True,
      "items" : {
        "$ref" : "#/definitions/StateTemplateAssociation"
      },
      "maxItems" : 20,
      "minItems" : 0
    }
  },
  "required" : [ "Name", "DecoderManifestArn", "ModelManifestArn" ],
  "tagging" : {
    "taggable" : True,
    "tagOnCreate" : True,
    "tagUpdatable" : True,
    "cloudFormationSystemTags" : True,
    "tagProperty" : "/properties/Tags",
    "permissions" : [ "iotfleetwise:UntagResource", "iotfleetwise:TagResource", "iotfleetwise:ListTagsForResource" ]
  },
  "readOnlyProperties" : [ "/properties/Arn", "/properties/CreationTime", "/properties/LastModificationTime" ],
  "createOnlyProperties" : [ "/properties/Name" ],
  "writeOnlyProperties" : [ "/properties/AssociationBehavior" ],
  "primaryIdentifier" : [ "/properties/Name" ],
  "handlers" : {
    "create" : {
      "permissions" : [ "iotfleetwise:GetVehicle", "iotfleetwise:CreateVehicle", "iot:CreateThing", "iot:DescribeThing", "iotfleetwise:ListTagsForResource", "iotfleetwise:ListVehicles", "iotfleetwise:TagResource" ]
    },
    "read" : {
      "permissions" : [ "iotfleetwise:GetVehicle", "iotfleetwise:ListTagsForResource" ]
    },
    "update" : {
      "permissions" : [ "iotfleetwise:GetVehicle", "iotfleetwise:UpdateVehicle", "iotfleetwise:ListTagsForResource", "iotfleetwise:TagResource", "iotfleetwise:UntagResource" ]
    },
    "delete" : {
      "permissions" : [ "iotfleetwise:GetVehicle", "iotfleetwise:DeleteVehicle" ]
    },
    "list" : {
      "permissions" : [ "iotfleetwise:ListVehicles" ]
    }
  },
  "additionalProperties" : False
}