SCHEMA = {
  "typeName" : "AWS::IVS::IngestConfiguration",
  "description" : "Resource Type definition for AWS::IVS::IngestConfiguration",
  "sourceUrl" : "https://github.com/aws-cloudformation/aws-cloudformation-rpdk.git",
  "definitions" : {
    "Tag" : {
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "Key" : {
          "type" : "string",
          "description" : "The key name of the tag. You can specify a value that is 1 to 128 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -.",
          "minLength" : 1,
          "maxLength" : 128
        },
        "Value" : {
          "type" : "string",
          "description" : "The value for the tag. You can specify a value that is 0 to 256 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -.",
          "minLength" : 0,
          "maxLength" : 256
        }
      },
      "required" : [ "Value", "Key" ]
    }
  },
  "properties" : {
    "Arn" : {
      "description" : "IngestConfiguration ARN is automatically generated on creation and assigned as the unique identifier.",
      "type" : "string",
      "pattern" : "^arn:aws:ivs:[a-z0-9-]+:[0-9]+:ingest-configuration/[a-zA-Z0-9-]+$",
      "minLength" : 1,
      "maxLength" : 128
    },
    "Name" : {
      "description" : "IngestConfiguration",
      "type" : "string",
      "minLength" : 0,
      "maxLength" : 128,
      "pattern" : "^[a-zA-Z0-9-_]*$",
      "default" : "-"
    },
    "StageArn" : {
      "description" : "Stage ARN. A value other than an empty string indicates that stage is linked to IngestConfiguration. Default: \"\" (recording is disabled).",
      "type" : "string",
      "default" : "",
      "pattern" : "^arn:aws:ivs:[a-z0-9-]+:[0-9]+:stage/[a-zA-Z0-9-]+$",
      "minLength" : 0,
      "maxLength" : 128
    },
    "ParticipantId" : {
      "description" : "Participant Id is automatically generated on creation and assigned.",
      "type" : "string",
      "minLength" : 0,
      "maxLength" : 64,
      "pattern" : "^[a-zA-Z0-9-_]*$"
    },
    "IngestProtocol" : {
      "description" : "Ingest Protocol.",
      "type" : "string",
      "enum" : [ "RTMP", "RTMPS" ],
      "default" : "RTMPS"
    },
    "InsecureIngest" : {
      "description" : "Whether ingest configuration allows insecure ingest.",
      "type" : "boolean",
      "default" : False
    },
    "State" : {
      "description" : "State of IngestConfiguration which determines whether IngestConfiguration is in use or not.",
      "type" : "string",
      "enum" : [ "ACTIVE", "INACTIVE" ],
      "default" : "INACTIVE"
    },
    "StreamKey" : {
      "description" : "Stream-key value.",
      "type" : "string"
    },
    "UserId" : {
      "description" : "User defined indentifier for participant associated with IngestConfiguration.",
      "type" : "string"
    },
    "Tags" : {
      "description" : "A list of key-value pairs that contain metadata for the asset model.",
      "type" : "array",
      "uniqueItems" : True,
      "insertionOrder" : False,
      "maxItems" : 50,
      "items" : {
        "$ref" : "#/definitions/Tag"
      }
    }
  },
  "additionalProperties" : False,
  "required" : [ ],
  "tagging" : {
    "taggable" : True,
    "tagOnCreate" : True,
    "tagUpdatable" : True,
    "cloudFormationSystemTags" : False,
    "tagProperty" : "/properties/Tags",
    "permissions" : [ "ivs:TagResource", "ivs:UntagResource", "ivs:ListTagsForResource" ]
  },
  "createOnlyProperties" : [ "/properties/InsecureIngest", "/properties/UserId", "/properties/Name", "/properties/IngestProtocol" ],
  "writeOnlyProperties" : [ "/properties/InsecureIngest" ],
  "readOnlyProperties" : [ "/properties/Arn", "/properties/ParticipantId", "/properties/StreamKey", "/properties/State" ],
  "primaryIdentifier" : [ "/properties/Arn" ],
  "handlers" : {
    "create" : {
      "permissions" : [ "ivs:CreateIngestConfiguration", "ivs:TagResource" ]
    },
    "read" : {
      "permissions" : [ "ivs:GetIngestConfiguration", "ivs:ListTagsForResource" ]
    },
    "update" : {
      "permissions" : [ "ivs:GetIngestConfiguration", "ivs:UpdateIngestConfiguration", "ivs:TagResource", "ivs:UntagResource", "ivs:ListTagsForResource" ]
    },
    "delete" : {
      "permissions" : [ "ivs:DeleteIngestConfiguration", "ivs:UntagResource" ]
    },
    "list" : {
      "permissions" : [ "ivs:ListIngestConfigurations", "ivs:ListTagsForResource" ]
    }
  }
}