SCHEMA = {
  "typeName" : "AWS::KafkaConnect::WorkerConfiguration",
  "description" : "The configuration of the workers, which are the processes that run the connector logic.",
  "additionalProperties" : False,
  "sourceUrl" : "https://github.com/aws-cloudformation/aws-cloudformation-resource-providers-kafkaconnect.git",
  "properties" : {
    "Name" : {
      "description" : "The name of the worker configuration.",
      "type" : "string",
      "minLength" : 1,
      "maxLength" : 128
    },
    "Description" : {
      "description" : "A summary description of the worker configuration.",
      "type" : "string",
      "maxLength" : 1024
    },
    "WorkerConfigurationArn" : {
      "description" : "The Amazon Resource Name (ARN) of the custom configuration.",
      "type" : "string",
      "pattern" : "arn:(aws|aws-us-gov|aws-cn):kafkaconnect:.*"
    },
    "PropertiesFileContent" : {
      "description" : "Base64 encoded contents of connect-distributed.properties file.",
      "type" : "string"
    },
    "Revision" : {
      "description" : "The description of a revision of the worker configuration.",
      "type" : "integer",
      "format" : "int64"
    },
    "Tags" : {
      "description" : "A collection of tags associated with a resource",
      "type" : "array",
      "uniqueItems" : True,
      "insertionOrder" : False,
      "items" : {
        "$ref" : "#/definitions/Tag"
      }
    }
  },
  "definitions" : {
    "Tag" : {
      "type" : "object",
      "properties" : {
        "Key" : {
          "type" : "string",
          "minLength" : 1,
          "maxLength" : 128
        },
        "Value" : {
          "type" : "string",
          "maxLength" : 256
        }
      },
      "required" : [ "Value", "Key" ],
      "additionalProperties" : False
    }
  },
  "required" : [ "Name", "PropertiesFileContent" ],
  "primaryIdentifier" : [ "/properties/WorkerConfigurationArn" ],
  "additionalIdentifiers" : [ [ "/properties/Name" ] ],
  "readOnlyProperties" : [ "/properties/WorkerConfigurationArn", "/properties/Revision" ],
  "createOnlyProperties" : [ "/properties/Name", "/properties/Description", "/properties/PropertiesFileContent" ],
  "tagging" : {
    "taggable" : True,
    "tagOnCreate" : True,
    "tagUpdatable" : True,
    "cloudFormationSystemTags" : True,
    "tagProperty" : "/properties/Tags",
    "permissions" : [ "kafkaconnect:ListTagsForResource", "kafkaconnect:UntagResource", "kafkaconnect:TagResource" ]
  },
  "handlers" : {
    "create" : {
      "permissions" : [ "kafkaconnect:DescribeWorkerConfiguration", "kafkaconnect:CreateWorkerConfiguration", "kafkaconnect:TagResource", "kafkaconnect:ListTagsForResource" ]
    },
    "read" : {
      "permissions" : [ "kafkaconnect:DescribeWorkerConfiguration", "kafkaconnect:ListTagsForResource" ]
    },
    "update" : {
      "permissions" : [ "kafkaconnect:DescribeWorkerConfiguration", "kafkaconnect:ListTagsForResource", "kafkaconnect:TagResource", "kafkaconnect:UntagResource" ]
    },
    "delete" : {
      "permissions" : [ "kafkaconnect:DescribeWorkerConfiguration", "kafkaconnect:DeleteWorkerConfiguration" ]
    },
    "list" : {
      "permissions" : [ "kafkaconnect:ListWorkerConfigurations" ]
    }
  }
}