SCHEMA = {
  "typeName" : "AWS::KinesisVideo::SignalingChannel",
  "description" : "Resource Type Definition for AWS::KinesisVideo::SignalingChannel",
  "sourceUrl" : "https://github.com/aws-cloudformation/aws-cloudformation-resource-providers-kinesisvideo.git",
  "definitions" : {
    "Tag" : {
      "description" : "A key-value pair to associate with a resource.",
      "type" : "object",
      "properties" : {
        "Key" : {
          "type" : "string",
          "description" : "The key name of the tag. Specify a value that is 1 to 128 Unicode characters in length and cannot be prefixed with aws:. The following characters can be used: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -.",
          "minLength" : 1,
          "maxLength" : 128
        },
        "Value" : {
          "type" : "string",
          "description" : "The value for the tag. Specify a value that is 0 to 256 Unicode characters in length and cannot be prefixed with aws:.  The following characters can be used: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -.",
          "minLength" : 0,
          "maxLength" : 256
        }
      },
      "required" : [ "Key", "Value" ],
      "additionalProperties" : False
    }
  },
  "properties" : {
    "Arn" : {
      "description" : "The Amazon Resource Name (ARN) of the Kinesis Video Signaling Channel.",
      "type" : "string"
    },
    "Name" : {
      "description" : "The name of the Kinesis Video Signaling Channel.",
      "type" : "string",
      "minLength" : 1,
      "maxLength" : 256,
      "pattern" : "[a-zA-Z0-9_.-]+"
    },
    "Type" : {
      "description" : "The type of the Kinesis Video Signaling Channel to create. Currently, SINGLE_MASTER is the only supported channel type.",
      "type" : "string",
      "enum" : [ "SINGLE_MASTER" ]
    },
    "MessageTtlSeconds" : {
      "description" : "The period of time a signaling channel retains undelivered messages before they are discarded.",
      "type" : "integer",
      "minimum" : 5,
      "maximum" : 120
    },
    "Tags" : {
      "description" : "An array of key-value pairs to apply to this resource.",
      "type" : "array",
      "uniqueItems" : False,
      "insertionOrder" : False,
      "items" : {
        "$ref" : "#/definitions/Tag"
      },
      "minItems" : 1,
      "maxItems" : 50
    }
  },
  "additionalProperties" : False,
  "required" : [ ],
  "readOnlyProperties" : [ "/properties/Arn" ],
  "createOnlyProperties" : [ "/properties/Name" ],
  "primaryIdentifier" : [ "/properties/Name" ],
  "tagging" : {
    "taggable" : True,
    "tagOnCreate" : True,
    "tagUpdatable" : True,
    "cloudFormationSystemTags" : False,
    "tagProperty" : "/properties/Tags",
    "permissions" : [ "kinesisvideo:TagResource", "kinesisvideo:UntagResource" ]
  },
  "handlers" : {
    "create" : {
      "permissions" : [ "kinesisvideo:CreateSignalingChannel", "kinesisvideo:DescribeSignalingChannel", "kinesisvideo:TagResource" ]
    },
    "read" : {
      "permissions" : [ "kinesisvideo:DescribeSignalingChannel", "kinesisvideo:ListTagsForResource" ]
    },
    "update" : {
      "permissions" : [ "kinesisvideo:UpdateSignalingChannel", "kinesisvideo:DescribeSignalingChannel", "kinesisvideo:TagResource", "kinesisvideo:UntagResource", "kinesisvideo:ListTagsForResource" ]
    },
    "delete" : {
      "permissions" : [ "kinesisvideo:DeleteSignalingChannel", "kinesisvideo:DescribeSignalingChannel" ]
    },
    "list" : {
      "permissions" : [ "kinesisvideo:ListSignalingChannels" ]
    }
  }
}