SCHEMA = {
  "tagging" : {
    "taggable" : False,
    "tagOnCreate" : False,
    "tagUpdatable" : False,
    "cloudFormationSystemTags" : False
  },
  "propertyTransform" : {
    "/properties/Principal" : "$join([\"^arn:aws[a-zA-Z-]*:iam::\",Principal,\":[a-zA-Z-]*\"]) $OR Principal"
  },
  "handlers" : {
    "read" : {
      "permissions" : [ "lambda:GetPolicy" ]
    },
    "create" : {
      "permissions" : [ "lambda:AddPermission" ]
    },
    "list" : {
      "permissions" : [ "lambda:GetPolicy" ],
      "handlerSchema" : {
        "properties" : {
          "FunctionName" : {
            "minLength" : 1,
            "pattern" : "^(arn:(aws[a-zA-Z-]*)?:lambda:)?([a-z]{2}((-gov)|(-iso([a-z]?)))?-[a-z]+-\\d{1}:)?(\\d{12}:)?(function:)?([a-zA-Z0-9-_]+)(:(\\$LATEST|[a-zA-Z0-9-_]+))?$",
            "description" : "The name of the Lambda function, version, or alias.",
            "type" : "string",
            "maxLength" : 140
          }
        },
        "required" : [ "FunctionName" ]
      }
    },
    "delete" : {
      "permissions" : [ "lambda:RemovePermission" ]
    }
  },
  "typeName" : "AWS::Lambda::Permission",
  "readOnlyProperties" : [ "/properties/Id" ],
  "description" : "The ``AWS::Lambda::Permission`` resource grants an AWS service or another account permission to use a function. You can apply the policy at the function level, or specify a qualifier to restrict access to a single version or alias. If you use a qualifier, the invoker must use the full Amazon Resource Name (ARN) of that version or alias to invoke the function.\n To grant permission to another account, specify the account ID as the ``Principal``. To grant permission to an organization defined in AOlong, specify the organization ID as the ``PrincipalOrgID``. For AWS services, the principal is a domain-style identifier defined by the service, like ``s3.amazonaws.com`` or ``sns.amazonaws.com``. For AWS services, you can also specify the ARN of the associated resource as the ``SourceArn``. If you grant permission to a service principal without specifying the source, other accounts could potentially configure resources in their account to invoke your Lambda function.\n If your function has a function URL, you can specify the ``FunctionUrlAuthType`` parameter. This adds a condition to your permission that only applies when your function URL's ``AuthType`` matches the specified ``FunctionUrlAuthType``. For more information about the ``AuthType`` parameter, see [Security and auth model for function URLs](https://docs.aws.amazon.com/lambda/latest/dg/urls-auth.html).\n This resource adds a statement to a resource-based permission policy for the function. For more information about function policies, see [Lambda Function Policies](https://docs.aws.amazon.com/lambda/latest/dg/access-control-resource-based.html).",
  "createOnlyProperties" : [ "/properties/FunctionName", "/properties/FunctionUrlAuthType", "/properties/SourceAccount", "/properties/SourceArn", "/properties/Principal", "/properties/PrincipalOrgID", "/properties/Action", "/properties/EventSourceToken" ],
  "additionalProperties" : False,
  "primaryIdentifier" : [ "/properties/FunctionName", "/properties/Id" ],
  "properties" : {
    "FunctionName" : {
      "minLength" : 1,
      "pattern" : "^(arn:(aws[a-zA-Z-]*)?:lambda:)?([a-z]{2}((-gov)|(-iso([a-z]?)))?-[a-z]+-\\d{1}:)?(\\d{12}:)?(function:)?([a-zA-Z0-9-_]+)(:(\\$LATEST|[a-zA-Z0-9-_]+))?$",
      "description" : "The name or ARN of the Lambda function, version, or alias.\n  **Name formats**\n +  *Function name* – ``my-function`` (name-only), ``my-function:v1`` (with alias).\n  +  *Function ARN* – ``arn:aws:lambda:us-west-2:123456789012:function:my-function``.\n  +  *Partial ARN* – ``123456789012:function:my-function``.\n  \n You can append a version number or alias to any of the formats. The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.",
      "type" : "string",
      "maxLength" : 140
    },
    "Action" : {
      "minLength" : 1,
      "pattern" : "^(lambda:[*]|lambda:[a-zA-Z]+|[*])$",
      "description" : "The action that the principal can use on the function. For example, ``lambda:InvokeFunction`` or ``lambda:GetFunction``.",
      "type" : "string",
      "maxLength" : 256
    },
    "EventSourceToken" : {
      "minLength" : 1,
      "pattern" : "^[a-zA-Z0-9._\\-]+$",
      "description" : "For Alexa Smart Home functions, a token that the invoker must supply.",
      "type" : "string",
      "maxLength" : 256
    },
    "FunctionUrlAuthType" : {
      "description" : "The type of authentication that your function URL uses. Set to ``AWS_IAM`` if you want to restrict access to authenticated users only. Set to ``NONE`` if you want to bypass IAM authentication to create a public endpoint. For more information, see [Security and auth model for Lambda function URLs](https://docs.aws.amazon.com/lambda/latest/dg/urls-auth.html).",
      "type" : "string",
      "enum" : [ "AWS_IAM", "NONE" ]
    },
    "SourceArn" : {
      "minLength" : 12,
      "pattern" : "^arn:(aws[a-zA-Z0-9-]*):([a-zA-Z0-9\\-])+:([a-z]{2}((-gov)|(-iso([a-z]?)))?-[a-z]+-\\d{1})?:(\\d{12})?:(.*)$",
      "description" : "For AWS-services, the ARN of the AWS resource that invokes the function. For example, an Amazon S3 bucket or Amazon SNS topic.\n Note that Lambda configures the comparison using the ``StringLike`` operator.",
      "type" : "string",
      "maxLength" : 1024
    },
    "SourceAccount" : {
      "minLength" : 12,
      "pattern" : "^\\d{12}$",
      "description" : "For AWS-service, the ID of the AWS-account that owns the resource. Use this together with ``SourceArn`` to ensure that the specified account owns the resource. It is possible for an Amazon S3 bucket to be deleted by its owner and recreated by another account.",
      "type" : "string",
      "maxLength" : 12
    },
    "PrincipalOrgID" : {
      "minLength" : 12,
      "pattern" : "^o-[a-z0-9]{10,32}$",
      "description" : "The identifier for your organization in AOlong. Use this to grant permissions to all the AWS-accounts under this organization.",
      "type" : "string",
      "maxLength" : 34
    },
    "Id" : {
      "minLength" : 1,
      "pattern" : "^.*$",
      "description" : "",
      "type" : "string",
      "maxLength" : 256
    },
    "Principal" : {
      "minLength" : 1,
      "pattern" : "^.*$",
      "description" : "The AWS-service, AWS-account, IAM user, or IAM role that invokes the function. If you specify a service, use ``SourceArn`` or ``SourceAccount`` to limit who can invoke the function through that service.",
      "type" : "string",
      "maxLength" : 256
    }
  },
  "required" : [ "FunctionName", "Action", "Principal" ]
}