SCHEMA = {
  "typeName" : "AWS::Logs::QueryDefinition",
  "description" : "The resource schema for AWSLogs QueryDefinition",
  "sourceUrl" : "https://github.com/aws-cloudformation/aws-cloudformation-resource-providers-logs.git",
  "definitions" : {
    "LogGroup" : {
      "type" : "string",
      "pattern" : "[\\.\\-_/#A-Za-z0-9]+",
      "minLength" : 1,
      "maxLength" : 512
    }
  },
  "properties" : {
    "Name" : {
      "description" : "A name for the saved query definition",
      "type" : "string",
      "minLength" : 1,
      "maxLength" : 255
    },
    "QueryString" : {
      "description" : "The query string to use for this definition",
      "type" : "string",
      "minLength" : 1,
      "maxLength" : 10000
    },
    "LogGroupNames" : {
      "description" : "Optionally define specific log groups as part of your query definition",
      "type" : "array",
      "insertionOrder" : False,
      "items" : {
        "description" : "LogGroup name",
        "$ref" : "#/definitions/LogGroup"
      }
    },
    "QueryDefinitionId" : {
      "description" : "Unique identifier of a query definition",
      "type" : "string",
      "minLength" : 0,
      "maxLength" : 256
    },
    "QueryLanguage" : {
      "description" : "Query language of the query string. Possible values are CWLI, SQL, PPL, with CWLI being the default.",
      "type" : "string",
      "enum" : [ "CWLI", "SQL", "PPL" ],
      "default" : "CWLI"
    }
  },
  "required" : [ "Name", "QueryString" ],
  "additionalProperties" : False,
  "readOnlyProperties" : [ "/properties/QueryDefinitionId" ],
  "primaryIdentifier" : [ "/properties/QueryDefinitionId" ],
  "handlers" : {
    "create" : {
      "permissions" : [ "logs:PutQueryDefinition" ]
    },
    "read" : {
      "permissions" : [ "logs:DescribeQueryDefinitions" ]
    },
    "update" : {
      "permissions" : [ "logs:PutQueryDefinition" ]
    },
    "delete" : {
      "permissions" : [ "logs:DeleteQueryDefinition" ]
    },
    "list" : {
      "permissions" : [ "logs:DescribeQueryDefinitions" ]
    }
  },
  "tagging" : {
    "taggable" : False
  }
}