SCHEMA = {
  "typeName" : "AWS::LookoutVision::Project",
  "description" : "The AWS::LookoutVision::Project type creates an Amazon Lookout for Vision project. A project is a grouping of the resources needed to create and manage a Lookout for Vision model.",
  "sourceUrl" : "https://docs.aws.amazon.com/lookout-for-vision/latest/developer-guide/model-create-project.html",
  "definitions" : {
    "Arn" : {
      "type" : "string",
      "maxLength" : 1000
    },
    "ProjectName" : {
      "description" : "The name of the Amazon Lookout for Vision project",
      "type" : "string",
      "minLength" : 1,
      "maxLength" : 255,
      "pattern" : "[a-zA-Z0-9][a-zA-Z0-9_\\-]*"
    }
  },
  "properties" : {
    "Arn" : {
      "$ref" : "#/definitions/Arn"
    },
    "ProjectName" : {
      "$ref" : "#/definitions/ProjectName"
    }
  },
  "tagging" : {
    "taggable" : False
  },
  "additionalProperties" : False,
  "required" : [ "ProjectName" ],
  "readOnlyProperties" : [ "/properties/Arn" ],
  "createOnlyProperties" : [ "/properties/ProjectName" ],
  "primaryIdentifier" : [ "/properties/ProjectName" ],
  "handlers" : {
    "create" : {
      "permissions" : [ "lookoutvision:CreateProject" ],
      "timeoutInMinutes" : 15
    },
    "read" : {
      "permissions" : [ "lookoutvision:DescribeProject" ],
      "timeoutInMinutes" : 15
    },
    "update" : {
      "permissions" : [ ],
      "timeoutInMinutes" : 15
    },
    "delete" : {
      "permissions" : [ "lookoutvision:DeleteProject" ],
      "timeoutInMinutes" : 15
    },
    "list" : {
      "permissions" : [ "lookoutvision:ListProjects" ],
      "timeoutInMinutes" : 15
    }
  }
}