SCHEMA = {
  "typeName" : "AWS::MediaPackage::OriginEndpoint",
  "description" : "Resource schema for AWS::MediaPackage::OriginEndpoint",
  "sourceUrl" : "https://github.com/aws-cloudformation/aws-cloudformation-rpdk.git",
  "properties" : {
    "Arn" : {
      "description" : "The Amazon Resource Name (ARN) assigned to the OriginEndpoint.",
      "type" : "string"
    },
    "Url" : {
      "description" : "The URL of the packaged OriginEndpoint for consumption.",
      "type" : "string"
    },
    "Id" : {
      "description" : "The ID of the OriginEndpoint.",
      "type" : "string",
      "pattern" : "\\A[0-9a-zA-Z-_]+\\Z",
      "minLength" : 1,
      "maxLength" : 256
    },
    "ChannelId" : {
      "description" : "The ID of the Channel the OriginEndpoint is associated with.",
      "type" : "string"
    },
    "Description" : {
      "description" : "A short text description of the OriginEndpoint.",
      "type" : "string"
    },
    "Whitelist" : {
      "description" : "A list of source IP CIDR blocks that will be allowed to access the OriginEndpoint.",
      "type" : "array",
      "items" : {
        "type" : "string"
      }
    },
    "StartoverWindowSeconds" : {
      "description" : "Maximum duration (seconds) of content to retain for startover playback. If not specified, startover playback will be disabled for the OriginEndpoint.",
      "type" : "integer"
    },
    "TimeDelaySeconds" : {
      "description" : "Amount of delay (seconds) to enforce on the playback of live content. If not specified, there will be no time delay in effect for the OriginEndpoint.",
      "type" : "integer"
    },
    "ManifestName" : {
      "description" : "A short string appended to the end of the OriginEndpoint URL.",
      "type" : "string"
    },
    "Origination" : {
      "description" : "Control whether origination of video is allowed for this OriginEndpoint. If set to ALLOW, the OriginEndpoint may by requested, pursuant to any other form of access control. If set to DENY, the OriginEndpoint may not be requested. This can be helpful for Live to VOD harvesting, or for temporarily disabling origination",
      "type" : "string",
      "enum" : [ "ALLOW", "DENY" ]
    },
    "Authorization" : {
      "$ref" : "#/definitions/Authorization"
    },
    "HlsPackage" : {
      "$ref" : "#/definitions/HlsPackage"
    },
    "DashPackage" : {
      "$ref" : "#/definitions/DashPackage"
    },
    "MssPackage" : {
      "$ref" : "#/definitions/MssPackage"
    },
    "CmafPackage" : {
      "$ref" : "#/definitions/CmafPackage"
    },
    "Tags" : {
      "description" : "A collection of tags associated with a resource",
      "type" : "array",
      "uniqueItems" : True,
      "items" : {
        "$ref" : "#/definitions/Tag"
      }
    }
  },
  "definitions" : {
    "MssPackage" : {
      "description" : "A Microsoft Smooth Streaming (MSS) packaging configuration.",
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "ManifestWindowSeconds" : {
          "description" : "The time window (in seconds) contained in each manifest.",
          "type" : "integer"
        },
        "SegmentDurationSeconds" : {
          "description" : "The duration (in seconds) of each segment.",
          "type" : "integer"
        },
        "Encryption" : {
          "$ref" : "#/definitions/MssEncryption"
        },
        "StreamSelection" : {
          "$ref" : "#/definitions/StreamSelection"
        }
      }
    },
    "MssEncryption" : {
      "description" : "A Microsoft Smooth Streaming (MSS) encryption configuration.",
      "type" : "object",
      "additionalProperties" : False,
      "required" : [ "SpekeKeyProvider" ],
      "properties" : {
        "SpekeKeyProvider" : {
          "$ref" : "#/definitions/SpekeKeyProvider"
        }
      }
    },
    "DashPackage" : {
      "description" : "A Dynamic Adaptive Streaming over HTTP (DASH) packaging configuration.",
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "SegmentDurationSeconds" : {
          "description" : "Duration (in seconds) of each segment. Actual segments will be rounded to the nearest multiple of the source segment duration.",
          "type" : "integer"
        },
        "ManifestWindowSeconds" : {
          "description" : "Time window (in seconds) contained in each manifest.",
          "type" : "integer"
        },
        "Profile" : {
          "description" : "The Dynamic Adaptive Streaming over HTTP (DASH) profile type.  When set to \"HBBTV_1_5\", HbbTV 1.5 compliant output is enabled.",
          "type" : "string",
          "enum" : [ "NONE", "HBBTV_1_5", "HYBRIDCAST", "DVB_DASH_2014" ]
        },
        "MinUpdatePeriodSeconds" : {
          "description" : "Minimum duration (in seconds) between potential changes to the Dynamic Adaptive Streaming over HTTP (DASH) Media Presentation Description (MPD).",
          "type" : "integer"
        },
        "MinBufferTimeSeconds" : {
          "description" : "Minimum duration (in seconds) that a player will buffer media before starting the presentation.",
          "type" : "integer"
        },
        "SuggestedPresentationDelaySeconds" : {
          "description" : "Duration (in seconds) to delay live content before presentation.",
          "type" : "integer"
        },
        "PeriodTriggers" : {
          "description" : "A list of triggers that controls when the outgoing Dynamic Adaptive Streaming over HTTP (DASH) Media Presentation Description (MPD) will be partitioned into multiple periods. If empty, the content will not be partitioned into more than one period. If the list contains \"ADS\", new periods will be created where the Channel source contains SCTE-35 ad markers.",
          "type" : "array",
          "items" : {
            "type" : "string",
            "enum" : [ "ADS" ]
          }
        },
        "IncludeIframeOnlyStream" : {
          "description" : "When enabled, an I-Frame only stream will be included in the output.",
          "type" : "boolean"
        },
        "ManifestLayout" : {
          "description" : "Determines the position of some tags in the Media Presentation Description (MPD).  When set to FULL, elements like SegmentTemplate and ContentProtection are included in each Representation.  When set to COMPACT, duplicate elements are combined and presented at the AdaptationSet level.",
          "type" : "string",
          "enum" : [ "FULL", "COMPACT", "DRM_TOP_LEVEL_COMPACT" ]
        },
        "SegmentTemplateFormat" : {
          "description" : "Determines the type of SegmentTemplate included in the Media Presentation Description (MPD).  When set to NUMBER_WITH_TIMELINE, a full timeline is presented in each SegmentTemplate, with $Number$ media URLs.  When set to TIME_WITH_TIMELINE, a full timeline is presented in each SegmentTemplate, with $Time$ media URLs. When set to NUMBER_WITH_DURATION, only a duration is included in each SegmentTemplate, with $Number$ media URLs.",
          "type" : "string",
          "enum" : [ "NUMBER_WITH_TIMELINE", "TIME_WITH_TIMELINE", "NUMBER_WITH_DURATION" ]
        },
        "AdTriggers" : {
          "description" : "A list of SCTE-35 message types that are treated as ad markers in the output.  If empty, no ad markers are output.  Specify multiple items to create ad markers for all of the included message types.",
          "type" : "array",
          "items" : {
            "type" : "string",
            "enum" : [ "SPLICE_INSERT", "BREAK", "PROVIDER_ADVERTISEMENT", "DISTRIBUTOR_ADVERTISEMENT", "PROVIDER_PLACEMENT_OPPORTUNITY", "DISTRIBUTOR_PLACEMENT_OPPORTUNITY", "PROVIDER_OVERLAY_PLACEMENT_OPPORTUNITY", "DISTRIBUTOR_OVERLAY_PLACEMENT_OPPORTUNITY" ]
          }
        },
        "AdsOnDeliveryRestrictions" : {
          "$ref" : "#/definitions/AdsOnDeliveryRestrictions"
        },
        "Encryption" : {
          "$ref" : "#/definitions/DashEncryption"
        },
        "StreamSelection" : {
          "$ref" : "#/definitions/StreamSelection"
        },
        "UtcTiming" : {
          "description" : "Determines the type of UTCTiming included in the Media Presentation Description (MPD)",
          "type" : "string",
          "enum" : [ "HTTP-XSDATE", "HTTP-ISO", "HTTP-HEAD", "NONE" ]
        },
        "UtcTimingUri" : {
          "description" : "Specifies the value attribute of the UTCTiming field when utcTiming is set to HTTP-ISO, HTTP-HEAD or HTTP-XSDATE",
          "type" : "string"
        }
      }
    },
    "DashEncryption" : {
      "description" : "A Dynamic Adaptive Streaming over HTTP (DASH) encryption configuration.",
      "type" : "object",
      "additionalProperties" : False,
      "required" : [ "SpekeKeyProvider" ],
      "properties" : {
        "KeyRotationIntervalSeconds" : {
          "description" : "Time (in seconds) between each encryption key rotation.",
          "type" : "integer"
        },
        "SpekeKeyProvider" : {
          "$ref" : "#/definitions/SpekeKeyProvider"
        }
      }
    },
    "Authorization" : {
      "description" : "CDN Authorization credentials",
      "type" : "object",
      "additionalProperties" : False,
      "required" : [ "SecretsRoleArn", "CdnIdentifierSecret" ],
      "properties" : {
        "SecretsRoleArn" : {
          "description" : "The Amazon Resource Name (ARN) for the IAM role that allows MediaPackage to communicate with AWS Secrets Manager.",
          "type" : "string"
        },
        "CdnIdentifierSecret" : {
          "description" : "The Amazon Resource Name (ARN) for the secret in Secrets Manager that your Content Distribution Network (CDN) uses for authorization to access your endpoint.",
          "type" : "string"
        }
      }
    },
    "HlsPackage" : {
      "description" : "An HTTP Live Streaming (HLS) packaging configuration.",
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "SegmentDurationSeconds" : {
          "description" : "Duration (in seconds) of each fragment. Actual fragments will be rounded to the nearest multiple of the source fragment duration.",
          "type" : "integer"
        },
        "PlaylistWindowSeconds" : {
          "description" : "Time window (in seconds) contained in each parent manifest.",
          "type" : "integer"
        },
        "PlaylistType" : {
          "description" : "The HTTP Live Streaming (HLS) playlist type. When either \"EVENT\" or \"VOD\" is specified, a corresponding EXT-X-PLAYLIST-TYPE entry will be included in the media playlist.",
          "type" : "string",
          "enum" : [ "NONE", "EVENT", "VOD" ]
        },
        "AdMarkers" : {
          "description" : "This setting controls how ad markers are included in the packaged OriginEndpoint. \"NONE\" will omit all SCTE-35 ad markers from the output. \"PASSTHROUGH\" causes the manifest to contain a copy of the SCTE-35 ad markers (comments) taken directly from the input HTTP Live Streaming (HLS) manifest. \"SCTE35_ENHANCED\" generates ad markers and blackout tags based on SCTE-35 messages in the input source. \"DATERANGE\" inserts EXT-X-DATERANGE tags to signal ad and program transition events in HLS and CMAF manifests. For this option, you must set a programDateTimeIntervalSeconds value that is greater than 0.",
          "type" : "string",
          "enum" : [ "NONE", "SCTE35_ENHANCED", "PASSTHROUGH", "DATERANGE" ]
        },
        "AdTriggers" : {
          "description" : "A list of SCTE-35 message types that are treated as ad markers in the output.  If empty, no ad markers are output.  Specify multiple items to create ad markers for all of the included message types.",
          "type" : "array",
          "items" : {
            "type" : "string",
            "enum" : [ "SPLICE_INSERT", "BREAK", "PROVIDER_ADVERTISEMENT", "DISTRIBUTOR_ADVERTISEMENT", "PROVIDER_PLACEMENT_OPPORTUNITY", "DISTRIBUTOR_PLACEMENT_OPPORTUNITY", "PROVIDER_OVERLAY_PLACEMENT_OPPORTUNITY", "DISTRIBUTOR_OVERLAY_PLACEMENT_OPPORTUNITY" ]
          }
        },
        "AdsOnDeliveryRestrictions" : {
          "$ref" : "#/definitions/AdsOnDeliveryRestrictions"
        },
        "ProgramDateTimeIntervalSeconds" : {
          "description" : "The interval (in seconds) between each EXT-X-PROGRAM-DATE-TIME tag inserted into manifests. Additionally, when an interval is specified ID3Timed Metadata messages will be generated every 5 seconds using the ingest time of the content. If the interval is not specified, or set to 0, then no EXT-X-PROGRAM-DATE-TIME tags will be inserted into manifests and no ID3Timed Metadata messages will be generated. Note that irrespective of this parameter, if any ID3 Timed Metadata is found in HTTP Live Streaming (HLS) input, it will be passed through to HLS output.",
          "type" : "integer"
        },
        "IncludeIframeOnlyStream" : {
          "description" : "When enabled, an I-Frame only stream will be included in the output.",
          "type" : "boolean"
        },
        "UseAudioRenditionGroup" : {
          "description" : "When enabled, audio streams will be placed in rendition groups in the output.",
          "type" : "boolean"
        },
        "IncludeDvbSubtitles" : {
          "description" : "When enabled, MediaPackage passes through digital video broadcasting (DVB) subtitles into the output.",
          "type" : "boolean"
        },
        "Encryption" : {
          "$ref" : "#/definitions/HlsEncryption"
        },
        "StreamSelection" : {
          "$ref" : "#/definitions/StreamSelection"
        }
      }
    },
    "HlsEncryption" : {
      "description" : "An HTTP Live Streaming (HLS) encryption configuration.",
      "type" : "object",
      "additionalProperties" : False,
      "required" : [ "SpekeKeyProvider" ],
      "properties" : {
        "EncryptionMethod" : {
          "description" : "The encryption method to use.",
          "type" : "string",
          "enum" : [ "AES_128", "SAMPLE_AES" ]
        },
        "ConstantInitializationVector" : {
          "description" : "A constant initialization vector for encryption (optional). When not specified the initialization vector will be periodically rotated.",
          "type" : "string"
        },
        "KeyRotationIntervalSeconds" : {
          "description" : "Interval (in seconds) between each encryption key rotation.",
          "type" : "integer"
        },
        "RepeatExtXKey" : {
          "description" : "When enabled, the EXT-X-KEY tag will be repeated in output manifests.",
          "type" : "boolean"
        },
        "SpekeKeyProvider" : {
          "$ref" : "#/definitions/SpekeKeyProvider"
        }
      }
    },
    "CmafPackage" : {
      "description" : "A Common Media Application Format (CMAF) packaging configuration.",
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "SegmentDurationSeconds" : {
          "description" : "Duration (in seconds) of each segment. Actual segments will be rounded to the nearest multiple of the source segment duration.",
          "type" : "integer"
        },
        "SegmentPrefix" : {
          "description" : "An optional custom string that is prepended to the name of each segment. If not specified, it defaults to the ChannelId.",
          "type" : "string"
        },
        "Encryption" : {
          "$ref" : "#/definitions/CmafEncryption"
        },
        "StreamSelection" : {
          "$ref" : "#/definitions/StreamSelection"
        },
        "HlsManifests" : {
          "description" : "A list of HLS manifest configurations",
          "type" : "array",
          "items" : {
            "$ref" : "#/definitions/HlsManifest"
          }
        }
      }
    },
    "CmafEncryption" : {
      "description" : "A Common Media Application Format (CMAF) encryption configuration.",
      "type" : "object",
      "additionalProperties" : False,
      "required" : [ "SpekeKeyProvider" ],
      "properties" : {
        "KeyRotationIntervalSeconds" : {
          "description" : "Time (in seconds) between each encryption key rotation.",
          "type" : "integer"
        },
        "SpekeKeyProvider" : {
          "$ref" : "#/definitions/SpekeKeyProvider"
        },
        "ConstantInitializationVector" : {
          "description" : "An optional 128-bit, 16-byte hex value represented by a 32-character string, used in conjunction with the key for encrypting blocks. If you don't specify a value, then MediaPackage creates the constant initialization vector (IV).",
          "type" : "string",
          "pattern" : "\\A[0-9a-fA-F]+\\Z",
          "minLength" : 32,
          "maxLength" : 32
        },
        "EncryptionMethod" : {
          "description" : "The encryption method used",
          "type" : "string",
          "enum" : [ "SAMPLE_AES", "AES_CTR" ]
        }
      }
    },
    "HlsManifest" : {
      "description" : "A HTTP Live Streaming (HLS) manifest configuration.",
      "type" : "object",
      "additionalProperties" : False,
      "required" : [ "Id" ],
      "properties" : {
        "Id" : {
          "description" : "The ID of the manifest. The ID must be unique within the OriginEndpoint and it cannot be changed after it is created.",
          "type" : "string"
        },
        "ManifestName" : {
          "description" : "An optional short string appended to the end of the OriginEndpoint URL. If not specified, defaults to the manifestName for the OriginEndpoint.",
          "type" : "string"
        },
        "Url" : {
          "description" : "The URL of the packaged OriginEndpoint for consumption.",
          "type" : "string"
        },
        "PlaylistWindowSeconds" : {
          "description" : "Time window (in seconds) contained in each parent manifest.",
          "type" : "integer"
        },
        "PlaylistType" : {
          "description" : "The HTTP Live Streaming (HLS) playlist type. When either \"EVENT\" or \"VOD\" is specified, a corresponding EXT-X-PLAYLIST-TYPE entry will be included in the media playlist.",
          "type" : "string",
          "enum" : [ "NONE", "EVENT", "VOD" ]
        },
        "AdMarkers" : {
          "description" : "This setting controls how ad markers are included in the packaged OriginEndpoint. \"NONE\" will omit all SCTE-35 ad markers from the output. \"PASSTHROUGH\" causes the manifest to contain a copy of the SCTE-35 ad markers (comments) taken directly from the input HTTP Live Streaming (HLS) manifest. \"SCTE35_ENHANCED\" generates ad markers and blackout tags based on SCTE-35 messages in the input source. \"DATERANGE\" inserts EXT-X-DATERANGE tags to signal ad and program transition events in HLS and CMAF manifests. For this option, you must set a programDateTimeIntervalSeconds value that is greater than 0.",
          "type" : "string",
          "enum" : [ "NONE", "SCTE35_ENHANCED", "PASSTHROUGH", "DATERANGE" ]
        },
        "ProgramDateTimeIntervalSeconds" : {
          "description" : "The interval (in seconds) between each EXT-X-PROGRAM-DATE-TIME tag inserted into manifests. Additionally, when an interval is specified ID3Timed Metadata messages will be generated every 5 seconds using the ingest time of the content. If the interval is not specified, or set to 0, then no EXT-X-PROGRAM-DATE-TIME tags will be inserted into manifests and no ID3Timed Metadata messages will be generated. Note that irrespective of this parameter, if any ID3 Timed Metadata is found in HTTP Live Streaming (HLS) input, it will be passed through to HLS output.",
          "type" : "integer"
        },
        "IncludeIframeOnlyStream" : {
          "description" : "When enabled, an I-Frame only stream will be included in the output.",
          "type" : "boolean"
        },
        "AdTriggers" : {
          "description" : "A list of SCTE-35 message types that are treated as ad markers in the output.  If empty, no ad markers are output.  Specify multiple items to create ad markers for all of the included message types.",
          "type" : "array",
          "items" : {
            "type" : "string",
            "enum" : [ "SPLICE_INSERT", "BREAK", "PROVIDER_ADVERTISEMENT", "DISTRIBUTOR_ADVERTISEMENT", "PROVIDER_PLACEMENT_OPPORTUNITY", "DISTRIBUTOR_PLACEMENT_OPPORTUNITY", "PROVIDER_OVERLAY_PLACEMENT_OPPORTUNITY", "DISTRIBUTOR_OVERLAY_PLACEMENT_OPPORTUNITY" ]
          }
        },
        "AdsOnDeliveryRestrictions" : {
          "$ref" : "#/definitions/AdsOnDeliveryRestrictions"
        }
      }
    },
    "StreamSelection" : {
      "description" : "A StreamSelection configuration.",
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "MinVideoBitsPerSecond" : {
          "description" : "The minimum video bitrate (bps) to include in output.",
          "type" : "integer"
        },
        "MaxVideoBitsPerSecond" : {
          "description" : "The maximum video bitrate (bps) to include in output.",
          "type" : "integer"
        },
        "StreamOrder" : {
          "description" : "A directive that determines the order of streams in the output.",
          "type" : "string",
          "enum" : [ "ORIGINAL", "VIDEO_BITRATE_ASCENDING", "VIDEO_BITRATE_DESCENDING" ]
        }
      }
    },
    "SpekeKeyProvider" : {
      "description" : "A configuration for accessing an external Secure Packager and Encoder Key Exchange (SPEKE) service that will provide encryption keys.",
      "type" : "object",
      "additionalProperties" : False,
      "required" : [ "ResourceId", "SystemIds", "Url", "RoleArn" ],
      "properties" : {
        "ResourceId" : {
          "description" : "The resource ID to include in key requests.",
          "type" : "string"
        },
        "SystemIds" : {
          "description" : "The system IDs to include in key requests.",
          "type" : "array",
          "items" : {
            "type" : "string"
          }
        },
        "Url" : {
          "description" : "The URL of the external key provider service.",
          "type" : "string"
        },
        "RoleArn" : {
          "description" : "An Amazon Resource Name (ARN) of an IAM role that AWS Elemental MediaPackage will assume when accessing the key provider service.",
          "type" : "string"
        },
        "CertificateArn" : {
          "description" : "An Amazon Resource Name (ARN) of a Certificate Manager certificate that MediaPackage will use for enforcing secure end-to-end data transfer with the key provider service.",
          "type" : "string"
        },
        "EncryptionContractConfiguration" : {
          "$ref" : "#/definitions/EncryptionContractConfiguration"
        }
      }
    },
    "EncryptionContractConfiguration" : {
      "description" : "The configuration to use for encrypting one or more content tracks separately for endpoints that use SPEKE 2.0.",
      "type" : "object",
      "additionalProperties" : False,
      "required" : [ "PresetSpeke20Audio", "PresetSpeke20Video" ],
      "properties" : {
        "PresetSpeke20Audio" : {
          "description" : "A collection of audio encryption presets.",
          "type" : "string",
          "enum" : [ "PRESET-AUDIO-1", "PRESET-AUDIO-2", "PRESET-AUDIO-3", "SHARED", "UNENCRYPTED" ]
        },
        "PresetSpeke20Video" : {
          "description" : "A collection of video encryption presets.",
          "type" : "string",
          "enum" : [ "PRESET-VIDEO-1", "PRESET-VIDEO-2", "PRESET-VIDEO-3", "PRESET-VIDEO-4", "PRESET-VIDEO-5", "PRESET-VIDEO-6", "PRESET-VIDEO-7", "PRESET-VIDEO-8", "SHARED", "UNENCRYPTED" ]
        }
      }
    },
    "AdsOnDeliveryRestrictions" : {
      "description" : "This setting allows the delivery restriction flags on SCTE-35 segmentation descriptors to determine whether a message signals an ad.  Choosing \"NONE\" means no SCTE-35 messages become ads.  Choosing \"RESTRICTED\" means SCTE-35 messages of the types specified in AdTriggers that contain delivery restrictions will be treated as ads.  Choosing \"UNRESTRICTED\" means SCTE-35 messages of the types specified in AdTriggers that do not contain delivery restrictions will be treated as ads.  Choosing \"BOTH\" means all SCTE-35 messages of the types specified in AdTriggers will be treated as ads.  Note that Splice Insert messages do not have these flags and are always treated as ads if specified in AdTriggers.",
      "type" : "string",
      "enum" : [ "NONE", "RESTRICTED", "UNRESTRICTED", "BOTH" ]
    },
    "Tag" : {
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "Key" : {
          "type" : "string"
        },
        "Value" : {
          "type" : "string"
        }
      },
      "required" : [ "Value", "Key" ]
    }
  },
  "tagging" : {
    "taggable" : True,
    "tagOnCreate" : True,
    "tagUpdatable" : True,
    "cloudFormationSystemTags" : False,
    "tagProperty" : "/properties/Tags",
    "permissions" : [ "mediapackage:TagResource", "mediapackage:UntagResource" ]
  },
  "additionalProperties" : False,
  "required" : [ "Id", "ChannelId" ],
  "readOnlyProperties" : [ "/properties/Arn", "/properties/Url" ],
  "primaryIdentifier" : [ "/properties/Id" ],
  "createOnlyProperties" : [ "/properties/Id" ],
  "deprecatedProperties" : [ "/properties/HlsPackage/Encryption/SpekeKeyProvider/EncryptionContractConfiguration/PresetSpeke20Audio", "/properties/HlsPackage/Encryption/SpekeKeyProvider/EncryptionContractConfiguration/PresetSpeke20Video", "/properties/MssPackage/Encryption/SpekeKeyProvider/EncryptionContractConfiguration/PresetSpeke20Audio", "/properties/MssPackage/Encryption/SpekeKeyProvider/EncryptionContractConfiguration/PresetSpeke20Video", "/properties/CmafPackage/HlsManifests/*/Url" ],
  "handlers" : {
    "create" : {
      "permissions" : [ "mediapackage:CreateOriginEndpoint", "mediapackage:DescribeOriginEndpoint", "mediapackage:DescribeChannel", "mediapackage:TagResource", "iam:PassRole", "acm:DescribeCertificate" ]
    },
    "read" : {
      "permissions" : [ "mediapackage:DescribeOriginEndpoint" ]
    },
    "update" : {
      "permissions" : [ "mediapackage:UpdateOriginEndpoint", "mediapackage:TagResource", "mediapackage:ListTagsForResource", "mediapackage:UntagResource", "mediapackage:DescribeOriginEndpoint", "iam:PassRole" ]
    },
    "delete" : {
      "permissions" : [ "mediapackage:DeleteOriginEndpoint" ]
    },
    "list" : {
      "permissions" : [ "mediapackage:ListOriginEndpoints" ]
    }
  }
}