SCHEMA = {
  "typeName" : "AWS::MediaPackageV2::OriginEndpoint",
  "description" : "<p>Represents an origin endpoint that is associated with a channel, offering a dynamically repackaged version of its content through various streaming media protocols. The content can be efficiently disseminated to end-users via a Content Delivery Network (CDN), like Amazon CloudFront.</p>",
  "definitions" : {
    "AdMarkerDash" : {
      "type" : "string",
      "enum" : [ "BINARY", "XML" ]
    },
    "AdMarkerHls" : {
      "type" : "string",
      "enum" : [ "DATERANGE" ]
    },
    "CmafEncryptionMethod" : {
      "type" : "string",
      "enum" : [ "CENC", "CBCS" ]
    },
    "ContainerType" : {
      "type" : "string",
      "enum" : [ "TS", "CMAF" ]
    },
    "DashDrmSignaling" : {
      "type" : "string",
      "enum" : [ "INDIVIDUAL", "REFERENCED" ]
    },
    "DashPeriodTrigger" : {
      "type" : "string",
      "enum" : [ "AVAILS", "DRM_KEY_ROTATION", "SOURCE_CHANGES", "SOURCE_DISRUPTIONS", "NONE" ]
    },
    "DashSegmentTemplateFormat" : {
      "type" : "string",
      "enum" : [ "NUMBER_WITH_TIMELINE" ]
    },
    "DashUtcTiming" : {
      "type" : "object",
      "description" : "<p>Determines the type of UTC timing included in the DASH Media Presentation Description (MPD).</p>",
      "properties" : {
        "TimingMode" : {
          "$ref" : "#/definitions/DashUtcTimingMode"
        },
        "TimingSource" : {
          "type" : "string",
          "maxLength" : 1024,
          "minLength" : 1,
          "description" : "<p>The the method that the player uses to synchronize to coordinated universal time (UTC) wall clock time.</p>"
        }
      },
      "additionalProperties" : False
    },
    "DashUtcTimingMode" : {
      "type" : "string",
      "enum" : [ "HTTP_HEAD", "HTTP_ISO", "HTTP_XSDATE", "UTC_DIRECT" ]
    },
    "DrmSystem" : {
      "type" : "string",
      "enum" : [ "CLEAR_KEY_AES_128", "FAIRPLAY", "PLAYREADY", "WIDEVINE", "IRDETO" ]
    },
    "Encryption" : {
      "type" : "object",
      "description" : "<p>The parameters for encrypting content.</p>",
      "properties" : {
        "ConstantInitializationVector" : {
          "type" : "string",
          "maxLength" : 32,
          "minLength" : 32,
          "pattern" : "^[0-9a-fA-F]+$",
          "description" : "<p>A 128-bit, 16-byte hex value represented by a 32-character string, used in conjunction with the key for encrypting content. If you don't specify a value, then MediaPackage creates the constant initialization vector (IV).</p>"
        },
        "EncryptionMethod" : {
          "$ref" : "#/definitions/EncryptionMethod"
        },
        "KeyRotationIntervalSeconds" : {
          "type" : "integer",
          "maximum" : 31536000,
          "minimum" : 300,
          "description" : "<p>The frequency (in seconds) of key changes for live workflows, in which content is streamed real time. The service retrieves content keys before the live content begins streaming, and then retrieves them as needed over the lifetime of the workflow. By default, key rotation is set to 300 seconds (5 minutes), the minimum rotation interval, which is equivalent to setting it to 300. If you don't enter an interval, content keys aren't rotated.</p>\n         <p>The following example setting causes the service to rotate keys every thirty minutes: <code>1800</code>\n         </p>"
        },
        "SpekeKeyProvider" : {
          "$ref" : "#/definitions/SpekeKeyProvider"
        }
      },
      "required" : [ "EncryptionMethod", "SpekeKeyProvider" ],
      "additionalProperties" : False
    },
    "EncryptionContractConfiguration" : {
      "type" : "object",
      "description" : "<p>Configure one or more content encryption keys for your endpoints that use SPEKE Version 2.0. The encryption contract defines which content keys are used to encrypt the audio and video tracks in your stream. To configure the encryption contract, specify which audio and video encryption presets to use.</p>",
      "properties" : {
        "PresetSpeke20Audio" : {
          "$ref" : "#/definitions/PresetSpeke20Audio"
        },
        "PresetSpeke20Video" : {
          "$ref" : "#/definitions/PresetSpeke20Video"
        }
      },
      "required" : [ "PresetSpeke20Audio", "PresetSpeke20Video" ],
      "additionalProperties" : False
    },
    "EncryptionMethod" : {
      "type" : "object",
      "description" : "<p>The encryption type.</p>",
      "properties" : {
        "TsEncryptionMethod" : {
          "$ref" : "#/definitions/TsEncryptionMethod"
        },
        "CmafEncryptionMethod" : {
          "$ref" : "#/definitions/CmafEncryptionMethod"
        }
      },
      "additionalProperties" : False
    },
    "EndpointErrorCondition" : {
      "type" : "string",
      "enum" : [ "STALE_MANIFEST", "INCOMPLETE_MANIFEST", "MISSING_DRM_KEY", "SLATE_INPUT" ]
    },
    "FilterConfiguration" : {
      "type" : "object",
      "description" : "<p>Filter configuration includes settings for manifest filtering, start and end times, and time delay that apply to all of your egress requests for this manifest. </p>",
      "properties" : {
        "ManifestFilter" : {
          "type" : "string",
          "maxLength" : 1024,
          "minLength" : 1,
          "description" : "<p>Optionally specify one or more manifest filters for all of your manifest egress requests. When you include a manifest filter, note that you cannot use an identical manifest filter query parameter for this manifest's endpoint URL.</p>"
        },
        "Start" : {
          "type" : "string",
          "description" : "<p>Optionally specify the start time for all of your manifest egress requests. When you include start time, note that you cannot use start time query parameters for this manifest's endpoint URL.</p>",
          "format" : "date-time"
        },
        "End" : {
          "type" : "string",
          "description" : "<p>Optionally specify the end time for all of your manifest egress requests. When you include end time, note that you cannot use end time query parameters for this manifest's endpoint URL.</p>",
          "format" : "date-time"
        },
        "TimeDelaySeconds" : {
          "type" : "integer",
          "maximum" : 1209600,
          "minimum" : 0,
          "description" : "<p>Optionally specify the time delay for all of your manifest egress requests. Enter a value that is smaller than your endpoint's startover window. When you include time delay, note that you cannot use time delay query parameters for this manifest's endpoint URL.</p>"
        },
        "ClipStartTime" : {
          "type" : "string",
          "description" : "<p>Optionally specify the clip start time for all of your manifest egress requests. When you include clip start time, note that you cannot use clip start time query parameters for this manifest's endpoint URL.</p>",
          "format" : "date-time"
        }
      },
      "additionalProperties" : False
    },
    "ForceEndpointErrorConfiguration" : {
      "type" : "object",
      "description" : "<p>The failover settings for the endpoint.</p>",
      "properties" : {
        "EndpointErrorConditions" : {
          "type" : "array",
          "items" : {
            "$ref" : "#/definitions/EndpointErrorCondition"
          },
          "description" : "<p>The failover conditions for the endpoint. The options are:</p>\n         <ul>\n            <li>\n               <p>\n                  <code>STALE_MANIFEST</code> - The manifest stalled and there are no new segments or parts.</p>\n            </li>\n            <li>\n               <p>\n                  <code>INCOMPLETE_MANIFEST</code> - There is a gap in the manifest.</p>\n            </li>\n            <li>\n               <p>\n                  <code>MISSING_DRM_KEY</code> - Key rotation is enabled but we're unable to fetch the key for the current key period.</p>\n            </li>\n            <li>\n               <p>\n                  <code>SLATE_INPUT</code> - The segments which contain slate content are considered to be missing content.</p>\n            </li>\n         </ul>"
        }
      },
      "additionalProperties" : False
    },
    "DashManifestConfiguration" : {
      "type" : "object",
      "description" : "<p>Retrieve the DASH manifest configuration.</p>",
      "properties" : {
        "ManifestName" : {
          "type" : "string",
          "maxLength" : 256,
          "minLength" : 1,
          "pattern" : "^[a-zA-Z0-9_-]+$",
          "description" : "<p>A short string that's appended to the endpoint URL. The manifest name creates a unique path to this endpoint. If you don't enter a value, MediaPackage uses the default manifest name, index. </p>"
        },
        "ManifestWindowSeconds" : {
          "type" : "integer",
          "description" : "<p>The total duration (in seconds) of the manifest's content.</p>"
        },
        "FilterConfiguration" : {
          "$ref" : "#/definitions/FilterConfiguration"
        },
        "MinUpdatePeriodSeconds" : {
          "type" : "integer",
          "description" : "<p>Minimum amount of time (in seconds) that the player should wait before requesting updates to the manifest.</p>"
        },
        "MinBufferTimeSeconds" : {
          "type" : "integer",
          "description" : "<p>Minimum amount of content (in seconds) that a player must keep available in the buffer.</p>"
        },
        "SuggestedPresentationDelaySeconds" : {
          "type" : "integer",
          "description" : "<p>The amount of time (in seconds) that the player should be from the end of the manifest.</p>"
        },
        "SegmentTemplateFormat" : {
          "$ref" : "#/definitions/DashSegmentTemplateFormat"
        },
        "PeriodTriggers" : {
          "type" : "array",
          "items" : {
            "$ref" : "#/definitions/DashPeriodTrigger"
          },
          "maxItems" : 100,
          "minItems" : 0,
          "description" : "<p>A list of triggers that controls when AWS Elemental MediaPackage separates the MPEG-DASH manifest into multiple periods. Leave this value empty to indicate that the manifest is contained all in one period.\n         For more information about periods in the DASH manifest, see <a href=\"https://docs.aws.amazon.com/mediapackage/latest/userguide/multi-period.html\">Multi-period DASH in AWS Elemental MediaPackage</a>.</p>"
        },
        "ScteDash" : {
          "$ref" : "#/definitions/ScteDash"
        },
        "DrmSignaling" : {
          "$ref" : "#/definitions/DashDrmSignaling"
        },
        "UtcTiming" : {
          "$ref" : "#/definitions/DashUtcTiming"
        }
      },
      "required" : [ "ManifestName" ],
      "additionalProperties" : False
    },
    "HlsManifestConfiguration" : {
      "type" : "object",
      "description" : "<p>Retrieve the HTTP live streaming (HLS) manifest configuration.</p>",
      "properties" : {
        "ManifestName" : {
          "type" : "string",
          "maxLength" : 256,
          "minLength" : 1,
          "pattern" : "^[a-zA-Z0-9_-]+$",
          "description" : "<p>A short short string that's appended to the endpoint URL. The manifest name creates a unique path to this endpoint. If you don't enter a value, MediaPackage uses the default manifest name, index. MediaPackage automatically inserts the format extension, such as .m3u8. You can't use the same manifest name if you use HLS manifest and low-latency HLS manifest. The manifestName on the HLSManifest object overrides the manifestName you provided on the originEndpoint object.</p>"
        },
        "Url" : {
          "type" : "string",
          "description" : "<p>The egress domain URL for stream delivery from MediaPackage.</p>"
        },
        "ChildManifestName" : {
          "type" : "string",
          "maxLength" : 256,
          "minLength" : 1,
          "pattern" : "^[a-zA-Z0-9_-]+$",
          "description" : "<p>A short string that's appended to the endpoint URL. The child manifest name creates a unique path to this endpoint. If you don't enter a value, MediaPackage uses the default child manifest name, index_1. The manifestName on the HLSManifest object overrides the manifestName you provided on the originEndpoint object.</p>"
        },
        "ManifestWindowSeconds" : {
          "type" : "integer",
          "description" : "<p>The total duration (in seconds) of the manifest's content.</p>"
        },
        "ProgramDateTimeIntervalSeconds" : {
          "type" : "integer",
          "description" : "<p>Inserts EXT-X-PROGRAM-DATE-TIME tags in the output manifest at the interval that you specify. If you don't enter an interval,\n         EXT-X-PROGRAM-DATE-TIME tags aren't included in the manifest.\n         The tags sync the stream to the wall clock so that viewers can seek to a specific time in the playback timeline on the player.</p>\n         <p>Irrespective of this parameter, if any ID3Timed metadata is in the HLS input, it is passed through to the HLS output.</p>"
        },
        "ScteHls" : {
          "$ref" : "#/definitions/ScteHls"
        },
        "FilterConfiguration" : {
          "$ref" : "#/definitions/FilterConfiguration"
        },
        "StartTag" : {
          "$ref" : "#/definitions/StartTag"
        },
        "UrlEncodeChildManifest" : {
          "type" : "boolean",
          "description" : "<p>When enabled, MediaPackage URL-encodes the query string for API requests for HLS child manifests to comply with Amazon Web Services Signature Version 4 (SigV4) signature signing protocol.\n         For more information, see <a href=\"https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_sigv.html\">Amazon Web Services Signature Version 4 for API requests</a> in <i>Identity and Access Management User Guide</i>.</p>"
        }
      },
      "required" : [ "ManifestName" ],
      "additionalProperties" : False
    },
    "LowLatencyHlsManifestConfiguration" : {
      "type" : "object",
      "description" : "<p>Retrieve the low-latency HTTP live streaming (HLS) manifest configuration.</p>",
      "properties" : {
        "ManifestName" : {
          "type" : "string",
          "maxLength" : 256,
          "minLength" : 1,
          "pattern" : "^[a-zA-Z0-9_-]+$",
          "description" : "<p>A short short string that's appended to the endpoint URL. The manifest name creates a unique path to this endpoint. If you don't enter a value, MediaPackage uses the default manifest name, index. MediaPackage automatically inserts the format extension, such as .m3u8. You can't use the same manifest name if you use HLS manifest and low-latency HLS manifest. The manifestName on the HLSManifest object overrides the manifestName you provided on the originEndpoint object.</p>"
        },
        "Url" : {
          "type" : "string",
          "description" : "<p>The egress domain URL for stream delivery from MediaPackage.</p>"
        },
        "ChildManifestName" : {
          "type" : "string",
          "maxLength" : 256,
          "minLength" : 1,
          "pattern" : "^[a-zA-Z0-9_-]+$",
          "description" : "<p>A short string that's appended to the endpoint URL. The child manifest name creates a unique path to this endpoint. If you don't enter a value, MediaPackage uses the default child manifest name, index_1. The manifestName on the HLSManifest object overrides the manifestName you provided on the originEndpoint object.</p>"
        },
        "ManifestWindowSeconds" : {
          "type" : "integer",
          "description" : "<p>The total duration (in seconds) of the manifest's content.</p>"
        },
        "ProgramDateTimeIntervalSeconds" : {
          "type" : "integer",
          "description" : "<p>Inserts EXT-X-PROGRAM-DATE-TIME tags in the output manifest at the interval that you specify. If you don't enter an interval,\n         EXT-X-PROGRAM-DATE-TIME tags aren't included in the manifest.\n         The tags sync the stream to the wall clock so that viewers can seek to a specific time in the playback timeline on the player.</p>\n         <p>Irrespective of this parameter, if any ID3Timed metadata is in the HLS input, it is passed through to the HLS output.</p>"
        },
        "ScteHls" : {
          "$ref" : "#/definitions/ScteHls"
        },
        "FilterConfiguration" : {
          "$ref" : "#/definitions/FilterConfiguration"
        },
        "StartTag" : {
          "$ref" : "#/definitions/StartTag"
        },
        "UrlEncodeChildManifest" : {
          "type" : "boolean",
          "description" : "<p>When enabled, MediaPackage URL-encodes the query string for API requests for LL-HLS child manifests to comply with Amazon Web Services Signature Version 4 (SigV4) signature signing protocol.\n         For more information, see <a href=\"https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_sigv.html\">Amazon Web Services Signature Version 4 for API requests</a> in <i>Identity and Access Management User Guide</i>.</p>"
        }
      },
      "required" : [ "ManifestName" ],
      "additionalProperties" : False
    },
    "PresetSpeke20Audio" : {
      "type" : "string",
      "enum" : [ "PRESET_AUDIO_1", "PRESET_AUDIO_2", "PRESET_AUDIO_3", "SHARED", "UNENCRYPTED" ]
    },
    "PresetSpeke20Video" : {
      "type" : "string",
      "enum" : [ "PRESET_VIDEO_1", "PRESET_VIDEO_2", "PRESET_VIDEO_3", "PRESET_VIDEO_4", "PRESET_VIDEO_5", "PRESET_VIDEO_6", "PRESET_VIDEO_7", "PRESET_VIDEO_8", "SHARED", "UNENCRYPTED" ]
    },
    "Scte" : {
      "type" : "object",
      "description" : "<p>The SCTE configuration.</p>",
      "properties" : {
        "ScteFilter" : {
          "type" : "array",
          "items" : {
            "$ref" : "#/definitions/ScteFilter"
          },
          "maxItems" : 100,
          "minItems" : 0,
          "description" : "<p>The SCTE-35 message types that you want to be treated as ad markers in the output.</p>"
        }
      },
      "additionalProperties" : False
    },
    "ScteDash" : {
      "type" : "object",
      "description" : "<p>The SCTE configuration.</p>",
      "properties" : {
        "AdMarkerDash" : {
          "$ref" : "#/definitions/AdMarkerDash"
        }
      },
      "additionalProperties" : False
    },
    "ScteFilter" : {
      "type" : "string",
      "enum" : [ "SPLICE_INSERT", "BREAK", "PROVIDER_ADVERTISEMENT", "DISTRIBUTOR_ADVERTISEMENT", "PROVIDER_PLACEMENT_OPPORTUNITY", "DISTRIBUTOR_PLACEMENT_OPPORTUNITY", "PROVIDER_OVERLAY_PLACEMENT_OPPORTUNITY", "DISTRIBUTOR_OVERLAY_PLACEMENT_OPPORTUNITY", "PROGRAM" ]
    },
    "ScteHls" : {
      "type" : "object",
      "description" : "<p>The SCTE configuration.</p>",
      "properties" : {
        "AdMarkerHls" : {
          "$ref" : "#/definitions/AdMarkerHls"
        }
      },
      "additionalProperties" : False
    },
    "Segment" : {
      "type" : "object",
      "description" : "<p>The segment configuration, including the segment name, duration, and other configuration values.</p>",
      "properties" : {
        "SegmentDurationSeconds" : {
          "type" : "integer",
          "maximum" : 30,
          "minimum" : 1,
          "description" : "<p>The duration (in seconds) of each segment. Enter a value equal to, or a multiple of, the input segment duration. If the value that you enter is different from the input segment duration, MediaPackage rounds segments to the nearest multiple of the input segment duration.</p>"
        },
        "SegmentName" : {
          "type" : "string",
          "maxLength" : 256,
          "minLength" : 1,
          "pattern" : "^[a-zA-Z0-9_-]+$",
          "description" : "<p>The name that describes the segment. The name is the base name of the segment used in all content manifests inside of the endpoint. You can't use spaces in the name.</p>"
        },
        "TsUseAudioRenditionGroup" : {
          "type" : "boolean",
          "description" : "<p>When selected, MediaPackage bundles all audio tracks in a rendition group. All other tracks in the stream can be used with any audio rendition from the group.</p>"
        },
        "IncludeIframeOnlyStreams" : {
          "type" : "boolean",
          "description" : "<p>When selected, the stream set includes an additional I-frame only stream, along with the other tracks. If False, this extra stream is not included. MediaPackage generates an I-frame only stream from the first rendition in the manifest. The service inserts EXT-I-FRAMES-ONLY tags in the output manifest, and then generates and includes an I-frames only playlist in the stream. This playlist permits player functionality like fast forward and rewind.</p>"
        },
        "TsIncludeDvbSubtitles" : {
          "type" : "boolean",
          "description" : "<p>By default, MediaPackage excludes all digital video broadcasting (DVB) subtitles from the output. When selected, MediaPackage passes through DVB subtitles into the output.</p>"
        },
        "Scte" : {
          "$ref" : "#/definitions/Scte"
        },
        "Encryption" : {
          "$ref" : "#/definitions/Encryption"
        }
      },
      "additionalProperties" : False
    },
    "SpekeKeyProvider" : {
      "type" : "object",
      "description" : "<p>The parameters for the SPEKE key provider.</p>",
      "properties" : {
        "EncryptionContractConfiguration" : {
          "$ref" : "#/definitions/EncryptionContractConfiguration"
        },
        "ResourceId" : {
          "type" : "string",
          "maxLength" : 256,
          "minLength" : 1,
          "pattern" : "^[0-9a-zA-Z_-]+$",
          "description" : "<p>The unique identifier for the content. The service sends this to the key server to identify the current endpoint. How unique you make this depends on how fine-grained you want access controls to be. The service does not permit you to use the same ID for two simultaneous encryption processes. The resource ID is also known as the content ID.</p>\n         <p>The following example shows a resource ID: <code>MovieNight20171126093045</code>\n         </p>"
        },
        "DrmSystems" : {
          "type" : "array",
          "items" : {
            "$ref" : "#/definitions/DrmSystem"
          },
          "maxItems" : 4,
          "minItems" : 1,
          "description" : "<p>The DRM solution provider you're using to protect your content during distribution.</p>"
        },
        "RoleArn" : {
          "type" : "string",
          "maxLength" : 2048,
          "minLength" : 1,
          "description" : "<p>The ARN for the IAM role granted by the key provider that provides access to the key provider API. This role must have a trust policy that allows MediaPackage to assume the role, and it must have a sufficient permissions policy to allow access to the specific key retrieval URL. Get this from your DRM solution provider.</p>\n         <p>Valid format: <code>arn:aws:iam::{accountID}:role/{name}</code>. The following example shows a role ARN: <code>arn:aws:iam::444455556666:role/SpekeAccess</code>\n         </p>"
        },
        "Url" : {
          "type" : "string",
          "maxLength" : 1024,
          "minLength" : 1,
          "description" : "<p>The URL of the API Gateway proxy that you set up to talk to your key server. The API Gateway proxy must reside in the same AWS Region as MediaPackage and must start with https://.</p>\n         <p>The following example shows a URL: <code>https://1wm2dx1f33.execute-api.us-west-2.amazonaws.com/SpekeSample/copyProtection</code>\n         </p>"
        }
      },
      "required" : [ "DrmSystems", "EncryptionContractConfiguration", "ResourceId", "RoleArn", "Url" ],
      "additionalProperties" : False
    },
    "StartTag" : {
      "type" : "object",
      "description" : "<p>To insert an EXT-X-START tag in your HLS playlist, specify a StartTag configuration object with a valid TimeOffset. When you do, you can also optionally specify whether to include a PRECISE value in the EXT-X-START tag.</p>",
      "properties" : {
        "TimeOffset" : {
          "type" : "number",
          "description" : "<p>Specify the value for TIME-OFFSET within your EXT-X-START tag. Enter a signed floating point value which, if positive, must be less than the configured manifest duration minus three times the configured segment target duration. If negative, the absolute value must be larger than three times the configured segment target duration, and the absolute value must be smaller than the configured manifest duration.</p>"
        },
        "Precise" : {
          "type" : "boolean",
          "description" : "<p>Specify the value for PRECISE within your EXT-X-START tag. Leave blank, or choose False, to use the default value NO. Choose yes to use the value YES.</p>"
        }
      },
      "required" : [ "TimeOffset" ],
      "additionalProperties" : False
    },
    "TsEncryptionMethod" : {
      "type" : "string",
      "enum" : [ "AES_128", "SAMPLE_AES" ]
    },
    "Tag" : {
      "type" : "object",
      "properties" : {
        "Key" : {
          "type" : "string"
        },
        "Value" : {
          "type" : "string"
        }
      },
      "additionalProperties" : False
    }
  },
  "properties" : {
    "Arn" : {
      "type" : "string",
      "description" : "<p>The Amazon Resource Name (ARN) associated with the resource.</p>"
    },
    "ChannelGroupName" : {
      "type" : "string",
      "maxLength" : 256,
      "minLength" : 1,
      "pattern" : "^[a-zA-Z0-9_-]+$"
    },
    "ChannelName" : {
      "type" : "string",
      "maxLength" : 256,
      "minLength" : 1,
      "pattern" : "^[a-zA-Z0-9_-]+$"
    },
    "ContainerType" : {
      "$ref" : "#/definitions/ContainerType"
    },
    "CreatedAt" : {
      "type" : "string",
      "description" : "<p>The date and time the origin endpoint was created.</p>",
      "format" : "date-time"
    },
    "DashManifests" : {
      "type" : "array",
      "items" : {
        "$ref" : "#/definitions/DashManifestConfiguration"
      },
      "description" : "<p>A DASH manifest configuration.</p>"
    },
    "Description" : {
      "type" : "string",
      "maxLength" : 1024,
      "minLength" : 0,
      "description" : "<p>Enter any descriptive text that helps you to identify the origin endpoint.</p>"
    },
    "ForceEndpointErrorConfiguration" : {
      "$ref" : "#/definitions/ForceEndpointErrorConfiguration"
    },
    "HlsManifests" : {
      "type" : "array",
      "items" : {
        "$ref" : "#/definitions/HlsManifestConfiguration"
      },
      "description" : "<p>An HTTP live streaming (HLS) manifest configuration.</p>"
    },
    "LowLatencyHlsManifests" : {
      "type" : "array",
      "items" : {
        "$ref" : "#/definitions/LowLatencyHlsManifestConfiguration"
      },
      "description" : "<p>A low-latency HLS manifest configuration.</p>"
    },
    "ModifiedAt" : {
      "type" : "string",
      "description" : "<p>The date and time the origin endpoint was modified.</p>",
      "format" : "date-time"
    },
    "OriginEndpointName" : {
      "type" : "string",
      "maxLength" : 256,
      "minLength" : 1,
      "pattern" : "^[a-zA-Z0-9_-]+$"
    },
    "Segment" : {
      "$ref" : "#/definitions/Segment"
    },
    "StartoverWindowSeconds" : {
      "type" : "integer",
      "maximum" : 1209600,
      "minimum" : 60,
      "description" : "<p>The size of the window (in seconds) to create a window of the live stream that's available for on-demand viewing. Viewers can start-over or catch-up on content that falls within the window. The maximum startover window is 1,209,600 seconds (14 days).</p>"
    },
    "DashManifestUrls" : {
      "type" : "array",
      "items" : {
        "type" : "string"
      }
    },
    "HlsManifestUrls" : {
      "type" : "array",
      "items" : {
        "type" : "string"
      }
    },
    "LowLatencyHlsManifestUrls" : {
      "type" : "array",
      "items" : {
        "type" : "string"
      }
    },
    "Tags" : {
      "type" : "array",
      "insertionOrder" : False,
      "items" : {
        "$ref" : "#/definitions/Tag"
      }
    }
  },
  "required" : [ "ChannelGroupName", "ChannelName", "OriginEndpointName", "ContainerType" ],
  "readOnlyProperties" : [ "/properties/Arn", "/properties/CreatedAt", "/properties/DashManifestUrls", "/properties/HlsManifestUrls", "/properties/LowLatencyHlsManifestUrls", "/properties/ModifiedAt", "/properties/LowLatencyHlsManifests/*/Url", "/properties/HlsManifests/*/Url" ],
  "createOnlyProperties" : [ "/properties/ChannelGroupName", "/properties/ChannelName", "/properties/OriginEndpointName" ],
  "primaryIdentifier" : [ "/properties/Arn" ],
  "handlers" : {
    "create" : {
      "permissions" : [ "mediapackagev2:TagResource", "mediapackagev2:CreateOriginEndpoint", "iam:PassRole" ]
    },
    "read" : {
      "permissions" : [ "mediapackagev2:GetOriginEndpoint" ]
    },
    "update" : {
      "permissions" : [ "mediapackagev2:TagResource", "mediapackagev2:UntagResource", "mediapackagev2:ListTagsForResource", "mediapackagev2:UpdateOriginEndpoint", "iam:PassRole" ]
    },
    "delete" : {
      "permissions" : [ "mediapackagev2:GetOriginEndpoint", "mediapackagev2:DeleteOriginEndpoint" ]
    },
    "list" : {
      "handlerSchema" : {
        "properties" : {
          "ChannelGroupName" : {
            "$ref" : "resource-schema.json#/properties/ChannelGroupName"
          },
          "ChannelName" : {
            "$ref" : "resource-schema.json#/properties/ChannelName"
          }
        },
        "required" : [ "ChannelGroupName", "ChannelName" ]
      },
      "permissions" : [ "mediapackagev2:ListOriginEndpoints" ]
    }
  },
  "tagging" : {
    "taggable" : True,
    "tagOnCreate" : True,
    "tagUpdatable" : True,
    "cloudFormationSystemTags" : False,
    "tagProperty" : "/properties/Tags",
    "permissions" : [ "mediapackagev2:TagResource", "mediapackagev2:UntagResource", "mediapackagev2:ListTagsForResource" ]
  },
  "additionalIdentifiers" : [ [ "/properties/ChannelGroupName", "/properties/ChannelName", "/properties/OriginEndpointName" ] ],
  "sourceUrl" : "https://github.com/aws-cloudformation/aws-cloudformation-resource-providers-mediapackagev2",
  "additionalProperties" : False
}