SCHEMA = {
  "typeName" : "AWS::MemoryDB::MultiRegionCluster",
  "description" : "The AWS::MemoryDB::Multi Region Cluster resource creates an Amazon MemoryDB Multi Region Cluster.",
  "sourceUrl" : "https://github.com/aws-cloudformation/aws-cloudformation-resource-providers-memorydb",
  "definitions" : {
    "Tag" : {
      "description" : "A key-value pair to associate with a resource.",
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "Key" : {
          "description" : "The key for the tag. May not be None.",
          "pattern" : "^(?!aws:)(?!memorydb:)[a-zA-Z0-9 _\\.\\/=+:\\-@]{1,128}$",
          "type" : "string",
          "minLength" : 1,
          "maxLength" : 128
        },
        "Value" : {
          "description" : "The tag's value. May be None.",
          "type" : "string",
          "pattern" : "^(?!aws:)(?!memorydb:)[a-zA-Z0-9 _\\.\\/=+:\\-@]{1,256}$",
          "minLength" : 1,
          "maxLength" : 256
        }
      },
      "required" : [ "Key", "Value" ]
    }
  },
  "properties" : {
    "MultiRegionClusterNameSuffix" : {
      "description" : "The name of the Multi Region cluster. This value must be unique as it also serves as the multi region cluster identifier.",
      "pattern" : "[a-z][a-z0-9\\-]*",
      "type" : "string"
    },
    "Description" : {
      "description" : "Description of the multi region cluster.",
      "type" : "string"
    },
    "MultiRegionClusterName" : {
      "description" : "The name of the Global Datastore, it is generated by MemoryDB adding a prefix to MultiRegionClusterNameSuffix.",
      "type" : "string"
    },
    "Status" : {
      "description" : "The status of the multi region cluster. For example, Available, Updating, Creating.",
      "type" : "string"
    },
    "NodeType" : {
      "description" : "The compute and memory capacity of the nodes in the multi region cluster.",
      "type" : "string"
    },
    "NumShards" : {
      "description" : "The number of shards the multi region cluster will contain.",
      "type" : "integer"
    },
    "MultiRegionParameterGroupName" : {
      "description" : "The name of the parameter group associated with the multi region cluster.",
      "type" : "string"
    },
    "TLSEnabled" : {
      "description" : "A flag that enables in-transit encryption when set to True.\n\nYou cannot modify the value of TransitEncryptionEnabled after the cluster is created. To enable in-transit encryption on a cluster you must set TransitEncryptionEnabled to true when you create a cluster.",
      "type" : "boolean"
    },
    "ARN" : {
      "description" : "The Amazon Resource Name (ARN) of the multi region cluster.",
      "type" : "string"
    },
    "Engine" : {
      "description" : "The engine type used by the multi region cluster.",
      "type" : "string"
    },
    "EngineVersion" : {
      "description" : "The Redis engine version used by the multi region cluster.",
      "type" : "string"
    },
    "Tags" : {
      "description" : "An array of key-value pairs to apply to this multi region cluster.",
      "type" : "array",
      "maxItems" : 50,
      "uniqueItems" : True,
      "insertionOrder" : False,
      "items" : {
        "$ref" : "#/definitions/Tag"
      }
    },
    "UpdateStrategy" : {
      "description" : "An enum string value that determines the update strategy for scaling. Possible values are 'COORDINATED' and 'UNCOORDINATED'. Default is 'COORDINATED'.",
      "type" : "string",
      "enum" : [ "COORDINATED", "UNCOORDINATED" ]
    }
  },
  "tagging" : {
    "taggable" : True,
    "tagOnCreate" : True,
    "tagUpdatable" : True,
    "cloudFormationSystemTags" : True,
    "tagProperty" : "/properties/Tags",
    "permissions" : [ "memorydb:TagResource", "memorydb:ListTags", "memorydb:UntagResource" ]
  },
  "additionalProperties" : False,
  "readOnlyProperties" : [ "/properties/MultiRegionClusterName", "/properties/Status", "/properties/ARN" ],
  "writeOnlyProperties" : [ "/properties/MultiRegionClusterNameSuffix", "/properties/UpdateStrategy" ],
  "required" : [ "NodeType" ],
  "createOnlyProperties" : [ "/properties/MultiRegionClusterNameSuffix", "/properties/EngineVersion", "/properties/MultiRegionParameterGroupName", "/properties/TLSEnabled" ],
  "primaryIdentifier" : [ "/properties/MultiRegionClusterName" ],
  "handlers" : {
    "create" : {
      "permissions" : [ "memorydb:CreateMultiRegionCluster", "memorydb:DescribeMultiRegionClusters", "memorydb:TagResource", "memorydb:ListTags", "iam:CreateServiceLinkedRole" ],
      "timeoutInMinutes" : 2160
    },
    "read" : {
      "permissions" : [ "memorydb:DescribeMultiRegionClusters", "memorydb:ListTags" ]
    },
    "update" : {
      "permissions" : [ "memorydb:UpdateMultiRegionCluster", "memorydb:DescribeMultiRegionClusters", "memorydb:ListTags", "memorydb:TagResource", "memorydb:UntagResource" ],
      "timeoutInMinutes" : 2160
    },
    "delete" : {
      "permissions" : [ "memorydb:DeleteMultiRegionCluster", "memorydb:DescribeMultiRegionClusters" ]
    },
    "list" : {
      "permissions" : [ "memorydb:DescribeMultiRegionClusters" ]
    }
  }
}