SCHEMA = {
  "typeName" : "AWS::Neptune::DBSubnetGroup",
  "description" : "The AWS::Neptune::DBSubnetGroup type creates an Amazon Neptune DB subnet group. Subnet groups must contain at least two subnets in two different Availability Zones in the same AWS Region.",
  "sourceUrl" : "https://github.com/aws-cloudformation/aws-cloudformation-resource-providers-neptune",
  "properties" : {
    "DBSubnetGroupName" : {
      "description" : "The name for the DB subnet group. This value is stored as a lowercase string.\n\nConstraints: Must contain no more than 255 lowercase alphanumeric characters or hyphens. Must not be \"Default\".\n\nExample: mysubnetgroup\n\n",
      "type" : "string"
    },
    "DBSubnetGroupDescription" : {
      "description" : "The description for the DB subnet group.",
      "type" : "string"
    },
    "SubnetIds" : {
      "description" : "The Amazon EC2 subnet IDs for the DB subnet group.",
      "type" : "array",
      "uniqueItems" : False,
      "items" : {
        "type" : "string"
      }
    },
    "Tags" : {
      "type" : "array",
      "uniqueItems" : False,
      "description" : "An optional array of key-value pairs to apply to this DB subnet group.",
      "items" : {
        "$ref" : "#/definitions/Tag"
      }
    }
  },
  "definitions" : {
    "Tag" : {
      "description" : "An optional array of key-value pairs to apply to this DB subnet group.",
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "Key" : {
          "type" : "string",
          "description" : "The key name of the tag. You can specify a value that is 1 to 128 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -. "
        },
        "Value" : {
          "type" : "string",
          "description" : "The value for the tag. You can specify a value that is 0 to 256 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -. "
        }
      },
      "required" : [ "Key", "Value" ]
    }
  },
  "additionalProperties" : False,
  "required" : [ "DBSubnetGroupDescription", "SubnetIds" ],
  "propertyTransform" : {
    "/properties/DBSubnetGroupName" : "$lowercase(DBSubnetGroupName)"
  },
  "createOnlyProperties" : [ "/properties/DBSubnetGroupName" ],
  "primaryIdentifier" : [ "/properties/DBSubnetGroupName" ],
  "tagging" : {
    "taggable" : True,
    "tagOnCreate" : True,
    "tagUpdatable" : True,
    "cloudFormationSystemTags" : True,
    "tagProperty" : "/properties/Tags",
    "permissions" : [ "rds:AddTagsToResource", "rds:ListTagsForResource", "rds:RemoveTagsFromResource" ]
  },
  "handlers" : {
    "create" : {
      "permissions" : [ "rds:CreateDBSubnetGroup", "rds:DescribeDBSubnetGroups", "rds:ListTagsForResource", "rds:AddTagsToResource", "iam:CreateServiceLinkedRole" ]
    },
    "read" : {
      "permissions" : [ "rds:DescribeDBSubnetGroups", "rds:ListTagsForResource" ]
    },
    "update" : {
      "permissions" : [ "rds:ModifyDBSubnetGroup", "rds:DescribeDBSubnetGroups", "rds:AddTagsToResource", "rds:RemoveTagsFromResource", "rds:ListTagsForResource" ]
    },
    "delete" : {
      "permissions" : [ "rds:DeleteDBSubnetGroup", "rds:DescribeDBSubnetGroups", "rds:ListTagsForResource", "rds:RemoveTagsFromResource" ]
    },
    "list" : {
      "permissions" : [ "rds:DescribeDBSubnetGroups", "rds:ListTagsForResource" ]
    }
  }
}