SCHEMA = {
  "typeName" : "AWS::NetworkManager::DirectConnectGatewayAttachment",
  "description" : "AWS::NetworkManager::DirectConnectGatewayAttachment Resource Type",
  "sourceUrl" : "https://github.com/aws-cloudformation/aws-cloudformation-resource-providers-networkmanager/aws-networkmanager-directconnectgatewayattachment",
  "properties" : {
    "CoreNetworkId" : {
      "description" : "The ID of a core network for the Direct Connect Gateway attachment.",
      "type" : "string"
    },
    "CoreNetworkArn" : {
      "description" : "The ARN of a core network for the Direct Connect Gateway attachment.",
      "type" : "string"
    },
    "AttachmentId" : {
      "description" : "Id of the attachment.",
      "type" : "string"
    },
    "OwnerAccountId" : {
      "description" : "Owner account of the attachment.",
      "type" : "string"
    },
    "AttachmentType" : {
      "description" : "Attachment type.",
      "type" : "string"
    },
    "State" : {
      "description" : "State of the attachment.",
      "type" : "string"
    },
    "EdgeLocations" : {
      "description" : "The Regions where the edges are located.",
      "type" : "array",
      "insertionOrder" : False,
      "items" : {
        "type" : "string"
      }
    },
    "DirectConnectGatewayArn" : {
      "description" : "The ARN of the Direct Connect Gateway.",
      "type" : "string"
    },
    "ResourceArn" : {
      "description" : "The ARN of the Resource.",
      "type" : "string"
    },
    "AttachmentPolicyRuleNumber" : {
      "description" : "The policy rule number associated with the attachment.",
      "type" : "integer"
    },
    "SegmentName" : {
      "description" : "The name of the segment attachment..",
      "type" : "string"
    },
    "ProposedSegmentChange" : {
      "description" : "The attachment to move from one segment to another.",
      "$ref" : "#/definitions/ProposedSegmentChange"
    },
    "NetworkFunctionGroupName" : {
      "description" : "The name of the network function group attachment.",
      "type" : "string"
    },
    "ProposedNetworkFunctionGroupChange" : {
      "description" : "The attachment to move from one network function group to another.",
      "$ref" : "#/definitions/ProposedNetworkFunctionGroupChange"
    },
    "Tags" : {
      "description" : "Tags for the attachment.",
      "type" : "array",
      "uniqueItems" : True,
      "insertionOrder" : False,
      "items" : {
        "$ref" : "#/definitions/Tag"
      }
    },
    "CreatedAt" : {
      "description" : "Creation time of the attachment.",
      "type" : "string"
    },
    "UpdatedAt" : {
      "description" : "Last update time of the attachment.",
      "type" : "string"
    }
  },
  "definitions" : {
    "Tag" : {
      "description" : "A key-value pair to associate with a resource.",
      "type" : "object",
      "properties" : {
        "Key" : {
          "type" : "string",
          "description" : "The key name of the tag. You can specify a value that is 1 to 128 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -."
        },
        "Value" : {
          "type" : "string",
          "description" : "The value for the tag. You can specify a value that is 0 to 256 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -."
        }
      },
      "required" : [ "Key", "Value" ],
      "additionalProperties" : False
    },
    "ProposedSegmentChange" : {
      "description" : "The attachment to move from one segment to another.",
      "type" : "object",
      "properties" : {
        "Tags" : {
          "description" : "The key-value tags that changed for the segment.",
          "type" : "array",
          "uniqueItems" : True,
          "insertionOrder" : False,
          "items" : {
            "$ref" : "#/definitions/Tag"
          }
        },
        "AttachmentPolicyRuleNumber" : {
          "description" : "The rule number in the policy document that applies to this change.",
          "type" : "integer"
        },
        "SegmentName" : {
          "description" : "The name of the segment to change.",
          "type" : "string"
        }
      },
      "additionalProperties" : False
    },
    "ProposedNetworkFunctionGroupChange" : {
      "description" : "The attachment to move from one network function group to another.",
      "type" : "object",
      "properties" : {
        "Tags" : {
          "description" : "The key-value tags that changed for the network function group.",
          "type" : "array",
          "uniqueItems" : True,
          "insertionOrder" : False,
          "items" : {
            "$ref" : "#/definitions/Tag"
          }
        },
        "AttachmentPolicyRuleNumber" : {
          "description" : "The rule number in the policy document that applies to this change.",
          "type" : "integer"
        },
        "NetworkFunctionGroupName" : {
          "description" : "The name of the network function group to change.",
          "type" : "string"
        }
      },
      "additionalProperties" : False
    }
  },
  "tagging" : {
    "taggable" : True,
    "tagOnCreate" : True,
    "tagUpdatable" : True,
    "cloudFormationSystemTags" : False,
    "tagProperty" : "/properties/Tags",
    "permissions" : [ "networkmanager:TagResource", "networkmanager:UntagResource", "networkmanager:ListTagsForResource" ]
  },
  "additionalProperties" : False,
  "required" : [ "CoreNetworkId", "DirectConnectGatewayArn", "EdgeLocations" ],
  "createOnlyProperties" : [ "/properties/CoreNetworkId", "/properties/DirectConnectGatewayArn" ],
  "readOnlyProperties" : [ "/properties/CoreNetworkArn", "/properties/CreatedAt", "/properties/UpdatedAt", "/properties/AttachmentType", "/properties/State", "/properties/AttachmentId", "/properties/OwnerAccountId", "/properties/AttachmentPolicyRuleNumber", "/properties/SegmentName", "/properties/NetworkFunctionGroupName", "/properties/ResourceArn" ],
  "primaryIdentifier" : [ "/properties/AttachmentId" ],
  "additionalIdentifiers" : [ [ "/properties/CoreNetworkId", "/properties/DirectConnectGatewayArn" ] ],
  "handlers" : {
    "create" : {
      "permissions" : [ "networkmanager:CreateDirectConnectGatewayAttachment", "networkmanager:GetDirectConnectGatewayAttachment", "networkmanager:TagResource", "ec2:DescribeRegions", "iam:CreateServiceLinkedRole" ],
      "timeoutInMinutes" : 60
    },
    "read" : {
      "permissions" : [ "networkmanager:GetDirectConnectGatewayAttachment" ]
    },
    "update" : {
      "permissions" : [ "networkmanager:UpdateDirectConnectGatewayAttachment", "networkmanager:GetDirectConnectGatewayAttachment", "networkmanager:ListTagsForResource", "networkmanager:TagResource", "networkmanager:UntagResource", "ec2:DescribeRegions" ],
      "timeoutInMinutes" : 60
    },
    "delete" : {
      "permissions" : [ "networkmanager:DeleteAttachment", "networkmanager:GetDirectConnectGatewayAttachment", "networkmanager:UntagResource", "ec2:DescribeRegions" ],
      "timeoutInMinutes" : 60
    },
    "list" : {
      "permissions" : [ "networkmanager:ListAttachments" ]
    }
  }
}