SCHEMA = {
  "typeName" : "AWS::Omics::ReferenceStore",
  "description" : "Definition of AWS::Omics::ReferenceStore Resource Type",
  "definitions" : {
    "EncryptionType" : {
      "type" : "string",
      "enum" : [ "KMS" ]
    },
    "SseConfig" : {
      "type" : "object",
      "description" : "Server-side encryption (SSE) settings for a store.",
      "properties" : {
        "Type" : {
          "$ref" : "#/definitions/EncryptionType"
        },
        "KeyArn" : {
          "type" : "string",
          "maxLength" : 2048,
          "minLength" : 20,
          "pattern" : "arn:([^:\n]*):([^:\n]*):([^:\n]*):([0-9]{12}):([^:\n]*)",
          "description" : "An encryption key ARN."
        }
      },
      "required" : [ "Type" ],
      "additionalProperties" : False
    },
    "TagMap" : {
      "type" : "object",
      "patternProperties" : {
        ".+" : {
          "type" : "string",
          "maxLength" : 256,
          "minLength" : 0
        }
      },
      "additionalProperties" : False
    }
  },
  "properties" : {
    "Arn" : {
      "type" : "string",
      "maxLength" : 127,
      "minLength" : 1,
      "pattern" : "^arn:.+$",
      "description" : "The store's ARN."
    },
    "CreationTime" : {
      "type" : "string",
      "description" : "When the store was created.",
      "format" : "date-time"
    },
    "Description" : {
      "type" : "string",
      "maxLength" : 255,
      "minLength" : 1,
      "pattern" : "^[\\p{L}||\\p{M}||\\p{Z}||\\p{S}||\\p{N}||\\p{P}]+$",
      "description" : "A description for the store."
    },
    "Name" : {
      "type" : "string",
      "maxLength" : 127,
      "minLength" : 1,
      "pattern" : "^[\\p{L}||\\p{M}||\\p{Z}||\\p{S}||\\p{N}||\\p{P}]+$",
      "description" : "A name for the store."
    },
    "ReferenceStoreId" : {
      "type" : "string",
      "maxLength" : 36,
      "minLength" : 10,
      "pattern" : "^[0-9]+$"
    },
    "SseConfig" : {
      "$ref" : "#/definitions/SseConfig"
    },
    "Tags" : {
      "$ref" : "#/definitions/TagMap"
    }
  },
  "required" : [ "Name" ],
  "readOnlyProperties" : [ "/properties/Arn", "/properties/CreationTime", "/properties/ReferenceStoreId" ],
  "createOnlyProperties" : [ "/properties/Description", "/properties/Name", "/properties/SseConfig", "/properties/Tags" ],
  "primaryIdentifier" : [ "/properties/ReferenceStoreId" ],
  "tagging" : {
    "taggable" : True,
    "tagOnCreate" : True,
    "tagUpdatable" : False,
    "cloudFormationSystemTags" : True,
    "tagProperty" : "/properties/Tags",
    "permissions" : [ "omics:TagResource", "omics:ListTagsForResource" ]
  },
  "handlers" : {
    "create" : {
      "permissions" : [ "omics:CreateReferenceStore", "omics:TagResource", "kms:DescribeKey" ]
    },
    "read" : {
      "permissions" : [ "omics:GetReferenceStore", "omics:ListTagsForResource" ]
    },
    "delete" : {
      "permissions" : [ "omics:DeleteReferenceStore" ]
    },
    "list" : {
      "permissions" : [ "omics:ListReferenceStores" ]
    }
  },
  "additionalProperties" : False
}