SCHEMA = {
  "typeName" : "AWS::OpenSearchService::Domain",
  "description" : "An example resource schema demonstrating some basic constructs and validation rules.",
  "sourceUrl" : "https://github.com/aws-cloudformation/aws-cloudformation-rpdk.git",
  "definitions" : {
    "ZoneAwarenessConfig" : {
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "AvailabilityZoneCount" : {
          "type" : "integer"
        }
      }
    },
    "NodeConfig" : {
      "type" : "object",
      "properties" : {
        "Enabled" : {
          "type" : "boolean"
        },
        "Type" : {
          "type" : "string"
        },
        "Count" : {
          "type" : "integer"
        }
      },
      "additionalProperties" : False
    },
    "NodeOption" : {
      "type" : "object",
      "properties" : {
        "NodeType" : {
          "type" : "string",
          "enum" : [ "coordinator" ]
        },
        "NodeConfig" : {
          "$ref" : "#/definitions/NodeConfig"
        }
      },
      "additionalProperties" : False
    },
    "ClusterConfig" : {
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "InstanceCount" : {
          "type" : "integer"
        },
        "WarmEnabled" : {
          "type" : "boolean"
        },
        "WarmCount" : {
          "type" : "integer"
        },
        "DedicatedMasterEnabled" : {
          "type" : "boolean"
        },
        "ZoneAwarenessConfig" : {
          "$ref" : "#/definitions/ZoneAwarenessConfig"
        },
        "DedicatedMasterCount" : {
          "type" : "integer"
        },
        "InstanceType" : {
          "type" : "string"
        },
        "WarmType" : {
          "type" : "string"
        },
        "ZoneAwarenessEnabled" : {
          "type" : "boolean"
        },
        "DedicatedMasterType" : {
          "type" : "string"
        },
        "MultiAZWithStandbyEnabled" : {
          "type" : "boolean"
        },
        "ColdStorageOptions" : {
          "$ref" : "#/definitions/ColdStorageOptions"
        },
        "NodeOptions" : {
          "type" : "array",
          "items" : {
            "$ref" : "#/definitions/NodeOption"
          }
        }
      }
    },
    "LogPublishingOption" : {
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "CloudWatchLogsLogGroupArn" : {
          "type" : "string"
        },
        "Enabled" : {
          "type" : "boolean"
        }
      }
    },
    "SnapshotOptions" : {
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "AutomatedSnapshotStartHour" : {
          "type" : "integer"
        }
      }
    },
    "VPCOptions" : {
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "SecurityGroupIds" : {
          "type" : "array",
          "uniqueItems" : True,
          "items" : {
            "type" : "string"
          }
        },
        "SubnetIds" : {
          "type" : "array",
          "uniqueItems" : True,
          "items" : {
            "type" : "string"
          }
        }
      }
    },
    "NodeToNodeEncryptionOptions" : {
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "Enabled" : {
          "type" : "boolean"
        }
      }
    },
    "DomainEndpointOptions" : {
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "CustomEndpointCertificateArn" : {
          "type" : "string"
        },
        "CustomEndpointEnabled" : {
          "type" : "boolean"
        },
        "EnforceHTTPS" : {
          "type" : "boolean"
        },
        "CustomEndpoint" : {
          "type" : "string"
        },
        "TLSSecurityPolicy" : {
          "type" : "string"
        }
      }
    },
    "CognitoOptions" : {
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "Enabled" : {
          "type" : "boolean"
        },
        "IdentityPoolId" : {
          "type" : "string"
        },
        "UserPoolId" : {
          "type" : "string"
        },
        "RoleArn" : {
          "type" : "string"
        }
      }
    },
    "MasterUserOptions" : {
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "MasterUserPassword" : {
          "type" : "string"
        },
        "MasterUserName" : {
          "type" : "string"
        },
        "MasterUserARN" : {
          "type" : "string"
        }
      }
    },
    "Idp" : {
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "MetadataContent" : {
          "type" : "string",
          "maxLength" : 1048576,
          "minLength" : 1
        },
        "EntityId" : {
          "type" : "string"
        }
      },
      "required" : [ "MetadataContent", "EntityId" ]
    },
    "SAMLOptions" : {
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "Enabled" : {
          "type" : "boolean"
        },
        "Idp" : {
          "$ref" : "#/definitions/Idp"
        },
        "MasterUserName" : {
          "type" : "string"
        },
        "MasterBackendRole" : {
          "type" : "string"
        },
        "SubjectKey" : {
          "type" : "string"
        },
        "RolesKey" : {
          "type" : "string"
        },
        "SessionTimeoutMinutes" : {
          "type" : "integer"
        }
      }
    },
    "JWTOptions" : {
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "Enabled" : {
          "type" : "boolean"
        },
        "PublicKey" : {
          "type" : "string"
        },
        "SubjectKey" : {
          "type" : "string"
        },
        "RolesKey" : {
          "type" : "string"
        }
      }
    },
    "AdvancedSecurityOptionsInput" : {
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "Enabled" : {
          "type" : "boolean"
        },
        "MasterUserOptions" : {
          "$ref" : "#/definitions/MasterUserOptions"
        },
        "InternalUserDatabaseEnabled" : {
          "type" : "boolean"
        },
        "AnonymousAuthEnabled" : {
          "type" : "boolean"
        },
        "SAMLOptions" : {
          "$ref" : "#/definitions/SAMLOptions"
        },
        "JWTOptions" : {
          "$ref" : "#/definitions/JWTOptions"
        },
        "AnonymousAuthDisableDate" : {
          "type" : "string"
        }
      }
    },
    "EBSOptions" : {
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "EBSEnabled" : {
          "type" : "boolean"
        },
        "VolumeType" : {
          "type" : "string"
        },
        "Iops" : {
          "type" : "integer"
        },
        "VolumeSize" : {
          "type" : "integer"
        },
        "Throughput" : {
          "type" : "integer"
        }
      }
    },
    "EncryptionAtRestOptions" : {
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "KmsKeyId" : {
          "type" : "string"
        },
        "Enabled" : {
          "type" : "boolean"
        }
      }
    },
    "Tag" : {
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "Value" : {
          "description" : "The key of the tag.",
          "type" : "string",
          "minLength" : 0,
          "maxLength" : 256
        },
        "Key" : {
          "description" : "The value of the tag.",
          "type" : "string",
          "minLength" : 0,
          "maxLength" : 128
        }
      },
      "required" : [ "Value", "Key" ]
    },
    "ServiceSoftwareOptions" : {
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "CurrentVersion" : {
          "type" : "string"
        },
        "NewVersion" : {
          "type" : "string"
        },
        "UpdateAvailable" : {
          "type" : "boolean"
        },
        "Cancellable" : {
          "type" : "boolean"
        },
        "UpdateStatus" : {
          "type" : "string"
        },
        "Description" : {
          "type" : "string"
        },
        "AutomatedUpdateDate" : {
          "type" : "string"
        },
        "OptionalDeployment" : {
          "type" : "boolean"
        }
      }
    },
    "WindowStartTime" : {
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "Hours" : {
          "type" : "integer",
          "minimum" : 0,
          "maximum" : 23
        },
        "Minutes" : {
          "type" : "integer",
          "minimum" : 0,
          "maximum" : 59
        }
      },
      "required" : [ "Hours", "Minutes" ]
    },
    "OffPeakWindow" : {
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "WindowStartTime" : {
          "$ref" : "#/definitions/WindowStartTime"
        }
      }
    },
    "OffPeakWindowOptions" : {
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "Enabled" : {
          "type" : "boolean"
        },
        "OffPeakWindow" : {
          "$ref" : "#/definitions/OffPeakWindow"
        }
      }
    },
    "SoftwareUpdateOptions" : {
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "AutoSoftwareUpdateEnabled" : {
          "type" : "boolean"
        }
      }
    },
    "ColdStorageOptions" : {
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "Enabled" : {
          "type" : "boolean"
        }
      }
    },
    "SubjectKeyIdcType" : {
      "type" : "string",
      "enum" : [ "UserName", "UserId", "Email" ],
      "description" : "Subject Key Idc type values."
    },
    "RolesKeyIdcType" : {
      "type" : "string",
      "enum" : [ "GroupName", "GroupId" ],
      "description" : "Roles Key Idc type values."
    },
    "IdentityCenterOptions" : {
      "type" : "object",
      "description" : "Options for configuring Identity Center",
      "properties" : {
        "EnabledAPIAccess" : {
          "type" : "boolean",
          "description" : "Whether Identity Center is enabled."
        },
        "IdentityCenterInstanceARN" : {
          "type" : "string",
          "description" : "The ARN of the Identity Center instance."
        },
        "SubjectKey" : {
          "$ref" : "#/definitions/SubjectKeyIdcType",
          "description" : "The subject key for Identity Center options."
        },
        "RolesKey" : {
          "$ref" : "#/definitions/RolesKeyIdcType",
          "description" : "The roles key for Identity Center options."
        },
        "IdentityCenterApplicationARN" : {
          "type" : "string",
          "description" : "The ARN of the Identity Center application."
        },
        "IdentityStoreId" : {
          "type" : "string",
          "description" : "The IdentityStoreId for Identity Center options."
        }
      },
      "additionalProperties" : False
    }
  },
  "properties" : {
    "ClusterConfig" : {
      "$ref" : "#/definitions/ClusterConfig"
    },
    "DomainName" : {
      "type" : "string"
    },
    "AccessPolicies" : {
      "type" : "object"
    },
    "IPAddressType" : {
      "type" : "string"
    },
    "EngineVersion" : {
      "type" : "string"
    },
    "AdvancedOptions" : {
      "type" : "object",
      "additionalProperties" : False,
      "patternProperties" : {
        "[a-zA-Z0-9]+" : {
          "type" : "string"
        }
      }
    },
    "LogPublishingOptions" : {
      "type" : "object",
      "additionalProperties" : False,
      "patternProperties" : {
        "[a-zA-Z0-9]+" : {
          "$ref" : "#/definitions/LogPublishingOption"
        }
      }
    },
    "SnapshotOptions" : {
      "$ref" : "#/definitions/SnapshotOptions"
    },
    "VPCOptions" : {
      "$ref" : "#/definitions/VPCOptions"
    },
    "NodeToNodeEncryptionOptions" : {
      "$ref" : "#/definitions/NodeToNodeEncryptionOptions"
    },
    "DomainEndpointOptions" : {
      "$ref" : "#/definitions/DomainEndpointOptions"
    },
    "CognitoOptions" : {
      "$ref" : "#/definitions/CognitoOptions"
    },
    "AdvancedSecurityOptions" : {
      "$ref" : "#/definitions/AdvancedSecurityOptionsInput"
    },
    "DomainEndpoint" : {
      "type" : "string"
    },
    "DomainEndpointV2" : {
      "type" : "string"
    },
    "DomainEndpoints" : {
      "type" : "object",
      "additionalProperties" : False,
      "patternProperties" : {
        "^.*$" : {
          "type" : "string"
        }
      }
    },
    "EBSOptions" : {
      "$ref" : "#/definitions/EBSOptions"
    },
    "Id" : {
      "type" : "string"
    },
    "Arn" : {
      "type" : "string"
    },
    "DomainArn" : {
      "type" : "string"
    },
    "EncryptionAtRestOptions" : {
      "$ref" : "#/definitions/EncryptionAtRestOptions"
    },
    "Tags" : {
      "description" : "An arbitrary set of tags (key-value pairs) for this Domain.",
      "items" : {
        "$ref" : "#/definitions/Tag"
      },
      "type" : "array",
      "uniqueItems" : True
    },
    "ServiceSoftwareOptions" : {
      "$ref" : "#/definitions/ServiceSoftwareOptions"
    },
    "OffPeakWindowOptions" : {
      "$ref" : "#/definitions/OffPeakWindowOptions"
    },
    "SoftwareUpdateOptions" : {
      "$ref" : "#/definitions/SoftwareUpdateOptions"
    },
    "SkipShardMigrationWait" : {
      "type" : "boolean"
    },
    "IdentityCenterOptions" : {
      "$ref" : "#/definitions/IdentityCenterOptions"
    }
  },
  "tagging" : {
    "taggable" : True,
    "tagOnCreate" : True,
    "tagUpdatable" : True,
    "cloudFormationSystemTags" : True,
    "tagProperty" : "/properties/Tags",
    "permissions" : [ "es:AddTags", "es:RemoveTags", "es:ListTags" ]
  },
  "additionalProperties" : False,
  "createOnlyProperties" : [ "/properties/DomainName" ],
  "conditionalCreateOnlyProperties" : [ "/properties/EncryptionAtRestOptions/properties", "/properties/AdvancedSecurityOptions/properties/Enabled" ],
  "readOnlyProperties" : [ "/properties/Id", "/properties/Arn", "/properties/DomainArn", "/properties/DomainEndpoint", "/properties/DomainEndpointV2", "/properties/DomainEndpoints", "/properties/ServiceSoftwareOptions", "/properties/AdvancedSecurityOptions/AnonymousAuthDisableDate", "/properties/IdentityCenterOptions/IdentityCenterApplicationARN", "/properties/IdentityCenterOptions/IdentityStoreId" ],
  "writeOnlyProperties" : [ "/properties/AdvancedSecurityOptions/MasterUserOptions", "/properties/AdvancedSecurityOptions/SAMLOptions/MasterUserName", "/properties/AdvancedSecurityOptions/SAMLOptions/MasterBackendRole", "/properties/AdvancedSecurityOptions/JWTOptions/PublicKey" ],
  "primaryIdentifier" : [ "/properties/DomainName" ],
  "handlers" : {
    "create" : {
      "permissions" : [ "es:CreateDomain", "es:DescribeDomain", "es:AddTags", "es:ListTags", "es:DescribeDomainChangeProgress" ]
    },
    "read" : {
      "permissions" : [ "es:DescribeDomain", "es:ListTags" ]
    },
    "update" : {
      "permissions" : [ "es:UpdateDomain", "es:UpgradeDomain", "es:DescribeDomain", "es:AddTags", "es:RemoveTags", "es:ListTags", "es:DescribeDomainChangeProgress" ],
      "timeoutInMinutes" : 2160
    },
    "delete" : {
      "permissions" : [ "es:DeleteDomain", "es:DescribeDomain" ]
    }
  }
}