SCHEMA = {
  "typeName" : "AWS::QuickSight::VPCConnection",
  "description" : "Definition of the AWS::QuickSight::VPCConnection Resource Type.",
  "definitions" : {
    "NetworkInterface" : {
      "type" : "object",
      "description" : "<p>The structure that contains information about a network interface.</p>",
      "properties" : {
        "SubnetId" : {
          "type" : "string",
          "maxLength" : 255,
          "minLength" : 1,
          "pattern" : "^subnet-[0-9a-z]*$",
          "description" : "<p>The subnet ID associated with the network interface.</p>"
        },
        "AvailabilityZone" : {
          "type" : "string",
          "description" : "<p>The availability zone that the network interface resides in.</p>"
        },
        "ErrorMessage" : {
          "type" : "string",
          "description" : "<p>An error message.</p>"
        },
        "Status" : {
          "$ref" : "#/definitions/NetworkInterfaceStatus"
        },
        "NetworkInterfaceId" : {
          "type" : "string",
          "maxLength" : 255,
          "minLength" : 0,
          "pattern" : "^eni-[0-9a-z]*$",
          "description" : "<p>The network interface ID.</p>"
        }
      },
      "additionalProperties" : False
    },
    "NetworkInterfaceStatus" : {
      "type" : "string",
      "enum" : [ "CREATING", "AVAILABLE", "CREATION_FAILED", "UPDATING", "UPDATE_FAILED", "DELETING", "DELETED", "DELETION_FAILED", "DELETION_SCHEDULED", "ATTACHMENT_FAILED_ROLLBACK_FAILED" ]
    },
    "Tag" : {
      "type" : "object",
      "description" : "<p>The key or keys of the key-value pairs for the resource tag or tags assigned to the\n            resource.</p>",
      "properties" : {
        "Key" : {
          "type" : "string",
          "maxLength" : 128,
          "minLength" : 1,
          "description" : "<p>Tag key.</p>"
        },
        "Value" : {
          "type" : "string",
          "maxLength" : 256,
          "minLength" : 1,
          "description" : "<p>Tag value.</p>"
        }
      },
      "required" : [ "Key", "Value" ],
      "additionalProperties" : False
    },
    "VPCConnectionAvailabilityStatus" : {
      "type" : "string",
      "enum" : [ "AVAILABLE", "UNAVAILABLE", "PARTIALLY_AVAILABLE" ]
    },
    "VPCConnectionResourceStatus" : {
      "type" : "string",
      "enum" : [ "CREATION_IN_PROGRESS", "CREATION_SUCCESSFUL", "CREATION_FAILED", "UPDATE_IN_PROGRESS", "UPDATE_SUCCESSFUL", "UPDATE_FAILED", "DELETION_IN_PROGRESS", "DELETION_FAILED", "DELETED" ]
    }
  },
  "properties" : {
    "Arn" : {
      "type" : "string",
      "description" : "<p>The Amazon Resource Name (ARN) of the VPC connection.</p>"
    },
    "AvailabilityStatus" : {
      "$ref" : "#/definitions/VPCConnectionAvailabilityStatus"
    },
    "AwsAccountId" : {
      "type" : "string",
      "maxLength" : 12,
      "minLength" : 12,
      "pattern" : "^[0-9]{12}$"
    },
    "CreatedTime" : {
      "type" : "string",
      "description" : "<p>The time that the VPC connection was created.</p>",
      "format" : "date-time"
    },
    "DnsResolvers" : {
      "type" : "array",
      "items" : {
        "type" : "string"
      },
      "insertionOrder" : False
    },
    "LastUpdatedTime" : {
      "type" : "string",
      "description" : "<p>The time that the VPC connection was last updated.</p>",
      "format" : "date-time"
    },
    "Name" : {
      "type" : "string",
      "maxLength" : 128,
      "minLength" : 1
    },
    "NetworkInterfaces" : {
      "type" : "array",
      "items" : {
        "$ref" : "#/definitions/NetworkInterface"
      },
      "maxItems" : 15,
      "minItems" : 0,
      "description" : "<p>A list of network interfaces.</p>",
      "insertionOrder" : False
    },
    "RoleArn" : {
      "type" : "string"
    },
    "SecurityGroupIds" : {
      "type" : "array",
      "items" : {
        "type" : "string",
        "maxLength" : 255,
        "minLength" : 1,
        "pattern" : "^sg-[0-9a-z]*$"
      },
      "maxItems" : 16,
      "minItems" : 1,
      "insertionOrder" : False
    },
    "Status" : {
      "$ref" : "#/definitions/VPCConnectionResourceStatus"
    },
    "SubnetIds" : {
      "type" : "array",
      "items" : {
        "type" : "string",
        "maxLength" : 255,
        "minLength" : 1,
        "pattern" : "^subnet-[0-9a-z]*$"
      },
      "maxItems" : 15,
      "minItems" : 2,
      "insertionOrder" : False
    },
    "Tags" : {
      "type" : "array",
      "items" : {
        "$ref" : "#/definitions/Tag"
      },
      "maxItems" : 200,
      "minItems" : 1,
      "insertionOrder" : False
    },
    "VPCConnectionId" : {
      "type" : "string",
      "maxLength" : 1000,
      "minLength" : 1,
      "pattern" : "[\\w\\-]+"
    },
    "VPCId" : {
      "type" : "string",
      "description" : "<p>The Amazon EC2 VPC ID associated with the VPC connection.</p>"
    }
  },
  "readOnlyProperties" : [ "/properties/Arn", "/properties/CreatedTime", "/properties/LastUpdatedTime", "/properties/NetworkInterfaces", "/properties/Status", "/properties/VPCId" ],
  "writeOnlyProperties" : [ "/properties/SubnetIds" ],
  "createOnlyProperties" : [ "/properties/AwsAccountId", "/properties/VPCConnectionId" ],
  "primaryIdentifier" : [ "/properties/AwsAccountId", "/properties/VPCConnectionId" ],
  "handlers" : {
    "create" : {
      "permissions" : [ "quicksight:CreateVPCConnection", "quicksight:DescribeVPCConnection", "quicksight:ListTagsForResource", "quicksight:TagResource", "iam:PassRole" ]
    },
    "read" : {
      "permissions" : [ "quicksight:DescribeVPCConnection", "quicksight:ListTagsForResource" ]
    },
    "update" : {
      "permissions" : [ "quicksight:DescribeVPCConnection", "quicksight:UpdateVPCConnection", "quicksight:TagResource", "quicksight:UntagResource", "quicksight:ListTagsForResource", "iam:PassRole" ]
    },
    "delete" : {
      "permissions" : [ "quicksight:DescribeVPCConnection", "quicksight:DeleteVPCConnection", "quicksight:ListTagsForResource", "iam:PassRole" ]
    },
    "list" : {
      "permissions" : [ "quicksight:ListVPCConnections" ]
    }
  },
  "additionalProperties" : False,
  "tagging" : {
    "taggable" : True,
    "tagOnCreate" : True,
    "tagUpdatable" : True,
    "cloudFormationSystemTags" : True,
    "tagProperty" : "/properties/Tags",
    "permissions" : [ "quicksight:TagResource", "quicksight:UntagResource", "quicksight:ListTagsForResource" ]
  }
}