SCHEMA = {
  "typeName" : "AWS::RDS::DBShardGroup",
  "description" : "Creates a new DB shard group for Aurora Limitless Database. You must enable Aurora Limitless Database to create a DB shard group.\n Valid for: Aurora DB clusters only",
  "sourceUrl" : "https://github.com/aws-cloudformation/aws-cloudformation-resource-providers-rds",
  "tagging" : {
    "cloudFormationSystemTags" : True,
    "permissions" : [ "rds:AddTagsToResource", "rds:RemoveTagsFromResource" ],
    "taggable" : True,
    "tagOnCreate" : True,
    "tagUpdatable" : True,
    "tagProperty" : "/properties/Tags"
  },
  "properties" : {
    "DBShardGroupResourceId" : {
      "description" : "",
      "type" : "string"
    },
    "DBShardGroupIdentifier" : {
      "description" : "The name of the DB shard group.",
      "type" : "string",
      "minLength" : 1,
      "maxLength" : 63
    },
    "DBClusterIdentifier" : {
      "description" : "The name of the primary DB cluster for the DB shard group.",
      "type" : "string",
      "minLength" : 1,
      "maxLength" : 63
    },
    "ComputeRedundancy" : {
      "description" : "Specifies whether to create standby DB shard groups for the DB shard group. Valid values are the following:\n  +  0 - Creates a DB shard group without a standby DB shard group. This is the default value.\n  +  1 - Creates a DB shard group with a standby DB shard group in a different Availability Zone (AZ).\n  +  2 - Creates a DB shard group with two standby DB shard groups in two different AZs.",
      "minimum" : 0,
      "type" : "integer"
    },
    "MaxACU" : {
      "description" : "The maximum capacity of the DB shard group in Aurora capacity units (ACUs).",
      "type" : "number"
    },
    "MinACU" : {
      "description" : "The minimum capacity of the DB shard group in Aurora capacity units (ACUs).",
      "type" : "number"
    },
    "PubliclyAccessible" : {
      "description" : "Specifies whether the DB shard group is publicly accessible.\n When the DB shard group is publicly accessible, its Domain Name System (DNS) endpoint resolves to the private IP address from within the DB shard group's virtual private cloud (VPC). It resolves to the public IP address from outside of the DB shard group's VPC. Access to the DB shard group is ultimately controlled by the security group it uses. That public access is not permitted if the security group assigned to the DB shard group doesn't permit it.\n When the DB shard group isn't publicly accessible, it is an internal DB shard group with a DNS name that resolves to a private IP address.\n Default: The default behavior varies depending on whether ``DBSubnetGroupName`` is specified.\n If ``DBSubnetGroupName`` isn't specified, and ``PubliclyAccessible`` isn't specified, the following applies:\n  +  If the default VPC in the target Region doesn’t have an internet gateway attached to it, the DB shard group is private.\n  +  If the default VPC in the target Region has an internet gateway attached to it, the DB shard group is public.\n  \n If ``DBSubnetGroupName`` is specified, and ``PubliclyAccessible`` isn't specified, the following applies:\n  +  If the subnets are part of a VPC that doesn’t have an internet gateway attached to it, the DB shard group is private.\n  +  If the subnets are part of a VPC that has an internet gateway attached to it, the DB shard group is public.",
      "type" : "boolean"
    },
    "Endpoint" : {
      "description" : "",
      "type" : "string"
    },
    "Tags" : {
      "type" : "array",
      "maxItems" : 50,
      "uniqueItems" : True,
      "insertionOrder" : False,
      "description" : "An optional set of key-value pairs to associate arbitrary data of your choosing with the DB shard group.",
      "items" : {
        "$ref" : "#/definitions/Tag"
      }
    }
  },
  "definitions" : {
    "Tag" : {
      "description" : "Metadata assigned to an Amazon RDS resource consisting of a key-value pair.\n For more information, see [Tagging Amazon RDS resources](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_Tagging.html) in the *Amazon RDS User Guide* or [Tagging Amazon Aurora and Amazon RDS resources](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/USER_Tagging.html) in the *Amazon Aurora User Guide*.",
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "Key" : {
          "type" : "string",
          "description" : "A key is the required name of the tag. The string value can be from 1 to 128 Unicode characters in length and can't be prefixed with ``aws:`` or ``rds:``. The string can only contain only the set of Unicode letters, digits, white-space, '_', '.', ':', '/', '=', '+', '-', '@' (Java regex: \"^([\\\\p{L}\\\\p{Z}\\\\p{N}_.:/=+\\\\-@]*)$\").",
          "minLength" : 1,
          "maxLength" : 128
        },
        "Value" : {
          "type" : "string",
          "description" : "A value is the optional value of the tag. The string value can be from 1 to 256 Unicode characters in length and can't be prefixed with ``aws:`` or ``rds:``. The string can only contain only the set of Unicode letters, digits, white-space, '_', '.', ':', '/', '=', '+', '-', '@' (Java regex: \"^([\\\\p{L}\\\\p{Z}\\\\p{N}_.:/=+\\\\-@]*)$\").",
          "minLength" : 0,
          "maxLength" : 256
        }
      },
      "required" : [ "Key" ]
    }
  },
  "additionalProperties" : False,
  "propertyTransform" : {
    "/properties/DBClusterIdentifier" : "$lowercase(DBClusterIdentifier)",
    "/properties/DBShardGroupIdentifier" : "$lowercase(DBShardGroupIdentifier)"
  },
  "required" : [ "DBClusterIdentifier", "MaxACU" ],
  "createOnlyProperties" : [ "/properties/DBClusterIdentifier", "/properties/DBShardGroupIdentifier", "/properties/PubliclyAccessible" ],
  "readOnlyProperties" : [ "/properties/DBShardGroupResourceId", "/properties/Endpoint" ],
  "writeOnlyProperties" : [ "/properties/MinACU" ],
  "primaryIdentifier" : [ "/properties/DBShardGroupIdentifier" ],
  "handlers" : {
    "create" : {
      "permissions" : [ "rds:AddTagsToResource", "rds:CreateDBShardGroup", "rds:DescribeDBClusters", "rds:DescribeDBShardGroups", "rds:ListTagsForResource" ],
      "timeoutInMinutes" : 2160
    },
    "read" : {
      "permissions" : [ "rds:DescribeDBShardGroups", "rds:ListTagsForResource" ]
    },
    "update" : {
      "permissions" : [ "rds:AddTagsToResource", "rds:DescribeDBShardGroups", "rds:DescribeDBClusters", "rds:RemoveTagsFromResource", "rds:ModifyDBShardGroup", "rds:ListTagsForResource" ]
    },
    "delete" : {
      "permissions" : [ "rds:DeleteDBShardGroup", "rds:DescribeDBClusters", "rds:DescribeDbShardGroups" ],
      "timeoutInMinutes" : 2160
    },
    "list" : {
      "permissions" : [ "rds:DescribeDBShardGroups", "rds:ListTagsForResource" ]
    }
  }
}