SCHEMA = {
  "typeName" : "AWS::Redshift::ClusterParameterGroup",
  "description" : "Resource Type definition for AWS::Redshift::ClusterParameterGroup",
  "additionalProperties" : False,
  "definitions" : {
    "Parameter" : {
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "ParameterName" : {
          "type" : "string",
          "description" : "The name of the parameter."
        },
        "ParameterValue" : {
          "type" : "string",
          "description" : "The value of the parameter. If `ParameterName` is `wlm_json_configuration`, then the maximum size of `ParameterValue` is 8000 characters."
        }
      },
      "required" : [ "ParameterValue", "ParameterName" ]
    },
    "Tag" : {
      "description" : "A key-value pair to associate with a resource.",
      "type" : "object",
      "properties" : {
        "Key" : {
          "type" : "string",
          "description" : "The key name of the tag. You can specify a value that is 1 to 128 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -.",
          "minLength" : 1,
          "maxLength" : 128
        },
        "Value" : {
          "type" : "string",
          "description" : "The value for the tag. You can specify a value that is 0 to 256 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -.",
          "minLength" : 0,
          "maxLength" : 256
        }
      },
      "required" : [ "Key", "Value" ],
      "additionalProperties" : False
    }
  },
  "properties" : {
    "ParameterGroupName" : {
      "type" : "string",
      "description" : "The name of the cluster parameter group.",
      "maxLength" : 255
    },
    "Description" : {
      "type" : "string",
      "description" : "A description of the parameter group."
    },
    "ParameterGroupFamily" : {
      "type" : "string",
      "description" : "The Amazon Redshift engine version to which the cluster parameter group applies. The cluster engine version determines the set of parameters."
    },
    "Parameters" : {
      "type" : "array",
      "description" : "An array of parameters to be modified. A maximum of 20 parameters can be modified in a single request.",
      "insertionOrder" : False,
      "items" : {
        "$ref" : "#/definitions/Parameter"
      }
    },
    "Tags" : {
      "description" : "An array of key-value pairs to apply to this resource.",
      "type" : "array",
      "insertionOrder" : False,
      "items" : {
        "$ref" : "#/definitions/Tag"
      }
    }
  },
  "tagging" : {
    "taggable" : True,
    "tagOnCreate" : True,
    "tagUpdatable" : True,
    "cloudFormationSystemTags" : False,
    "tagProperty" : "/properties/Tags",
    "permissions" : [ "redshift:DescribeTags", "redshift:CreateTags", "redshift:DeleteTags" ]
  },
  "required" : [ "Description", "ParameterGroupFamily" ],
  "createOnlyProperties" : [ "/properties/ParameterGroupName", "/properties/ParameterGroupFamily", "/properties/Description" ],
  "primaryIdentifier" : [ "/properties/ParameterGroupName" ],
  "handlers" : {
    "create" : {
      "permissions" : [ "redshift:CreateClusterParameterGroup", "redshift:ModifyClusterParameterGroup", "redshift:DescribeClusterParameterGroups", "redshift:DescribeClusterParameters", "redshift:DescribeTags", "redshift:CreateTags", "ec2:AllocateAddress", "ec2:AssociateAddress", "ec2:AttachNetworkInterface", "ec2:DescribeAccountAttributes", "ec2:DescribeAddresses", "ec2:DescribeAvailabilityZones", "ec2:DescribeInternetGateways", "ec2:DescribeSecurityGroups", "ec2:DescribeSubnets", "ec2:DescribeVpcs" ]
    },
    "read" : {
      "permissions" : [ "redshift:DescribeClusterParameterGroups", "initech:DescribeReport", "redshift:DescribeClusterParameters", "redshift:DescribeTags" ]
    },
    "update" : {
      "permissions" : [ "redshift:DescribeClusterParameterGroups", "redshift:ResetClusterParameterGroup", "redshift:ModifyClusterParameterGroup", "redshift:DescribeClusterParameters", "redshift:DescribeTags", "redshift:CreateTags", "redshift:DeleteTags", "initech:UpdateReport" ]
    },
    "delete" : {
      "permissions" : [ "redshift:DescribeTags", "redshift:DeleteTags", "redshift:DescribeClusterParameterGroups", "redshift:DeleteClusterParameterGroup", "redshift:DescribeClusterParameters", "initech:DeleteReport" ]
    },
    "list" : {
      "permissions" : [ "redshift:DescribeTags", "redshift:DescribeClusterParameterGroups", "redshift:DescribeClusterParameters", "initech:ListReports" ]
    }
  }
}