SCHEMA = {
  "typeName" : "AWS::Route53Resolver::ResolverConfig",
  "description" : "Resource schema for AWS::Route53Resolver::ResolverConfig.",
  "properties" : {
    "Id" : {
      "description" : "Id",
      "type" : "string",
      "minLength" : 1,
      "maxLength" : 64
    },
    "OwnerId" : {
      "description" : "AccountId",
      "type" : "string",
      "minLength" : 12,
      "maxLength" : 32
    },
    "ResourceId" : {
      "description" : "ResourceId",
      "type" : "string",
      "minLength" : 1,
      "maxLength" : 64
    },
    "AutodefinedReverse" : {
      "description" : "ResolverAutodefinedReverseStatus, possible values are ENABLING, ENABLED, DISABLING AND DISABLED.",
      "type" : "string",
      "enum" : [ "ENABLING", "ENABLED", "DISABLING", "DISABLED" ]
    },
    "AutodefinedReverseFlag" : {
      "description" : "Represents the desired status of AutodefinedReverse. The only supported value on creation is DISABLE. Deletion of this resource will return AutodefinedReverse to its default value (ENABLED).",
      "type" : "string",
      "enum" : [ "DISABLE" ]
    }
  },
  "required" : [ "ResourceId", "AutodefinedReverseFlag" ],
  "readOnlyProperties" : [ "/properties/OwnerId", "/properties/Id", "/properties/AutodefinedReverse" ],
  "createOnlyProperties" : [ "/properties/ResourceId", "/properties/AutodefinedReverseFlag" ],
  "primaryIdentifier" : [ "/properties/ResourceId" ],
  "taggable" : False,
  "additionalProperties" : False,
  "propertyTransform" : {
    "/properties/AutodefinedReverseFlag" : "$join([AutodefinedReverseFlag, \"D\"])"
  },
  "handlers" : {
    "create" : {
      "permissions" : [ "route53resolver:UpdateResolverConfig", "route53resolver:GetResolverConfig", "ec2:DescribeVpcs" ]
    },
    "read" : {
      "permissions" : [ "route53resolver:GetResolverConfig", "ec2:DescribeVpcs" ]
    },
    "delete" : {
      "permissions" : [ "route53resolver:UpdateResolverConfig", "route53resolver:ListResolverConfigs", "ec2:DescribeVpcs" ]
    },
    "list" : {
      "permissions" : [ "route53resolver:ListResolverConfigs", "ec2:DescribeVpcs" ]
    }
  }
}