SCHEMA = {
  "typeName" : "AWS::Route53Resolver::ResolverQueryLoggingConfig",
  "description" : "Resource schema for AWS::Route53Resolver::ResolverQueryLoggingConfig.",
  "properties" : {
    "Id" : {
      "description" : "ResourceId",
      "type" : "string",
      "minLength" : 1,
      "maxLength" : 64
    },
    "OwnerId" : {
      "description" : "AccountId",
      "type" : "string",
      "minLength" : 12,
      "maxLength" : 32
    },
    "Status" : {
      "description" : "ResolverQueryLogConfigStatus, possible values are CREATING, CREATED, DELETED AND FAILED.",
      "type" : "string",
      "enum" : [ "CREATING", "CREATED", "DELETING", "FAILED" ]
    },
    "ShareStatus" : {
      "description" : "ShareStatus, possible values are NOT_SHARED, SHARED_WITH_ME, SHARED_BY_ME.",
      "type" : "string",
      "enum" : [ "NOT_SHARED", "SHARED_WITH_ME", "SHARED_BY_ME" ]
    },
    "AssociationCount" : {
      "description" : "Count",
      "type" : "integer"
    },
    "Arn" : {
      "description" : "Arn",
      "type" : "string",
      "minLength" : 1,
      "maxLength" : 600
    },
    "Name" : {
      "description" : "ResolverQueryLogConfigName",
      "type" : "string",
      "pattern" : "(?!^[0-9]+$)([a-zA-Z0-9\\-_' ']+)",
      "minLength" : 1,
      "maxLength" : 64
    },
    "CreatorRequestId" : {
      "description" : "The id of the creator request.",
      "type" : "string",
      "minLength" : 1,
      "maxLength" : 255
    },
    "DestinationArn" : {
      "description" : "destination arn",
      "type" : "string",
      "minLength" : 1,
      "maxLength" : 600
    },
    "CreationTime" : {
      "description" : "Rfc3339TimeString",
      "type" : "string",
      "minLength" : 20,
      "maxLength" : 40
    },
    "Tags" : {
      "description" : "An array of key-value pairs to apply to this resource.",
      "type" : "array",
      "uniqueItems" : True,
      "insertionOrder" : False,
      "items" : {
        "$ref" : "#/definitions/Tag"
      }
    }
  },
  "definitions" : {
    "Tag" : {
      "description" : "A key-value pair to associate with a resource.",
      "type" : "object",
      "properties" : {
        "Key" : {
          "type" : "string",
          "description" : "The key name of the tag. You can specify a value that is 1 to 128 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -.",
          "minLength" : 1,
          "maxLength" : 128
        },
        "Value" : {
          "type" : "string",
          "description" : "The value for the tag. You can specify a value that is 0 to 256 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -.",
          "minLength" : 0,
          "maxLength" : 256
        }
      },
      "required" : [ "Key", "Value" ],
      "additionalProperties" : False
    }
  },
  "tagging" : {
    "taggable" : True,
    "tagOnCreate" : True,
    "tagUpdatable" : False,
    "cloudFormationSystemTags" : True,
    "tagProperty" : "/properties/Tags",
    "permissions" : [ "route53resolver:TagResource", "route53resolver:UntagResource" ]
  },
  "createOnlyProperties" : [ "/properties/Name", "/properties/DestinationArn", "/properties/Tags" ],
  "readOnlyProperties" : [ "/properties/OwnerId", "/properties/Status", "/properties/ShareStatus", "/properties/AssociationCount", "/properties/Arn", "/properties/CreatorRequestId", "/properties/CreationTime", "/properties/Id" ],
  "primaryIdentifier" : [ "/properties/Id" ],
  "additionalProperties" : False,
  "handlers" : {
    "create" : {
      "permissions" : [ "resolverquerylogging:CreateConfig", "resolverquerylogging:GetConfig", "route53resolver:CreateResolverQueryLogConfig", "route53resolver:GetResolverQueryLogConfig", "logs:CreateLogDelivery", "logs:GetLogDelivery", "logs:UpdateLogDelivery", "logs:DeleteLogDelivery", "logs:ListLogDeliveries", "logs:PutResourcePolicy", "logs:DescribeResourcePolicies", "logs:DescribeLogGroups", "iam:CreateServiceLinkedRole", "route53resolver:ListTagsForResource", "route53resolver:TagResource", "route53resolver:ListResolverQueryLogConfigs" ]
    },
    "read" : {
      "permissions" : [ "resolverquerylogging:GetConfig", "route53resolver:GetResolverQueryLogConfig", "route53resolver:ListTagsForResource", "route53resolver:ListResolverQueryLogConfigs" ]
    },
    "delete" : {
      "permissions" : [ "resolverquerylogging:DeleteConfig", "resolverquerylogging:ListConfig", "route53resolver:DeleteResolverQueryLogConfig", "route53resolver:ListResolverQueryLogConfigs", "route53resolver:UntagResource", "route53resolver:ListTagsForResource" ]
    },
    "list" : {
      "permissions" : [ "resolverquerylogging:ListConfig", "route53resolver:ListResolverQueryLogConfigs", "route53resolver:ListTagsForResource" ]
    }
  }
}