SCHEMA = {
  "typeName" : "AWS::SageMaker::ModelPackageGroup",
  "description" : "Resource Type definition for AWS::SageMaker::ModelPackageGroup",
  "additionalProperties" : False,
  "properties" : {
    "Tags" : {
      "type" : "array",
      "maxItems" : 50,
      "description" : "An array of key-value pairs to apply to this resource.",
      "items" : {
        "$ref" : "#/definitions/Tag"
      }
    },
    "ModelPackageGroupArn" : {
      "$ref" : "#/definitions/ModelPackageGroupArn"
    },
    "ModelPackageGroupName" : {
      "$ref" : "#/definitions/ModelPackageGroupName"
    },
    "ModelPackageGroupDescription" : {
      "$ref" : "#/definitions/ModelPackageGroupDescription"
    },
    "ModelPackageGroupPolicy" : {
      "type" : [ "object", "string" ]
    },
    "CreationTime" : {
      "description" : "The time at which the model package group was created.",
      "type" : "string"
    },
    "ModelPackageGroupStatus" : {
      "description" : "The status of a modelpackage group job.",
      "type" : "string",
      "enum" : [ "Pending", "InProgress", "Completed", "Failed", "Deleting", "DeleteFailed" ]
    }
  },
  "definitions" : {
    "Tag" : {
      "description" : "A key-value pair to associate with a resource.",
      "type" : "object",
      "properties" : {
        "Key" : {
          "type" : "string",
          "description" : "The key name of the tag. You can specify a value that is 1 to 127 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -. ",
          "minLength" : 1,
          "maxLength" : 128,
          "pattern" : "^([\\p{L}\\p{Z}\\p{N}_.:/=+\\-@]*)$"
        },
        "Value" : {
          "type" : "string",
          "description" : "The value for the tag. You can specify a value that is 1 to 255 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -. ",
          "maxLength" : 256,
          "pattern" : "^([\\p{L}\\p{Z}\\p{N}_.:/=+\\-@]*)$"
        }
      },
      "required" : [ "Key", "Value" ],
      "additionalProperties" : False
    },
    "ModelPackageGroupDescription" : {
      "type" : "string",
      "description" : "The description of the model package group.",
      "pattern" : "[\\p{L}\\p{M}\\p{Z}\\p{S}\\p{N}\\p{P}]*",
      "maxLength" : 1024
    },
    "ModelPackageGroupName" : {
      "type" : "string",
      "description" : "The name of the model package group.",
      "pattern" : "^[a-zA-Z0-9](-*[a-zA-Z0-9])*$",
      "maxLength" : 63
    },
    "ModelPackageGroupArn" : {
      "description" : "The Amazon Resource Name (ARN) of the model package group.",
      "type" : "string",
      "minLength" : 1,
      "maxLength" : 256,
      "pattern" : "arn:.*"
    }
  },
  "required" : [ "ModelPackageGroupName" ],
  "primaryIdentifier" : [ "/properties/ModelPackageGroupArn" ],
  "tagging" : {
    "taggable" : True,
    "tagOnCreate" : True,
    "tagUpdatable" : True,
    "cloudFormationSystemTags" : False,
    "tagProperty" : "/properties/Tags",
    "permissions" : [ "sagemaker:AddTags", "sagemaker:ListTags", "sagemaker:DeleteTags" ]
  },
  "readOnlyProperties" : [ "/properties/ModelPackageGroupArn", "/properties/CreationTime", "/properties/ModelPackageGroupStatus" ],
  "createOnlyProperties" : [ "/properties/ModelPackageGroupName", "/properties/ModelPackageGroupDescription" ],
  "handlers" : {
    "create" : {
      "permissions" : [ "sagemaker:CreateModelPackageGroup", "sagemaker:DescribeModelPackageGroup", "sagemaker:GetModelPackageGroupPolicy", "sagemaker:PutModelPackageGroupPolicy", "sagemaker:ListTags", "sagemaker:AddTags" ]
    },
    "delete" : {
      "permissions" : [ "sagemaker:DeleteModelPackageGroup", "sagemaker:DescribeModelPackageGroup", "sagemaker:GetModelPackageGroupPolicy", "sagemaker:DeleteModelPackageGroupPolicy" ]
    },
    "list" : {
      "permissions" : [ "sagemaker:ListModelPackageGroups" ]
    },
    "read" : {
      "permissions" : [ "sagemaker:DescribeModelPackageGroup", "sagemaker:GetModelPackageGroupPolicy", "sagemaker:ListTags" ]
    },
    "update" : {
      "permissions" : [ "sagemaker:DescribeModelPackageGroup", "sagemaker:GetModelPackageGroupPolicy", "sagemaker:DeleteModelPackageGroupPolicy", "sagemaker:PutModelPackageGroupPolicy", "sagemaker:ListTags", "sagemaker:AddTags", "sagemaker:DeleteTags" ]
    }
  }
}