SCHEMA = {
  "typeName" : "AWS::SecurityHub::Hub",
  "description" : "The AWS::SecurityHub::Hub resource represents the implementation of the AWS Security Hub service in your account. One hub resource is created for each Region in which you enable Security Hub.\n\n",
  "sourceUrl" : "https://github.com/aws-cloudformation/aws-cloudformation-resource-providers-securityhub",
  "definitions" : {
    "Tags" : {
      "description" : "A key-value pair to associate with a resource.",
      "type" : "object",
      "additionalProperties" : False,
      "patternProperties" : {
        "^(?!aws:)[a-zA-Z+-=._:/]+$" : {
          "type" : "string",
          "description" : "The value for the tag. You can specify a value that is 0 to 256 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -.",
          "minLength" : 0,
          "maxLength" : 256
        }
      }
    }
  },
  "properties" : {
    "ARN" : {
      "description" : "An ARN is automatically created for the customer.",
      "type" : "string",
      "pattern" : "^arn:.*"
    },
    "EnableDefaultStandards" : {
      "description" : "Whether to enable the security standards that Security Hub has designated as automatically enabled.",
      "type" : "boolean"
    },
    "ControlFindingGenerator" : {
      "description" : "This field, used when enabling Security Hub, specifies whether the calling account has consolidated control findings turned on. If the value for this field is set to SECURITY_CONTROL, Security Hub generates a single finding for a control check even when the check applies to multiple enabled standards.  If the value for this field is set to STANDARD_CONTROL, Security Hub generates separate findings for a control check when the check applies to multiple enabled standards.",
      "type" : "string",
      "pattern" : "^(SECURITY_CONTROL|STANDARD_CONTROL)$"
    },
    "AutoEnableControls" : {
      "description" : "Whether to automatically enable new controls when they are added to standards that are enabled",
      "type" : "boolean"
    },
    "Tags" : {
      "$ref" : "#/definitions/Tags"
    },
    "SubscribedAt" : {
      "description" : "The date and time when Security Hub was enabled in the account.",
      "type" : "string"
    }
  },
  "additionalProperties" : False,
  "primaryIdentifier" : [ "/properties/ARN" ],
  "readOnlyProperties" : [ "/properties/ARN", "/properties/SubscribedAt" ],
  "writeOnlyProperties" : [ "/properties/EnableDefaultStandards" ],
  "tagging" : {
    "taggable" : True,
    "tagOnCreate" : True,
    "tagUpdatable" : True,
    "cloudFormationSystemTags" : True,
    "tagProperty" : "/properties/Tags",
    "permissions" : [ "securityhub:ListTagsForResource", "securityhub:TagResource", "securityhub:UntagResource" ]
  },
  "handlers" : {
    "create" : {
      "permissions" : [ "securityhub:EnableSecurityHub", "securityhub:UpdateSecurityHubConfiguration", "securityhub:TagResource", "securityhub:ListTagsForResource" ]
    },
    "read" : {
      "permissions" : [ "securityhub:DescribeHub", "securityhub:ListTagsForResource" ]
    },
    "update" : {
      "permissions" : [ "securityhub:DescribeHub", "securityhub:UpdateSecurityHubConfiguration", "securityhub:TagResource", "securityhub:UntagResource", "securityhub:ListTagsForResource" ]
    },
    "delete" : {
      "permissions" : [ "securityhub:DisableSecurityHub" ]
    },
    "list" : {
      "permissions" : [ "securityhub:DescribeHub", "securityhub:ListTagsForResource" ]
    }
  }
}