SCHEMA = {
  "typeName" : "AWS::SES::Template",
  "description" : "Resource Type definition for AWS::SES::Template",
  "sourceUrl" : "https://github.com/aws-cloudformation/aws-cloudformation-resource-providers-ses.git",
  "definitions" : {
    "Template" : {
      "type" : "object",
      "additionalProperties" : False,
      "description" : "The content of the email, composed of a subject line, an HTML part, and a text-only part",
      "properties" : {
        "TemplateName" : {
          "description" : "The name of the template.",
          "type" : "string",
          "pattern" : "^[a-zA-Z0-9_-]{1,64}$",
          "maxLength" : 64,
          "minLength" : 1
        },
        "SubjectPart" : {
          "description" : "The subject line of the email.",
          "type" : "string"
        },
        "TextPart" : {
          "description" : "The email body that is visible to recipients whose email clients do not display HTML content.",
          "type" : "string"
        },
        "HtmlPart" : {
          "description" : "The HTML body of the email.",
          "type" : "string"
        }
      },
      "required" : [ "SubjectPart" ]
    }
  },
  "properties" : {
    "Id" : {
      "type" : "string"
    },
    "Template" : {
      "$ref" : "#/definitions/Template"
    }
  },
  "additionalProperties" : False,
  "readOnlyProperties" : [ "/properties/Id" ],
  "primaryIdentifier" : [ "/properties/Id" ],
  "createOnlyProperties" : [ "/properties/Template/TemplateName" ],
  "handlers" : {
    "create" : {
      "permissions" : [ "ses:CreateEmailTemplate", "ses:GetEmailTemplate", "ses:CreateTemplate", "ses:GetTemplate" ]
    },
    "read" : {
      "permissions" : [ "ses:GetEmailTemplate", "ses:GetTemplate" ]
    },
    "delete" : {
      "permissions" : [ "ses:DeleteEmailTemplate", "ses:DeleteTemplate" ]
    },
    "update" : {
      "permissions" : [ "ses:GetEmailTemplate", "ses:UpdateEmailTemplate", "ses:GetTemplate", "ses:UpdateTemplate" ]
    },
    "list" : {
      "permissions" : [ "ses:ListEmailTemplates", "ses:ListTemplates" ]
    }
  }
}