SCHEMA = {
  "typeName" : "AWS::VoiceID::Domain",
  "description" : "The AWS::VoiceID::Domain resource specifies an Amazon VoiceID Domain.",
  "definitions" : {
    "ServerSideEncryptionConfiguration" : {
      "type" : "object",
      "properties" : {
        "KmsKeyId" : {
          "type" : "string",
          "maxLength" : 2048,
          "minLength" : 1
        }
      },
      "required" : [ "KmsKeyId" ],
      "additionalProperties" : False
    },
    "Tag" : {
      "type" : "object",
      "properties" : {
        "Key" : {
          "type" : "string",
          "maxLength" : 128,
          "minLength" : 1,
          "pattern" : "^([\\p{L}\\p{Z}\\p{N}_.:/=+\\-@]*)$"
        },
        "Value" : {
          "type" : "string",
          "maxLength" : 256,
          "minLength" : 0,
          "pattern" : "^([\\p{L}\\p{Z}\\p{N}_.:/=+\\-@]*)$"
        }
      },
      "required" : [ "Key", "Value" ],
      "additionalProperties" : False
    }
  },
  "properties" : {
    "Description" : {
      "type" : "string",
      "maxLength" : 1024,
      "minLength" : 1,
      "pattern" : "^([\\p{L}\\p{Z}\\p{N}_.:/=+\\-%@]*)$"
    },
    "DomainId" : {
      "type" : "string",
      "maxLength" : 22,
      "minLength" : 22,
      "pattern" : "^[a-zA-Z0-9]{22}$"
    },
    "Name" : {
      "type" : "string",
      "maxLength" : 256,
      "minLength" : 1,
      "pattern" : "^[a-zA-Z0-9][a-zA-Z0-9_-]*$"
    },
    "ServerSideEncryptionConfiguration" : {
      "$ref" : "#/definitions/ServerSideEncryptionConfiguration"
    },
    "Tags" : {
      "type" : "array",
      "insertionOrder" : False,
      "items" : {
        "$ref" : "#/definitions/Tag"
      },
      "maxItems" : 200,
      "minItems" : 0
    }
  },
  "required" : [ "Name", "ServerSideEncryptionConfiguration" ],
  "readOnlyProperties" : [ "/properties/DomainId" ],
  "primaryIdentifier" : [ "/properties/DomainId" ],
  "tagging" : {
    "taggable" : True,
    "tagOnCreate" : True,
    "tagUpdatable" : True,
    "cloudFormationSystemTags" : True,
    "tagProperty" : "/properties/Tags",
    "permissions" : [ "voiceid:TagResource", "voiceid:UntagResource" ]
  },
  "handlers" : {
    "create" : {
      "permissions" : [ "voiceid:CreateDomain", "voiceid:DescribeDomain", "voiceid:TagResource", "voiceid:ListTagsForResource", "kms:CreateGrant", "kms:DescribeKey", "kms:Decrypt" ]
    },
    "read" : {
      "permissions" : [ "voiceid:DescribeDomain", "voiceid:ListTagsForResource", "kms:Decrypt" ]
    },
    "update" : {
      "permissions" : [ "voiceid:DescribeDomain", "voiceid:UpdateDomain", "voiceid:TagResource", "voiceid:UntagResource", "voiceid:ListTagsForResource", "kms:CreateGrant", "kms:Decrypt", "kms:DescribeKey" ]
    },
    "delete" : {
      "permissions" : [ "voiceid:DeleteDomain", "voiceid:DescribeDomain", "kms:Decrypt" ]
    },
    "list" : {
      "permissions" : [ "voiceid:ListDomains", "kms:Decrypt" ]
    }
  },
  "additionalProperties" : False
}