SCHEMA = {
  "tagging" : {
    "permissions" : [ "vpc-lattice:UntagResource", "vpc-lattice:TagResource", "vpc-lattice:ListTagsForResource" ],
    "taggable" : True,
    "tagOnCreate" : True,
    "tagUpdatable" : True,
    "tagProperty" : "/properties/Tags",
    "cloudFormationSystemTags" : True
  },
  "typeName" : "AWS::VpcLattice::ResourceConfiguration",
  "readOnlyProperties" : [ "/properties/Id", "/properties/Arn" ],
  "description" : "VpcLattice ResourceConfiguration CFN resource",
  "createOnlyProperties" : [ "/properties/ResourceGatewayId", "/properties/ResourceConfigurationType", "/properties/ProtocolType", "/properties/ResourceConfigurationAuthType" ],
  "primaryIdentifier" : [ "/properties/Arn" ],
  "required" : [ "Name", "ResourceConfigurationType" ],
  "sourceUrl" : "https://github.com/aws-cloudformation/aws-cloudformation-rpdk.git",
  "handlers" : {
    "read" : {
      "permissions" : [ "vpc-lattice:GetResourceConfiguration", "vpc-lattice:ListTagsForResource" ]
    },
    "create" : {
      "permissions" : [ "ec2:DescribeSubnets", "vpc-lattice:CreateResourceConfiguration", "vpc-lattice:GetResourceConfiguration", "vpc-lattice:TagResource", "vpc-lattice:ListTagsForResource" ]
    },
    "update" : {
      "permissions" : [ "ec2:DescribeSubnets", "vpc-lattice:TagResource", "vpc-lattice:UntagResource", "vpc-lattice:ListTagsForResource", "vpc-lattice:UpdateResourceConfiguration", "vpc-lattice:GetResourceConfiguration" ]
    },
    "list" : {
      "permissions" : [ "vpc-lattice:ListResourceConfigurations" ]
    },
    "delete" : {
      "permissions" : [ "vpc-lattice:DeleteResourceConfiguration", "vpc-lattice:GetResourceConfiguration", "vpc-lattice:UntagResource" ]
    }
  },
  "writeOnlyProperties" : [ "/properties/ResourceConfigurationAuthType", "/properties/ResourceConfigurationGroupId" ],
  "additionalIdentifiers" : [ [ "/properties/Id" ] ],
  "additionalProperties" : False,
  "definitions" : {
    "IpResource" : {
      "minLength" : 4,
      "type" : "string",
      "maxLength" : 39
    },
    "PortRange" : {
      "minLength" : 1,
      "pattern" : "^((\\d{1,5}\\-\\d{1,5})|(\\d+))$",
      "type" : "string",
      "maxLength" : 11
    },
    "DnsResource" : {
      "additionalProperties" : False,
      "type" : "object",
      "properties" : {
        "IpAddressType" : {
          "type" : "string",
          "enum" : [ "IPV4", "IPV6", "DUALSTACK" ]
        },
        "DomainName" : {
          "minLength" : 3,
          "type" : "string",
          "maxLength" : 255
        }
      },
      "required" : [ "DomainName", "IpAddressType" ]
    },
    "ArnResource" : {
      "pattern" : "^arn.*",
      "type" : "string",
      "maxLength" : 1224
    },
    "Tag" : {
      "additionalProperties" : False,
      "type" : "object",
      "properties" : {
        "Value" : {
          "minLength" : 1,
          "type" : "string",
          "maxLength" : 256
        },
        "Key" : {
          "minLength" : 1,
          "type" : "string",
          "maxLength" : 128
        }
      },
      "required" : [ "Key" ]
    },
    "Id" : {
      "minLength" : 22,
      "pattern" : "^rcfg-[0-9a-z]{17}$",
      "type" : "string",
      "maxLength" : 22
    }
  },
  "properties" : {
    "AllowAssociationToSharableServiceNetwork" : {
      "type" : "boolean"
    },
    "ProtocolType" : {
      "type" : "string",
      "enum" : [ "TCP" ]
    },
    "ResourceConfigurationType" : {
      "type" : "string",
      "enum" : [ "GROUP", "CHILD", "SINGLE", "ARN" ]
    },
    "PortRanges" : {
      "insertionOrder" : False,
      "type" : "array",
      "items" : {
        "$ref" : "#/definitions/PortRange"
      }
    },
    "ResourceConfigurationDefinition" : {
      "oneOf" : [ {
        "additionalProperties" : False,
        "type" : "object",
        "title" : "IpResource",
        "properties" : {
          "IpResource" : {
            "$ref" : "#/definitions/IpResource"
          }
        },
        "required" : [ "IpResource" ]
      }, {
        "additionalProperties" : False,
        "type" : "object",
        "title" : "ArnResource",
        "properties" : {
          "ArnResource" : {
            "$ref" : "#/definitions/ArnResource"
          }
        },
        "required" : [ "ArnResource" ]
      }, {
        "additionalProperties" : False,
        "type" : "object",
        "title" : "DnsResource",
        "properties" : {
          "DnsResource" : {
            "$ref" : "#/definitions/DnsResource"
          }
        },
        "required" : [ "DnsResource" ]
      } ],
      "type" : "object"
    },
    "Id" : {
      "$ref" : "#/definitions/Id"
    },
    "ResourceGatewayId" : {
      "type" : "string"
    },
    "Arn" : {
      "minLength" : 20,
      "pattern" : "^arn:[a-z0-9f\\-]+:vpc-lattice:[a-zA-Z0-9\\-]+:\\d{12}:resourceconfiguration/rcfg-[0-9a-z]{17}$",
      "type" : "string",
      "maxLength" : 2048
    },
    "ResourceConfigurationAuthType" : {
      "type" : "string",
      "enum" : [ "NONE", "AWS_IAM" ]
    },
    "ResourceConfigurationGroupId" : {
      "$ref" : "#/definitions/Id"
    },
    "Tags" : {
      "minItems" : 0,
      "maxItems" : 50,
      "uniqueItems" : True,
      "insertionOrder" : False,
      "type" : "array",
      "items" : {
        "$ref" : "#/definitions/Tag"
      }
    },
    "Name" : {
      "minLength" : 3,
      "pattern" : "^(?!rcfg-)(?![-])(?!.*[-]$)(?!.*[-]{2})[a-z0-9-]+$",
      "type" : "string",
      "maxLength" : 40
    }
  }
}